@@ -6,7 +6,9 @@ OC.L10N.register(
     "Invalid file provided" : "Ongeldige lêer verskaf",
     "Invalid image" : "Ongeldige beeld",
     "Unknown filetype" : "Onbekende lêertipe",
+    "Accept" : "Aanvaar",
     "Open settings" : "Open instellings",
+    "error" : "fout",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Verenigde Arabiese Emirate",
     "Afghanistan" : "Afghanistan",
@@ -248,9 +250,7 @@ OC.L10N.register(
     "Saving …" : "Word gestoor …",
     "Saved!" : "Gestoor!",
     "Name" : "Naam",
-    "None" : "Geen",
-    "User" : "Gebruiker",
-    "Users" : "Gebruikers",
+    "Description" : "Beskrywing",
     "All messages" : "Alle boodskappe",
     "Off" : "Af",
     "Language" : "Taal",
@@ -263,45 +263,43 @@ OC.L10N.register(
     "OK" : "Goed",
     "Checking …" : "Gaan tans na …",
     "Back" : "Terug",
+    "Cancel" : "Kanselleer",
     "Confirm" : "Bevestig",
     "Reset" : "Herstel",
-    "Cancel" : "Kanselleer",
+    "This conversation is read-only" : "Hierdie gesprek is leesalleen",
     "Copy link" : "Kopieer skakel",
     "You" : "U",
     "Collapse" : "Vou In",
-    "This conversation is read-only" : "Hierdie gesprek is leesalleen",
     "Favorite" : "Gunsteling",
-    "Description" : "Beskrywing",
+    "Disable" : "Deaktiveer",
+    "Choose" : "Kies",
     "Personal" : "Persoonlik",
     "Leave conversation" : "verlaat gesprek",
     "Delete conversation" : "Skrap gesprek",
-    "Submit" : "Dien in",
     "Save" : "Stoor",
     "Edit" : "Wysig",
     "Delete" : "Skrap",
-    "Password" : "Wagwoord",
-    "Login" : "Teken aan",
-    "Nickname" : "Bynaam",
-    "Client ID" : "Kliënt-ID",
     "Notifications" : "Kennisgewings",
+    "Login" : "Teken aan",
     "Remove from favorites" : "Verwyder uit gunstelinge",
     "Add to favorites" : "Voeg by gunstelinge",
-    "Loading" : "Laai tans..",
+    "Users" : "Gebruikers",
     "Groups" : "Groepe",
-    "Password protect" : "Beskerm met 'n wagwoord",
-    "Enter password" : "Voer wagwoord in",
-    "Add participants" : "Voeg deelnemers toe",
-    "Close" : "Sluit",
+    "Loading" : "Laai tans..",
     "You are currently waiting in the lobby" : "U wag tans in die voorportaal",
+    "None" : "Geen",
     "Devices" : "Toestelle",
     "Upload" : "Oplaai",
     "Files" : " Lêers",
-    "Dismiss" : "Ontslaan",
     "Reply" : "Antwoord",
+    "Dismiss" : "Ontslaan",
     "Contact" : "Kontak",
     "Today" : "Vandag",
     "Yesterday" : "Gister",
-    "Group" : "Groep",
+    "Add participants" : "Voeg deelnemers toe",
+    "Close" : "Sluit",
+    "Password protect" : "Beskerm met 'n wagwoord",
+    "Enter password" : "Voer wagwoord in",
     "Settings" : "Instellings",
     "Send" : "Stuur",
     "Join" : "Sluit aan",
@@ -313,10 +311,16 @@ OC.L10N.register(
     "Privacy" : "Privaatheid",
     "Keyboard shortcuts" : "Sneltoetse",
     "Search" : "Soek",
-    "Open sidebar" : "Open kantbalk",
+    "Select a region" : "Kies ’n streek",
+    "Submit" : "Dien in",
+    "User" : "Gebruiker",
+    "Password" : "Wagwoord",
+    "Nickname" : "Bynaam",
+    "Client ID" : "Kliënt-ID",
     "Media" : "Media",
     "Audio" : "Oudio",
     "Other" : "Ander",
+    "Group" : "Groep",
     "Do not disturb" : "Moenie pla nie",
     "Away" : "Weg",
     "Default" : "Verstek",
