@@ -15,8 +15,6 @@ OC.L10N.register(
     "Other activities" : "Andre aktiviteter",
     "Talk" : "Snak",
     "Guest" : "Gæst",
-    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Velkommen til Nextcloud Talk!\nI denne samtale finder du information om nye features tilgængelige i Nextcloud Talk.",
-    "New in Talk %s" : "Nyt i Snak %s",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge og Safari kan nu benyttes til at deltage i lyd- og videosamtaler",
     "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-til-en-samtaler er nu vedvarende og kan ikke længere omdannes til gruppesamtaler ved et uheld. Også når en af deltagerne forlader samtalen, slettes samtalen ikke automatisk længere. Kun hvis begge deltagere forlader, slettes samtalen fra serveren",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- Nu kan nu sende en notifikation til alle deltagere ved at skrive \"@all\" i chatten",
@@ -43,15 +41,12 @@ OC.L10N.register(
     "- A preview of your audio and video is shown before joining a call" : "- En forhåndsvisning af din lyd og video vises, før du deltager i et opkald",
     "- You can now blur your background in the newly designed call view" : "- Du kan nu sløre din baggrund i den nydesignede opkaldsvisning",
     "- Moderators can now assign general and individual permissions to participants" : "- Moderatorer kan nu tildele generelle og individuelle tilladelser til deltagere",
-    "- You can now react to chat message" : "- Du kan nu reagere på chatbeskeden",
     "- In the sidebar you can now find an overview of the latest shared items" : "- I sidebjælken kan du nu finde en oversigt over de seneste delte elementer",
     "- Use a poll to collect the opinions of others or settle on a date" : "- Brug en meningsmåling til at indsamle andres meninger eller afgør en dato",
     "- Configure an expiration time for chat messages" : "- Konfigurer en udløbstid for chatbeskeder",
     "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Start opkald uden at underrette andre i store samtaler. Du kan sende individuelle opkaldsmeddelelser, når opkaldet er startet.",
     "- Send chat messages without notifying the recipients in case it is not urgent" : "- Send chatbeskeder uden at give modtagerne besked, hvis det ikke haster",
-    "There are currently no commands available." : "Der er pt ingen kommandoer tilgængelige.",
-    "The command does not exist" : "Kommandoen findes ikke",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Der opstod en fejl ved kørsel af kommandoen. Bed venligst en administrator om at kigge i logfilerne.",
+    "- Link various items using the new smart-picker by typing a \"/\"" : "- Link forskellige elementer ved at bruge den nye Smart Vælger ved at taste \"/\"",
     "Talk updates ✅" : "Talk-opdateringer ✅",
     "Reaction deleted by author" : "Reaktion slettet af forfatter",
     "{actor} created the conversation" : "{actor} oprettede samtalen",
@@ -66,8 +61,8 @@ OC.L10N.register(
     "{actor} removed the description" : "{actor} fjernede beskrivelsen",
     "You removed the description" : "Du fjernede beskrivelsen",
     "An administrator removed the description" : "En administrator fjernede beskrivelsen",
-    "{actor} started a call" : "{actor} startede et opkald",
     "You started a call" : "Du startede et opkald",
+    "{actor} started a call" : "{actor} startede et opkald",
     "{actor} joined the call" : "{actor} deltog i opkaldet",
     "You joined the call" : "Du forbandt til opkaldet",
     "{actor} left the call" : "{actor} forlod opkaldet",
@@ -84,9 +79,6 @@ OC.L10N.register(
     "{actor} opened the conversation to registered users" : "{actor} åbnede samtalen for registrerede brugere",
     "You opened the conversation to registered users" : "Du åbnede samtalen for registrerede brugere",
     "An administrator opened the conversation to registered users" : "En administrator åbnede samtalen for registrerede brugere",
-    "{actor} opened the conversation to registered and guest app users" : "{actor} åbnede samtalen for registrerede og gæsteapp brugere",
-    "You opened the conversation to registered and guest app users" : "Du åbnede samtalen for registrerede og gæsteapp brugere",
-    "An administrator opened the conversation to registered and guest app users" : "En administrator åbnede samtalen for registrerede og gæsteapp brugere",
     "The conversation is now open to everyone" : "Samtalen er nu åben for alle",
     "{actor} opened the conversation to everyone" : "{actor} åbnede samtalen for alle",
     "You opened the conversation to everyone" : "Du åbnede samtalen for alle",
@@ -122,9 +114,6 @@ OC.L10N.register(
     "{actor} removed you" : "{actor} fjernede dig",
     "An administrator removed you" : "En administrator fjernede dig",
     "An administrator removed {user}" : "En administrator fjernede {user}",
-    "{actor} invited {user}" : "{actor} inviterede {user}",
-    "You invited {user}" : "Du inviterede {user}",
-    "An administrator invited {user}" : "En administrator inviterede {user}",
     "{federated_user} accepted the invitation" : "{federated_user} tog imod invitationen",
     "{actor} removed {federated_user}" : "{actor} fjernede {federated_user}",
     "You removed {federated_user}" : "Du fjernede {federated_user}",
@@ -136,8 +125,6 @@ OC.L10N.register(
     "{actor} removed group {group}" : "{actor} fjernede gruppen {group}",
     "You removed group {group}" : "Du fjernede gruppen {group}",
     "An administrator removed group {group}" : "En administrator fjernede gruppen {group}",
-    "{actor} added circle {circle}" : "{actor} tilføjede cirklen {circle}",
-    "You added circle {circle}" : "Du tilføjede cirklen {circle}",
     "{actor} promoted {user} to moderator" : "{actor} forfremmede {user} til moderator",
     "You promoted {user} to moderator" : "Du forfremmede {user} til moderator",
     "{actor} promoted you to moderator" : "{actor} forfremmede dig til moderator",
@@ -147,13 +134,9 @@ OC.L10N.register(
     "{actor} shared a file which is no longer available" : "{actor} delte en fil, der ikke længere er tilgængelig",
     "You shared a file which is no longer available" : "Du delte en fil, der ikke længere er tilgængelig",
     "You cleared the history of the conversation" : "Du ryddede samtalens historik",
+    "Message deleted by author" : "Beskeden er slettet af forfatteren",
     "%s (guest)" : "%s (gæst)",
     "You missed a call from {user}" : "Du missede et opkald fra {user}",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Opkald med 1 gæst (Varighed {duration})","Opkald med %n gæster (Varighed {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Opkald med {user1} og {user2} (Varighed {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Opkald med {user1}, {user2} og {user3} (Varighed {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Opkald med {user1}, {user2}, {user3} og {user4} (Varighed {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Opkald med {user1}, {user2}, {user3}, {user4} og {user5} (Varighed {duration})",
     "Talk conversations" : "Snak samtaler",
     "Talk to %s" : "Tal med %s",
     "File is not shared, or shared but not with the user" : "Filen er ikke delt, eller den er delt men ikke med brugeren",
@@ -162,6 +145,8 @@ OC.L10N.register(
     "Invalid image" : "Ugyldigt billede",
     "Unknown filetype" : "Ukendt filtype",
     "Talk mentions" : "Snak samtaler",
+    "Say hi to your friends and colleagues!" : "Sig hej til dine venner og kollegaer.",
+    "No unread mentions" : "Ingen ulæste samtaler",
     "Call in progress" : "Opkald i gang",
     "Write to conversation" : "Skriv til samtale",
     "Writes event information into a conversation of your choice" : "Skriver begivenhedsinformation i en samtale du vælger",
@@ -174,6 +159,8 @@ OC.L10N.register(
     "Private conversation" : "Privat samtale",
     "Deleted user (%s)" : "Slettet bruger (%s)",
     "Dismiss notification" : "Fjern notifikation",
+    "Accept" : "Accepter",
+    "Decline" : "Afvis",
     "{user} sent you a private message" : "{user} sendte dig en privat besked",
     "{user} sent a message in conversation {call}" : "{user} sendte en besked i samtalen {call}",
     "A deleted user sent a message in conversation {call}" : "En slettet bruger sendte en besked i samtalen {call}",
@@ -202,11 +189,13 @@ OC.L10N.register(
     "Someone is requesting the password to access {file}" : "Nogen beder om adgangskoden til {file}",
     "Someone tried to request the password to access {file}" : "Nogen forsøgte at bede om adgangskoden til {file}",
     "Open settings" : "Indstillinger",
+    "error" : "fejl",
     "Conversations" : "Samtaler",
     "Messages" : "Beskeder",
     "Avatar image is not square" : "Avatar billedet er ikke kvadratisk",
     "Andorra" : "Andorra",
     "Afghanistan" : "Afghanistan",
+    "Anguilla" : "Anguilla",
     "Albania" : "Albanien",
     "Armenia" : "Armenien",
     "Angola" : "Angola",
@@ -221,10 +210,12 @@ OC.L10N.register(
     "Bermuda" : "Bermuda",
     "Brazil" : "Brasilien",
     "Bahamas" : "Bahamas",
+    "Botswana" : "Botswana",
     "Canada" : "Canada",
     "Chile" : "Chile",
     "China" : "Kina",
     "Cuba" : "Cuba",
+    "Cyprus" : "Cypern",
     "Germany" : "Tyskland",
     "Denmark" : "Danmark",
     "Algeria" : "Algeriet",
@@ -242,6 +233,8 @@ OC.L10N.register(
     "Guinea" : "Guinea",
     "Greece" : "Grækenland",
     "Guatemala" : "Guatemala",
+    "Guinea-Bissau" : "Guinea-Bissau",
+    "Guyana" : "Guyana",
     "Hong Kong" : "Hong Kong",
     "Honduras" : "Honduras",
     "Croatia" : "Kroatien",
@@ -257,10 +250,18 @@ OC.L10N.register(
     "Jamaica" : "Jamaica",
     "Japan" : "Japan",
     "Kenya" : "Kenya",
+    "Comoros" : "Comoros",
     "Kuwait" : "Kuwait",
     "Liechtenstein" : "Liechtenstein",
+    "Liberia" : "Liberia",
+    "Lesotho" : "Lesotho",
+    "Lithuania" : "Litauen",
     "Luxembourg" : "Luxembourg",
+    "Libya" : "Libyen",
+    "Morocco" : "Marokko",
     "Montenegro" : "Montenegro",
+    "Myanmar" : "Myanmar",
+    "Malaysia" : "Malaysia",
     "Namibia" : "Namibia",
     "Norway" : "Norge",
     "Nepal" : "Nepal",
@@ -270,10 +271,14 @@ OC.L10N.register(
     "Peru" : "Peru",
     "Pakistan" : "Pakistan",
     "Poland" : "Polen",
+    "Pitcairn" : "Pitcairn",
     "Portugal" : "Portugal",
+    "Paraguay" : "Paraguay",
     "Qatar" : "Qatar",
     "Romania" : "Rumænien",
+    "Serbia" : "Serbien",
     "Rwanda" : "Rwanda",
+    "Seychelles" : "Seychellerne",
     "Sudan" : "Sudan",
     "Sweden" : "Sverige",
     "Singapore" : "Singapore",
@@ -285,15 +290,17 @@ OC.L10N.register(
     "Thailand" : "Thailand",
     "Tunisia" : "Tunesien",
     "Turkey" : "Tyrkiet",
+    "Trinidad and Tobago" : "Trinidad og Tobago",
     "Ukraine" : "Ukraine",
     "Uganda" : "Uganda",
+    "Vanuatu" : "Vanuatu",
     "Samoa" : "Samoa",
     "Yemen" : "Yemen",
     "South Africa" : "Sydafrika",
     "Zimbabwe" : "Zimbabwe",
+    "Federation" : "Datafællesskab",
     "Invalid date, date format must be YYYY-MM-DD" : "Ugyldig dato. Brug formatet ÅÅÅ-MM-DD",
     "Conversation not found" : "Samtalen blev ikke fundet",
-    "Path is already shared with this room" : "Stien er allerede delt med dette rum",
     "Chat, video & audio-conferencing using WebRTC" : "Chat, video- & lyd-samtaler over WebRTC",
     "Leave call" : "Forlad opkald",
     "Discuss this file" : "Diskuter denne fil",
@@ -313,18 +320,13 @@ OC.L10N.register(
     "Save changes" : "Gem ændringer",
     "Saving …" : "Gemmer…",
     "Saved!" : "Gemt!",
-    "Commands" : "Kommandoer",
-    "Beta" : "Beta",
+    "State" : "Tilstand",
     "Name" : "Navn",
-    "Command" : "Kommando",
-    "Script" : "Script",
-    "Response to" : "Svar til",
-    "Enabled for" : "Aktiveret for",
-    "None" : "Ingen",
-    "User" : "ruger",
+    "Description" : "Beskrivelse",
+    "Enabled" : "Aktiveret",
     "Disabled" : "Deaktiveret",
-    "Moderators" : "Moderatorer",
-    "Users" : "Brugere",
+    "Beta" : "Beta",
+    "Permissions" : "Rettigheder",
     "General settings" : "Generelle indstillinger",
     "Default notification settings" : "Standardindstillinger for notifikationer",
     "Default group notification" : "Standardindstillinger for gruppenotifikation",
@@ -356,12 +358,14 @@ OC.L10N.register(
     "TURN server protocols" : "TURN server protokoller ",
     "Test this server" : "Test denne server",
     "TURN servers" : "TURN-servere",
+    "Failed" : "Mislykkede",
     "OK" : "OK",
     "Checking …" : "Tjekker...",
+    "Federated user" : "Fødereret bruger",
     "Back" : "Tilbage",
+    "Cancel" : "Annuller",
     "Confirm" : "Bekræft",
     "Reset" : "Nulstil",
-    "Cancel" : "Annuller",
     "Copy link" : "Kopier link",
     "Connecting …" : "Forbinder ...",
     "Waiting for others to join the call …" : "Venter på andre tilslutter sig opkaldet ...",
@@ -380,17 +384,24 @@ OC.L10N.register(
     "You need to be logged in to upload files" : "Du skal være logget ind for at kunne uploade filer",
     "Drop your files to upload" : "Drop dine filer for at uploade",
     "Favorite" : "Foretrukken",
-    "Description" : "Beskrivelse",
+    "Hide details" : "Skjul detaljer",
+    "Show details" : "Vis detaljer",
+    "Date:" : "Dato:",
+    "Disable" : "Deaktiver",
+    "Enable" : "Aktiver",
+    "The file must be a PNG or JPG" : "Fil format: PNG eller JPG",
+    "Choose" : "Vælg",
     "Restricted" : "Begrænset",
     "Conversation settings" : "Samtale indstillinger",
     "Personal" : "Personlig",
     "Meeting" : "Møde",
-    "Permissions" : "Rettigheder",
     "Danger zone" : "Farezone",
+    "Archive conversation" : "Arkiv samtale",
     "Leave conversation" : "Forlad samtale",
+    "You can archive this conversation instead." : "Du kan arkivere denne samtale i stedet for.",
     "Delete conversation" : "Slet samtale",
+    "Do you really want to leave \"{displayName}\"?" : "Vil du virkelig forlade \"{displayName}\"?",
     "Do you really want to delete \"{displayName}\"?" : "Er du sikker på at du vil slette \"{displayName}\"?",
-    "Submit" : "Tilføj",
     "Password protection" : "Adgangskodebeskyttelse",
     "Copy conversation link" : "Kopier samtalelink",
     "Start time (optional)" : "Starttid (valgfri)",
@@ -398,74 +409,76 @@ OC.L10N.register(
     "Edit" : "Rediger",
     "More information" : "Mere information",
     "Delete" : "Slet",
-    "Password" : "Password",
-    "API token" : "API nøgle",
-    "Login" : "Login",
-    "Nickname" : "Kaldenavn",
-    "Client ID" : "Klient-ID",
+    "Log content" : "Log indhold",
     "Notifications" : "Notifikationer",
+    "Login" : "Login",
     "Mark as read" : "Marker som læst",
     "Mark as unread" : "Marker som ulæst",
     "Remove from favorites" : "Fjernet fra favoritter",
     "Add to favorites" : "Føj til favoritter",
-    "You: {lastMessage}" : "Dig: {lastMessage}",
-    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "Unarchive conversation" : "Fjern samtale fra arkiv",
     "You need to promote a new moderator before you can leave the conversation." : "Du skal udnævne en ny moderator før du kan forlade samtalen.",
-    "Loading" : "Indlæser",
-    "No search results" : "Ingen søgeresultater",
+    "Clear filter" : "Ryd filter",
+    "Users" : "Brugere",
     "Groups" : "Grupper",
-    "Circles" : "Cirkler",
+    "Teams" : "Teams",
+    "No search results" : "Ingen søgeresultater",
+    "Loading" : "Indlæser",
+    "Back to conversations" : "Tilbage til samtaler",
+    "Archived conversations" : "Arkiverede samtaler",
     "Talk settings" : "Snak indstillinger",
-    "Groups and circles" : "Grupper og cirkler",
+    "You have no archived conversations." : "Du har ingen arkiverede samtaler.",
     "Other sources" : "Andre kilder",
     "An error occurred while performing the search" : "Der opstod en fejl under søgningen",
-    "Create a new group conversation" : "Opret en ny gruppesamtale",
-    "Allow guests to join via link" : "Tillad gæster at deltage via link",
-    "Password protect" : "Beskyt med adgangskode",
-    "Creating your conversation" : "Opret din samtale",
-    "All set" : "Samtalen er klar",
-    "Error while creating the conversation" : "Fejl under oprettelse af samtalen",
-    "Create conversation" : "Opret samtale",
-    "Add participants" : "Tilføj deltagere",
-    "Close" : "Luk",
-    "Search participants" : "Find deltagere",
-    "Conversation name" : "Samtalenavn",
     "You are currently waiting in the lobby" : "Du venter nu i lobbyen",
+    "Select a device" : "Vælg en enhed",
+    "None" : "Ingen",
     "Devices" : "Enhed",
-    "Done" : "Færdig",
     "No audio" : "Ingen lyd",
     "No camera" : "Intet kamera",
     "Upload" : "Send",
     "Files" : "Filer",
-    "File to share" : "Vælg fil til deling",
+    "Select a file" : "Vælg en fil",
     "Invalid path selected" : "Ugyldig filsti valgt",
     "Unread messages" : "Ulæste beskedder",
     "Message sent" : "Beskeden blev sendt",
-    "The message has been forwarded to {selectedConversationName}" : "Beskeden er videresendt til {selectedConversationName}",
-    "Dismiss" : "Afvis",
-    "Forward message" : "Videresend besked",
-    "Choose a conversation to forward the selected message." : "Vælg en samtale at videresende den valgte besked til.",
-    "Error while forwarding message" : "Der opstod en fejl ved videresendelse af beskeden.",
     "Reply" : "Besvar",
+    "Set reminder" : "Sæt påmindelse",
     "Reply privately" : "Svar privat",
     "Copy message link" : "Kopier besked link",
     "Go to file" : "Gå til fil",
+    "Forward message" : "Videresend besked",
     "Translate" : "Oversæt",
+    "The message has been forwarded to {selectedConversationName}" : "Beskeden er videresendt til {selectedConversationName}",
+    "Dismiss" : "Afvis",
+    "Choose a conversation to forward the selected message." : "Vælg en samtale at videresende den valgte besked til.",
+    "Error while forwarding message" : "Der opstod en fejl ved videresendelse af beskeden.",
     "Contact" : "Kontakt",
     "No messages" : "Ingen beskeder",
     "Today" : "I dag",
     "Yesterday" : "I går",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dage siden"],
+    "Search participants" : "Find deltagere",
+    "Create a new group conversation" : "Opret en ny gruppesamtale",
+    "Create conversation" : "Opret samtale",
+    "Add participants" : "Tilføj deltagere",
+    "Close" : "Luk",
+    "Error while creating the conversation" : "Fejl under oprettelse af samtalen",
+    "Allow guests to join via link" : "Tillad gæster at deltage via link",
+    "Password protect" : "Beskyt med adgangskode",
     "Add emoji" : "Tilføj emoji",
+    "File to share" : "Vælg fil til deling",
     "Send message" : "Send besked",
-    "Write message, @ to mention someone …" : "Skriv besked, brug @ for at nævne en bruger ...",
-    "Group" : "Gruppe",
     "Upload from device" : "Upload fra enhed",
     "Create new poll" : "Opret ny afstemning",
+    "Smart picker" : "Smart Vælger",
     "Share from {nextcloud}" : "Del fra {nextcloud}",
+    "Share from Files" : "Del fra Filer",
     "New file" : "Ny fil",
     "Blank" : "Tom",
     "Settings" : "Indstillinger",
+    "Anonymous poll" : "Anonym afstemning",
     "Create poll" : "Opret afstemning",
     "Send" : "Send",
     "Join" : "Deltag",
@@ -473,32 +486,36 @@ OC.L10N.register(
     "guest" : "Gæst",
     "Demote from moderator" : "Degrader fra moderator",
     "Promote to moderator" : "Forfrem til moderator",
-    "Remove participant" : "Fjern deltager",
+    "Remove" : "Fjern",
     "Settings for participant \"{user}\"" : "Indstillinger for deltager \"{user}\"",
+    "Remove participant" : "Fjern deltager",
+    "Add users" : "Tilføj brugere",
     "Add groups" : "Tilføj grupper",
     "Add emails" : "Tilføj emails",
-    "Add circles" : "Tilføj cirkler",
     "Integrations" : "Integrationer",
     "Searching …" : "Søger ...",
     "No results" : "Ingen resultater",
     "Add users or groups" : "Add users or groups",
-    "Add groups or circles" : "Tilføj grupper eller cirkler",
     "Add other sources" : "Tilføj andre kilder",
     "Participants" : "Deltagere",
     "Chat" : "Chat",
     "Details" : "Detaljer",
+    "Open chat" : "Åbn chat",
     "Projects" : "Projekter",
-    "Show all files" : "Vis alle filer",
     "Search conversations or users" : "Søg samtaler eller kontakter",
     "Select conversation" : "Vælg samtale",
     "Link to a conversation" : "Link til samtale",
+    "Edit display name" : "Redigér vist navn",
     "Choose devices" : "Vælg enheder",
+    "Turn off camera and microphone by default when joining a call" : "Sluk kamera og mikrofon som standard, når du deltager i et opkald",
     "Attachments folder" : "Mappe til vedhæftede filer",
+    "Select location for attachments" : "Select location for attachments",
     "Privacy" : "Privatliv",
     "Share my read-status and show the read-status of others" : "Del min læsestatus og vis andres læsestatus",
     "Sounds" : "Lyde",
     "Play sounds when participants join or leave a call" : "Afspil lyde, når deltagere tilslutter sig eller forlader et opkald",
     "Sounds for chat and call notifications can be adjusted in the personal settings." : "Lyde til chat og opkaldsmeddelelser kan justeres i de personlige indstillinger.",
+    "Performance" : "Ydelse",
     "Keyboard shortcuts" : "Tastaturgenveje",
     "Speed up your Talk experience with these quick shortcuts." : "Optimer din Talk-oplevelse med disse tastaturgenveje.",
     "Focus the chat input" : "Fokuser chat funktionen",
@@ -511,11 +528,11 @@ OC.L10N.register(
     "Push to talk or push to mute" : "Tryk for at tale eller tryk for at slå lyden fra",
     "Raise or lower hand" : "Løft eller sænk hånden",
     "Choose the folder in which attachments should be saved." : "Vælg den mappe, hvori vedhæftede filer skal gemmes.",
-    "Select location for attachments" : "Select location for attachments",
     "Error while setting attachment folder" : "Fejl under indstilling af mappe til vedhæftninger",
+    "Your default media state has been saved" : "Din standard medietilstand er blevet gemt",
+    "Error while setting default media state" : "Din standard medietilstand er blevet gemt",
     "Start call" : "Start opkald",
-    "Open sidebar" : "Åbn sidebar",
-    "Open chat" : "Åbn chat",
+    "Now" : "Nu",
     "Show your screen" : "Vis din skærm",
     "Stop screensharing" : "Stop skærmdeling",
     "Screensharing options" : "Skærmdeling indstillinger",
@@ -528,24 +545,32 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
     "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
     "Grid view" : "Grid visning",
-    "No unread mentions" : "Ingen ulæste samtaler",
-    "Say hi to your friends and colleagues!" : "Sig hej til dine venner og kollegaer.",
-    "Start a conversation" : "Start en samtale",
+    "Select a region" : "Vælg en region",
+    "Submit" : "Tilføj",
     "Message without mention" : "Besked som ikke nævner nogen",
     "Mention myself" : "Nævn mig selv",
-    "Mention room" : "Nævn rum",
     "The conversation does not exist" : "Samtalen findes ikke",
     "Join a conversation or start a new one!" : "Deltag i en samtale eller start en ny!",
     "Join a conversation or start a new one" : "Deltag i en samtale eller start en ny",
-    "An error occurred while fetching the participants" : "Kunne ikke hente listen over deltagere",
+    "User" : "ruger",
+    "Password" : "Password",
+    "API token" : "API nøgle",
+    "Nickname" : "Kaldenavn",
+    "Client ID" : "Klient-ID",
     "Media" : "Medier",
     "Polls" : "Afstemning",
     "Locations" : "Sted",
     "Audio" : "Audio",
     "Other" : "Andet",
+    "Show all files" : "Vis alle filer",
+    "Group" : "Gruppe",
+    "You: {lastMessage}" : "Dig: {lastMessage}",
+    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "Error while sharing file" : "Fejl ved deling af fil",
+    "An error occurred while fetching the participants" : "Kunne ikke hente listen over deltagere",
+    "Error while parsing a PROPFIND error" : "Fejl under parsing af en PROPFIND-fejl",
     "Do not disturb" : "Forstyr ikke",
     "Away" : "Ikke tilstede",
-    "Error while sharing file" : "Fejl ved deling af fil",
     "Default" : "Standard",
     "You seem to be talking while muted, please unmute yourself for others to hear you" : "Det virker som om du snakker mens lyden er slået fra, slå den til hvis du vil have at andre skal høre dig",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Dette tager lidt længere end forventet. Er medie-rettigheder allerede givet (eller nægtet)? Hvis ja så prøv at genstarte din browser, for lyd og video virker ikke lige nu",
@@ -556,23 +581,35 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Benyt venligst en anden browser f.eks. Firefox eller Chrome",
     "Error while accessing microphone & camera" : "Der opstod en fejl da vi prøvede at få adgang til din mikrofon og kamera",
     "The password is wrong. Try again." : "Passwordet er forkert. Prøv igen.",
-    "Specify commands the users can use in chats" : "Definer kommandoer brugerne kan bruge i chats",
-    "TURN server" : "TURN server",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveren bliver brugt til at proxy trafikken fra deltagerne bagved en firewall.",
-    "Signaling servers" : "Signaleringsservere",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaleringsserver kan eventuelt bruges i større installationer. Efterlad tom for at bruge intern signaleringsserver.",
     "%s Talk on your mobile devices" : "%s Talk på dine mobilenheder",
     "Join conversations at any time, anywhere, on any device." : "Deltag i samtaler når som helst, hvor som helst og på en hvilken som helst enhed.",
     "Android app" : "Android app",
     "iOS app" : "iOS app",
-    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Observer at i opkald med mere end 4 deltagere uden en ekstern signaleringsserver, kan deltagerne opleve problemer med forbindelsen og det kan skabe høj belastning på deltagernes enheder.",
-    "More actions" : "Flere handlinger",
-    "Conversation link copied to clipboard." : "Samtalelink kopieret til udklipsholder",
-    "The link could not be copied." : "Linket kunne ikke kopieres.",
-    "No matches" : "Ingen matches",
-    "Link copied to the clipboard!" : "Link kopieret til udklipsholderen!",
-    "Sounds can currently not be played in Safari browser and iPad and iPhone devices due to technical restrictions by the manufacturer." : "Lyde kan i øjeblikket ikke afspilles i Safari-browseren og iPad- og iPhone-enheder på grund af tekniske begrænsninger fra producenten.",
-    "Rename conversation" : "Omdøb samtale",
-    "Sending signaling message has failed." : "Kunne ikke sende signalerings-besked"
+    "There are currently no commands available." : "Der er pt ingen kommandoer tilgængelige.",
+    "The command does not exist" : "Kommandoen findes ikke",
+    "An error occurred while running the command. Please ask an administrator to check the logs." : "Der opstod en fejl ved kørsel af kommandoen. Bed venligst en administrator om at kigge i logfilerne.",
+    "{actor} added circle {circle}" : "{actor} tilføjede cirklen {circle}",
+    "You added circle {circle}" : "Du tilføjede cirklen {circle}",
+    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Opkald med 1 gæst (Varighed {duration})","Opkald med %n gæster (Varighed {duration})"],
+    "Call with {user1} and {user2} (Duration {duration})" : "Opkald med {user1} og {user2} (Varighed {duration})",
+    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Opkald med {user1}, {user2} og {user3} (Varighed {duration})",
+    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Opkald med {user1}, {user2}, {user3} og {user4} (Varighed {duration})",
+    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Opkald med {user1}, {user2}, {user3}, {user4} og {user5} (Varighed {duration})",
+    "Commands" : "Kommandoer",
+    "Command" : "Kommando",
+    "Script" : "Script",
+    "Response to" : "Svar til",
+    "Enabled for" : "Aktiveret for",
+    "Moderators" : "Moderatorer",
+    "Circles" : "Cirkler",
+    "Groups and circles" : "Grupper og cirkler",
+    "Add circles" : "Tilføj cirkler",
+    "Add groups or circles" : "Tilføj grupper eller cirkler",
+    "Start a conversation" : "Start en samtale",
+    "Specify commands the users can use in chats" : "Definer kommandoer brugerne kan bruge i chats",
+    "TURN server" : "TURN server",
+    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveren bliver brugt til at proxy trafikken fra deltagerne bagved en firewall.",
+    "Signaling servers" : "Signaleringsservere",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaleringsserver kan eventuelt bruges i større installationer. Efterlad tom for at bruge intern signaleringsserver."
 },
 "nplurals=2; plural=(n != 1);");
