@@ -4,6 +4,7 @@ OC.L10N.register(
     "Other activities" : "Alia aktivado",
     "Talk" : "Paroli",
     "Guest" : "Gasto",
+    "Message deleted by author" : "Mesaĝo estas forigita per aǔtoro",
     "Talk conversations" : "Buŝaj konversacioj",
     "Talk to %s" : "Paroli al %s",
     "File is too big" : "Dosiero tro grandas",
@@ -11,6 +12,9 @@ OC.L10N.register(
     "Invalid image" : "Nevalida bildo",
     "Unknown filetype" : "Nekonata dosiertipo",
     "Dismiss notification" : "Forsendi sciigon",
+    "Accept" : "Akcepti",
+    "Decline" : "Malakcepti",
+    "error" : "eraro",
     "Avatar image is not square" : "Avatarbildo ne estas kvadrata",
     "Andorra" : "Andoro",
     "United Arab Emirates" : "Unuiĝintaj Arabaj Emirlandoj",
@@ -248,18 +252,17 @@ OC.L10N.register(
     "South Africa" : "Sud-Afriko",
     "Zambia" : "Zambio",
     "Zimbabwe" : "Zimbabvo",
+    "Federation" : "Federado",
     "Invalid date, date format must be YYYY-MM-DD" : "Nevalida dato; datoformo estu JJJJ-MM-TT",
     "Limit to groups" : "Limigi al grupoj",
     "Everyone" : "Ĉiuj",
     "Save changes" : "Konservi ŝanĝojn",
     "Saving …" : "Konservado...",
     "Saved!" : "Konservita!",
-    "Beta" : "Beta",
     "Name" : "Nomo",
-    "None" : "Nenio",
-    "User" : "Uzanto",
+    "Description" : "Priskribo",
     "Disabled" : "Malŝaltita",
-    "Users" : "Uzantoj",
+    "Beta" : "Beta",
     "Language" : "Lingvo",
     "Country" : "Lando",
     "Status" : "Stato",
@@ -270,66 +273,80 @@ OC.L10N.register(
     "Expired" : "Senvalidiĝis",
     "OK" : "Bone",
     "Back" : "Antaŭen",
+    "Cancel" : "Nuligi",
     "Confirm" : "Konfirmi",
     "Reset" : "Restarigi",
-    "Cancel" : "Nuligi",
     "Copy link" : "Kopii ligilon",
     "You" : "Vi",
     "Collapse" : "Maletendi",
     "Favorite" : "Pliŝatata",
-    "Description" : "Priskribo",
+    "Loading …" : "Ŝargado...",
+    "Hide details" : "Kaŝi la detalojn",
+    "Show details" : "Montri la detalojn",
+    "Date:" : "Dato:",
+    "Disable" : "Malŝalti",
+    "Enable" : "Ŝalti",
+    "Choose" : "Elekti",
     "Restricted" : "Limigita",
     "Personal" : "Persona",
-    "Submit" : "Sendi",
+    "No" : "Ne",
+    "Yes" : "Jes",
     "Password protection" : "Protektita per pasvorto",
     "Save" : "Konservi",
     "Edit" : "Modifi",
     "Delete" : "Forigi",
-    "Password" : "Pasvorto",
-    "API token" : "API-ĵetono",
-    "Login" : "Login",
-    "Nickname" : "Kromnomo",
-    "Client ID" : "Klientidentigilo",
+    "Log content" : "Protokolenhavo",
     "Notifications" : "Sciigoj",
+    "Login" : "Login",
     "Remove from favorites" : "Forigi el pliŝataĵoj",
     "Add to favorites" : "Aldoni al pliŝataĵoj",
-    "Loading" : "Ŝargado",
+    "Users" : "Uzantoj",
     "Groups" : "Grupoj",
-    "Circles" : "Rondoj",
-    "Password protect" : "Protekti per pasvorto",
-    "Close" : "Malfermi",
+    "Loading" : "Ŝargado",
+    "None" : "Nenio",
     "Devices" : "Aparatoj",
-    "Done" : "Farita",
     "Upload" : "Alŝuti",
     "Files" : "Dosieroj",
-    "Dismiss" : "Preterpasi",
     "Reply" : "Respondi",
     "Translate" : "Traduku",
+    "Dismiss" : "Preterpasi",
     "Contact" : "Kontakto",
     "Today" : "Hodiaŭ",
     "Yesterday" : "Hieraŭ",
-    "Group" : "Grupo",
+    "_%n day ago_::_%n days ago_" : ["antaŭ %n tago","antaŭ %n tagoj"],
+    "Close" : "Malfermi",
+    "Password protect" : "Protekti per pasvorto",
     "Create new poll" : "Krei novan enketon",
     "Settings" : "Agordoj",
+    "Anonymous poll" : "Enketo sennoma",
     "Send" : "Sendi",
     "Join" : "Aliĝi",
     "guest" : "gasto",
+    "Searching …" : "Serĉado ...",
     "No results" : "Neniu rezulto",
     "Add users or groups" : "Add users or groups",
     "Chat" : "Babili",
     "Details" : "Detaloj",
     "Privacy" : "Privateco",
+    "Performance" : "Rendimento",
     "Keyboard shortcuts" : "Fulmoklavoj",
     "Search" : "Serĉi",
-    "Open sidebar" : "Malfermi flankopanelon",
     "Grid view" : "Krada vido",
+    "Select a region" : "Elekti regionon",
+    "Submit" : "Sendi",
+    "User" : "Uzanto",
+    "Password" : "Pasvorto",
+    "API token" : "API-ĵetono",
+    "Nickname" : "Kromnomo",
+    "Client ID" : "Klientidentigilo",
     "Polls" : "Enketilo",
     "Audio" : "Sonaĵo",
     "Other" : "Alia",
+    "Group" : "Grupo",
     "Default" : "Defaŭlta",
     "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
     "Android app" : "Android-aplikaĵo",
     "iOS app" : "iOS-aplikaĵo",
-    "More actions" : "Pliaj agoj"
+    "Circles" : "Rondoj"
 },
 "nplurals=2; plural=(n != 1);");
