@@ -2,27 +2,34 @@ OC.L10N.register(
     "spreed",
     {
     "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados","%n inivitados"],
+    "Talk" : "Hablar",
     "Guest" : "Invitado",
+    "Message deleted by author" : "Mensaje eliminado por el autor",
     "File is too big" : "El archivo es demasiado grande.",
     "Invalid file provided" : "Archivo proporcionado inválido",
     "Invalid image" : "Imagen inválida",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Dismiss notification" : "Eliminar notificación",
+    "Accept" : "Aceptar",
+    "Decline" : "Declinar",
     "Open settings" : "Abrir opciones",
+    "error" : "error",
     "Messages" : "Mensajes",
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
+    "Federation" : "Federación",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
     "Limit to groups" : "Limitar a grupos",
     "Everyone" : "Todos",
     "Save changes" : "Guardar cambios",
     "Saved!" : "¡Guardado!",
-    "Beta" : "Beta",
+    "State" : "Estado",
     "Name" : "Nombre",
-    "None" : "Ninguno",
-    "User" : "Usuario",
+    "Description" : "Descripción",
+    "Enabled" : "Habilitado",
     "Disabled" : "Deshabilitado",
-    "Users" : "Ususarios",
+    "Beta" : "Beta",
+    "Permissions" : "Permisos",
     "General settings" : "Configuraciones generales",
     "Off" : "Apagado",
     "Language" : "Idioma",
@@ -33,11 +40,12 @@ OC.L10N.register(
     "Error" : "Error",
     "Blocked" : "Bloqueado",
     "TURN server protocols" : "Protocolos del servidor TURN",
+    "Failed" : "Error",
     "OK" : "OK",
     "Back" : "Atrás",
+    "Cancel" : "Cancelar",
     "Confirm" : "Confirmar",
     "Reset" : "Restablecer",
-    "Cancel" : "Cancelar",
     "Copy link" : "Copiar enlace",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "Mute audio" : "Silenciar audio",
@@ -45,47 +53,47 @@ OC.L10N.register(
     "You" : "Usted",
     "Collapse" : "Colapsar",
     "Favorite" : "Favorito",
-    "Description" : "Descripción",
+    "Hide details" : "Ocultar detalles",
+    "Show details" : "Mostrar detalles",
+    "Disable" : "Deshabilitar",
+    "Enable" : "Activar",
+    "Choose" : "Elige",
     "Restricted" : "Restringido",
     "Personal" : "Personal",
-    "Permissions" : "Permisos",
     "Leave conversation" : "Dejar la conversación",
+    "Yes" : "Sí",
     "Delete conversation" : "Eliminar conversación",
-    "Submit" : "Enviar",
     "Password protection" : "Protección con contraseña",
     "Save" : "Guardar",
     "Edit" : "Editar",
     "More information" : "Más información",
     "Delete" : "Eliminar",
-    "Password" : "Contraseña",
-    "API token" : "Ficha del API",
-    "Login" : "Inicio de sesión",
-    "Nickname" : "Apodo",
-    "Client ID" : "ID del cliente",
+    "Log content" : "Contenido del registro",
     "Notifications" : "Notificaciones",
+    "Login" : "Inicio de sesión",
     "Remove from favorites" : "Eliminado de favoritos",
     "Add to favorites" : "Agregar a favoritos",
-    "Loading" : "Cargando",
+    "Users" : "Ususarios",
     "Groups" : "Grupos",
-    "Circles" : "Círculos",
-    "Password protect" : "Proteger con contraseña",
-    "Close" : "Cerrar",
-    "Conversation name" : "Nombre de conversación",
+    "Loading" : "Cargando",
+    "None" : "Ninguno",
     "Devices" : "Dispositivos",
-    "Done" : "Terminado",
     "Upload" : "Cargar",
     "Files" : "Archivos",
-    "Dismiss" : "Despedir",
     "Reply" : "Responder",
     "Translate" : "Traducir",
+    "Dismiss" : "Despedir",
     "Contact" : "Contacto",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
+    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
+    "Close" : "Cerrar",
+    "Password protect" : "Proteger con contraseña",
     "Send message" : "Enviar mensaje",
-    "Group" : "Grupo",
     "New file" : "Nuevo archivo",
     "Settings" : "Ajustes",
     "Send" : "Enviar",
+    "Remove" : "Eliminar",
     "Searching …" : "Buscando ...",
     "No results" : "Sin resultados",
     "Add users or groups" : "Agregar usuarios o grupos",
@@ -95,7 +103,6 @@ OC.L10N.register(
     "Privacy" : "Privacidad",
     "Keyboard shortcuts" : "Atajos de teclado",
     "Search" : "Buscar",
-    "Open sidebar" : "Abrir barra lateral",
     "Show your screen" : "Mostrar su pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -104,11 +111,17 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome to share your screen." : "Favor de usar un navegador diferente como Firefox o Chrome para compartir su pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Grid view" : "Vista de cuadrícula",
-    "Start a conversation" : "Iniciar una conversación",
+    "Submit" : "Enviar",
+    "User" : "Usuario",
+    "Password" : "Contraseña",
+    "API token" : "Ficha del API",
+    "Nickname" : "Apodo",
+    "Client ID" : "ID del cliente",
     "Media" : "Media",
     "Locations" : "Ubicaciones",
     "Audio" : "Audio",
     "Other" : "Otro",
+    "Group" : "Grupo",
     "Do not disturb" : "No molestar",
     "Away" : "Lejos",
     "Default" : "Predeterminado",
@@ -118,10 +131,11 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Favor de usar un navegador diferente como Firefox o Chrome",
     "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
     "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo.",
-    "TURN server" : "Servidor TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS",
-    "Rename conversation" : "Renombrar conversación"
+    "Circles" : "Círculos",
+    "Start a conversation" : "Iniciar una conversación",
+    "TURN server" : "Servidor TURN",
+    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
