@@ -17,11 +17,15 @@ OC.L10N.register(
     "Invalid file provided" : "Archivo proporcionado inválido",
     "Invalid image" : "Imagen inválida",
     "Unknown filetype" : "Tipo de archivo desconocido",
+    "Accept" : "Aceptar",
+    "Decline" : "Declinar",
     "Join call" : "Unirse a la llamada",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
+    "error" : "error",
     "Conversations" : "Conversaciones",
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
+    "Federation" : "Federación",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
     "This conversation has ended" : "Esta conversación ha terminado",
@@ -30,10 +34,10 @@ OC.L10N.register(
     "Save changes" : "Guardar cambios",
     "Saved!" : "¡Guardado!",
     "Name" : "Nombre",
-    "None" : "Ninguno",
-    "User" : "Usuario",
+    "Description" : "Descripción",
+    "Enabled" : "Habilitado",
     "Disabled" : "Deshabilitado",
-    "Users" : "Usuarios",
+    "Permissions" : "Permisos",
     "General settings" : "Configuraciones generales",
     "Language" : "Idioma",
     "Country" : "País",
@@ -51,9 +55,9 @@ OC.L10N.register(
     "OK" : "OK",
     "Checking …" : "Verificando ...",
     "Back" : "Atrás",
+    "Cancel" : "Cancelar",
     "Confirm" : "Confirmar",
     "Reset" : "Restablecer",
-    "Cancel" : "Cancelar",
     "Copy link" : "Copiar liga",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
@@ -66,43 +70,41 @@ OC.L10N.register(
     "Show screen" : "Mostrar pantalla",
     "Collapse" : "Colapsar",
     "Favorite" : "Hacer favorito",
-    "Description" : "Descripción",
+    "Hide details" : "Ocultar detalles",
+    "Disable" : "Deshabilitar",
+    "Enable" : "Habilitar",
+    "Choose" : "Seleccionar",
     "Restricted" : "Restringido",
     "Personal" : "Personal",
-    "Permissions" : "Permisos",
     "Leave conversation" : "Dejar la conversación",
     "Delete conversation" : "Borrar conversación",
-    "Submit" : "Enviar",
     "Password protection" : "Protección con contraseña",
     "Save" : "Guardar",
     "Edit" : "Editar",
     "Delete" : "Borrar",
-    "Password" : "Contraseña",
-    "API token" : "Ficha del API",
-    "Login" : "Iniciar sesión",
-    "Nickname" : "Apodo",
-    "Client ID" : "ID del cliente",
+    "Log content" : "Contenido de bitácoras",
     "Notifications" : "Notificaciones",
+    "Login" : "Iniciar sesión",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
-    "Loading" : "Cargando",
+    "Users" : "Usuarios",
     "Groups" : "Grupos",
-    "Circles" : "Círculos",
-    "Password protect" : "Proteger con contraseña",
-    "Close" : "Cerrar",
-    "Conversation name" : "Nombre de la conversación",
+    "Loading" : "Cargando",
+    "None" : "Ninguno",
     "Devices" : "Dispositivos",
     "No audio" : "Sin audio",
     "Upload" : "Cargar",
     "Files" : "Archivos",
-    "Dismiss" : "Descartar",
     "Reply" : "Responder",
     "Translate" : "Traducir",
+    "Dismiss" : "Descartar",
     "Contact" : "Contacto",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Group" : "Grupo",
+    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
+    "Close" : "Cerrar",
+    "Password protect" : "Proteger con contraseña",
     "Create new poll" : "Crear nueva encuesta",
     "Settings" : "Configuraciones ",
     "Create poll" : "Crear encuesta",
@@ -129,10 +131,17 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
     "Grid view" : "Vista de cuadrícula",
+    "Submit" : "Enviar",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
+    "User" : "Usuario",
+    "Password" : "Contraseña",
+    "API token" : "Ficha del API",
+    "Nickname" : "Apodo",
+    "Client ID" : "ID del cliente",
     "Polls" : "Encuestas",
     "Audio" : "Audio",
     "Other" : "Otro",
+    "Group" : "Grupo",
     "Away" : "Lejos",
     "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
@@ -142,12 +151,11 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
     "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
     "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
-    "TURN server" : "Servidor TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
     "Android app" : "Aplicación Android",
     "iOS app" : "Aplicación iOS",
-    "More actions" : "Más acciones",
-    "Rename conversation" : "Renombrar conversación"
+    "Circles" : "Círculos",
+    "TURN server" : "Servidor TURN",
+    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
