@@ -9,23 +9,19 @@ OC.L10N.register(
     "You attended a call with {user1}, {user2} and {user3}" : "השתתפת בשיחה עם {user1}, {user2} ועם {user3}",
     "You attended a call with {user1}, {user2}, {user3} and {user4}" : "השתתפת בשיחה עם {user1}, {user2}, {user3} ועם {user4}",
     "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "השתתפת בשיחה עם {user1}, {user2}, {user3}, {user4} ועם {user5}",
-    "_%n other_::_%n others_" : ["מישהו נוסף","%n נוספים","%n נוספים","%n נוספים"],
+    "_%n other_::_%n others_" : ["מישהו נוסף","%n נוספים","%n נוספים"],
     "{actor} invited you to {call}" : "הוזמנת אל {call} על ידי {actor}",
     "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "הוזמנת ל<strong>דיון</strong> או שקיבלת <strong>שיחה</strong>",
     "Other activities" : "פעילויות אחרות",
     "Talk" : "שיחה",
     "Guest" : "אורח/ת",
-    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "ברוך בואך ל־Talk מבית Nextcloud!\nבדיון הזה נעדכן אותך בנוגע לתכונות החדשות שזמינות ב־Talk מבית Nextcloud.",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- ניתן מעתה להשתמש ב־Microsoft Edge וב־Safari כדי להשתת, בשיחות שמע ווידאו",
-    "There are currently no commands available." : "אין פקודות זמינות.",
-    "The command does not exist" : "הפקודה לא קיימת",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "אירעה שגיאה בעת הפעלת הפקודה. נא לבקש מהנהלת המערכת לבדוק את יומן התיעוד.",
     "{actor} created the conversation" : "הדיון נוצר על ידי {actor}",
     "You created the conversation" : "יצרת את הדיון",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "השם של הדיון השתנה מ־„%1$s” ל־„%2$s” על ידי {actor}",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "שינית את שם הדיון מהשם „%1$s” לשם „%2$s”",
-    "{actor} started a call" : "שיחה החלה על ידי {actor}",
     "You started a call" : "התחלת שיחה",
+    "{actor} started a call" : "שיחה החלה על ידי {actor}",
     "{actor} joined the call" : "{actor} מעכשיו בשיחה",
     "You joined the call" : "הצטרפת לשיחה",
     "{actor} left the call" : "{actor} לא בשיחה עוד",
@@ -66,12 +62,15 @@ OC.L10N.register(
     "You stopped Matterbridge" : "עצרת את Matterbridge",
     "{actor} deleted a message" : "הודעה נמחקה על ידי {actor}",
     "You deleted a message" : "מחקת הודעה",
+    "Message deleted by author" : "ההודעה נמחקה על ידי מי שפרסם אותה",
     "You missed a call from {user}" : "החמצת שיחה עם {user}",
     "Talk conversations" : "דיוני שיח",
     "File is too big" : "הקובץ גדול מדי",
     "Invalid file provided" : "הקובץ שסופק שגוי",
     "Invalid image" : "תמונה לא חוקית",
     "Unknown filetype" : "סוג קובץ לא מוכר",
+    "Say hi to your friends and colleagues!" : "על הדרך לראות מה עם חבריך לעבודה!",
+    "No unread mentions" : "אין אזכורים שלא נקראו",
     "Call in progress" : "מתנהלת שיחה",
     "Conversation invitation" : "הזמנה לדיון",
     "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
@@ -80,6 +79,8 @@ OC.L10N.register(
     "Private conversation" : "דיון פרטי",
     "Deleted user (%s)" : "משתמש שנמחק (%s)",
     "Dismiss notification" : "התעלמות מהתראה",
+    "Accept" : "אשר",
+    "Decline" : "דחייה",
     "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
     "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
     "Join call" : "הצטרפות לשיחה",
@@ -88,9 +89,10 @@ OC.L10N.register(
     "Call back" : "להתקשר בחזרה",
     "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
     "Open settings" : "פתיחת הגדרות",
+    "error" : "שגיאה",
     "Conversations" : "דיונים",
-    "Messages" : "הודעות",
     "{user}" : "{user}",
+    "Messages" : "הודעות",
     "Messages in other conversations" : "הודעות בדיונים אחרים",
     "Avatar image is not square" : "התמונה המייצגת אינה מרובעת",
     "The email address is invalid." : "כתובת הדוא״ל שגויה.",
@@ -334,12 +336,12 @@ OC.L10N.register(
     "South Africa" : "דרום אפריקה",
     "Zambia" : "זמביה",
     "Zimbabwe" : "זימבבואה",
+    "Federation" : "איגוד",
     "Invalid date, date format must be YYYY-MM-DD" : "תאריך לא חוקי, תבנית התאריך חייבת להיות YYYY-MM-DD",
     "Conversation not found" : "הדיון לא נמצא",
     "Navigating away from the page will leave the call in {conversation}" : "ניווט מחוץ לעמוד תנתק את השיחה שב־{conversation}",
     "Leave call" : "יציאה מהשיחה",
     "Stay in call" : "להישאר בשיחה",
-    "Duplicate session" : "שכפול הפעלה",
     "Discuss this file" : "לדון על הקובץ הזה",
     "Share this file with others to discuss it" : "שיתוף הקובץ הזה לדיונם של אחרים",
     "Share this file" : "שיתוף הקובץ הזה",
@@ -356,18 +358,13 @@ OC.L10N.register(
     "Save changes" : "שמירת שינויים",
     "Saving …" : "מתבצעת שמירה…",
     "Saved!" : "נשמר!",
-    "Commands" : "פקודות",
-    "Beta" : "בטא",
+    "State" : "מצב",
     "Name" : "שם",
-    "Command" : "פקודה",
-    "Script" : "סקריפט",
-    "Response to" : "תגובה אל",
-    "Enabled for" : "מופעל עבור",
-    "None" : "אין",
-    "User" : "משתמש",
+    "Description" : "תיאור",
+    "Enabled" : "מופעל",
     "Disabled" : "מושבת",
-    "Moderators" : "מפקחים",
-    "Users" : "משתמשים",
+    "Beta" : "בטא",
+    "Permissions" : "הרשאות",
     "General settings" : "הגדרות כלליות",
     "All messages" : "כל ההודעות",
     "Off" : "כבוי",
@@ -398,9 +395,9 @@ OC.L10N.register(
     "OK" : "אישור",
     "Checking …" : "מתבצעת בדיקה…",
     "Back" : "חזרה",
+    "Cancel" : "ביטול",
     "Confirm" : "אימות",
     "Reset" : "איפוס",
-    "Cancel" : "ביטול",
     "Copy link" : "העתקת קישור",
     "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
     "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
@@ -414,15 +411,21 @@ OC.L10N.register(
     "Collapse" : "קיווץ",
     "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
     "Favorite" : "סימון כמועדף",
-    "Description" : "תיאור",
+    "Loading …" : "בטעינה…",
+    "Hide details" : "הסתרת פרטים",
+    "Show details" : "הצגת פרטים",
+    "Date:" : "בתאריך:",
+    "Note:" : "הערה:",
+    "Disable" : "השבתה",
+    "Choose" : "בחר",
     "Restricted" : "מוגבלת",
     "Conversation settings" : "הגדרות דיון",
     "Personal" : "אישי",
     "Meeting" : "מפגש",
-    "Permissions" : "הרשאות",
     "Leave conversation" : "יציאה מהדיון",
     "Delete conversation" : "מחיקת דיון",
-    "Submit" : "שליחה",
+    "_%n hour_::_%n hours_" : ["שעה","שעתיים","%n שעות"],
+    "_%n day_::_%n days_" : ["יום","יומיים","%n ימים"],
     "Password protection" : "הגנה בססמה",
     "Copy conversation link" : "העתקת קישור דיון",
     "Start time (optional)" : "מועד התחלה (רשות)",
@@ -430,10 +433,119 @@ OC.L10N.register(
     "Edit" : "עריכה",
     "More information" : "מידע נוסף",
     "Delete" : "מחיקה",
+    "Log content" : "תוכן הרישום",
+    "unknown state" : "מצב לא ידוע",
+    "Bridge saved" : "הגישור נשמר",
+    "Notifications" : "התראות",
+    "Enter your name" : "נא למלא את שמך",
+    "Login" : "התחבר",
+    "Mark as read" : "סימון כנקרא",
+    "Mark as unread" : "סימון כלא נקרא",
+    "Remove from favorites" : "הסרה מהמועדפים",
+    "Add to favorites" : "הוספה למועדפים",
+    "Clear filter" : "מחיקת מסנן",
+    "No matches found" : "לא נמצאו התאמות",
+    "Users" : "משתמשים",
+    "Groups" : "קבוצות",
+    "Loading" : "בטעינה",
+    "Other sources" : "מקורות אחרים",
+    "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
+    "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
+    "None" : "אין",
+    "Devices" : "מכשירים",
+    "No audio" : "אין שמע",
+    "Upload" : "העלאה",
+    "Files" : "קבצים",
+    "Invalid path selected" : "הנתיב שנבחר שגוי",
+    "Unread messages" : "הודעות שלא נקראו",
+    "Message sent" : "הודעה נשלחה",
+    "Deleting message" : "ההודעה נמחקה",
+    "Reply" : "תגובה",
+    "Go to file" : "מעבר לקובץ",
+    "Translate" : "תרגום",
+    "Dismiss" : "התעלמות",
+    "Contact" : "איש/אשת קשר",
+    "No messages" : "אין הודעות",
+    "Today" : "היום",
+    "Yesterday" : "מחר",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
+    "Search participants" : "חיפוש משתתפים",
+    "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
+    "Create conversation" : "יצירת דיון",
+    "Add participants" : "הוספת משתתפים",
+    "Close" : "סגירה",
+    "Error while creating the conversation" : "שגיאה ביצירת הדיון",
+    "Password protect" : "הגנה בססמה",
+    "Add emoji" : "הוספת אמוג׳י",
+    "File to share" : "קובץ לשיתוף",
+    "Send message" : "שליחת הודעה",
+    "Share files to the conversation" : "שיתוף קבצים לדיון",
+    "Create new poll" : "יצירת סקר חדש",
+    "Share from Files" : "שיתוף מקבצים",
+    "New file" : "קובץ חדש",
+    "Settings" : "הגדרות",
+    "Anonymous poll" : "סקר אלמוני",
+    "Create poll" : "יצירת סקר",
+    "Send" : "שליחה",
+    "Add more files" : "הוספת קבצים נוספים",
+    "Join" : "הצטרף",
+    "moderator" : "מפקח/ת",
+    "guest" : "אורח",
+    "Demote from moderator" : "הורדה מדרגת פיקוח",
+    "Promote to moderator" : "קידום לדרגת פיקוח",
+    "Remove" : "הסרה",
+    "Remove group and members" : "הסרת קבוצה וחברים",
+    "Remove participant" : "הסרת משתתף",
+    "Add groups" : "הוספת קבוצות",
+    "Add emails" : "הוספת כתובות דוא״ל",
+    "Integrations" : "שילובים",
+    "Searching …" : "מתבצע חיפוש…",
+    "No results" : "אין תוצאות",
+    "Add users or groups" : "הוספת משתמשים או קבוצות",
+    "Add other sources" : "הוספת מקורות אחרים",
+    "Participants" : "משתתפים",
+    "Chat" : "צ׳אט",
+    "Details" : "פרטים",
+    "Projects" : "מיזמים",
+    "Select conversation" : "בחירת דיון",
+    "Link to a conversation" : "קישור לדיון",
+    "Calls are not supported in your browser" : "אין תמיכה בשיחות בדפדפן שלך",
+    "Access to microphone was denied" : "הגישה למיקרופון נדחתה",
+    "Choose devices" : "בחירת התקנים",
+    "Attachments folder" : "תיקיית הקבצים המצורפים",
+    "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
+    "Privacy" : "פרטיות",
+    "Performance" : "ביצועים",
+    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Search" : "חיפוש",
+    "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
+    "Start call" : "התחלת שיחה",
+    "Show your screen" : "הצגת המסך שלך",
+    "Stop screensharing" : "הפסקת שיתוף המסך",
+    "Screensharing options" : "אפשרויות שיתוף מסך",
+    "Enable screensharing" : "הפעלת שיתוף מסך",
+    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
+    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
+    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
+    "Mute others" : "השתקה של אחרים",
+    "Speaker view" : "תצוגת דובר",
+    "Grid view" : "תצוגת טבלה",
+    "Select a region" : "נא לבחור איזור",
+    "Submit" : "שליחה",
+    "Message without mention" : "הודעה ללא אזכור",
+    "Mention myself" : "אזכור עצמי",
+    "The conversation does not exist" : "הדיון לא קיים",
+    "Join a conversation or start a new one!" : "הצטרפות לדיון או ליצור אחד חדש!",
+    "Duplicate session" : "שכפול הפעלה",
+    "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
     "Nextcloud URL" : "כתובת Nextcloud",
     "Nextcloud user" : "משתמש Nextcloud",
     "User password" : "ססמת משתמש",
     "Matrix server URL" : "כתובת שרת Matrix",
+    "User" : "משתמש",
     "Matrix channel" : "ערוץ Matrix",
     "Mattermost server URL" : "כתובת שרת Mattermost",
     "Mattermost user" : "משתמש Mattermost",
@@ -451,7 +563,6 @@ OC.L10N.register(
     "Server ID or name" : "מזהה או שם שרת",
     "Channel ID or name" : "מזהה ערוץ או שם",
     "Channel" : "ערוץ",
-    "Login" : "התחבר",
     "Chat ID" : "מזהה צ׳אט",
     "Nickname" : "כינוי",
     "Connection password" : "ססמת התחברות",
@@ -461,124 +572,16 @@ OC.L10N.register(
     "Thread ID" : "מזהה שרשור",
     "MUC server URL" : "כתובת שרת MUC",
     "Jabber ID" : "מזהה Jabber",
-    "unknown state" : "מצב לא ידוע",
-    "Bridge saved" : "הגישור נשמר",
-    "Notifications" : "התראות",
-    "Mark as read" : "סימון כנקרא",
-    "Mark as unread" : "סימון כלא נקרא",
-    "Remove from favorites" : "הסרה מהמועדפים",
-    "Add to favorites" : "הוספה למועדפים",
-    "No matches found" : "לא נמצאו התאמות",
-    "Loading" : "בטעינה",
-    "Groups" : "קבוצות",
-    "Circles" : "מעגלים",
-    "Groups and circles" : "קבוצות ומעגלים",
-    "Other sources" : "מקורות אחרים",
-    "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
-    "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
-    "Password protect" : "הגנה בססמה",
-    "Creating your conversation" : "הדיון שלך נוצר",
-    "All set" : "הכול מוכן",
-    "Error while creating the conversation" : "שגיאה ביצירת הדיון",
-    "Create conversation" : "יצירת דיון",
-    "Add participants" : "הוספת משתתפים",
-    "Close" : "סגירה",
-    "Search participants" : "חיפוש משתתפים",
-    "Conversation name" : "שם דיון",
-    "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
-    "Devices" : "מכשירים",
-    "Done" : "הסתיים",
-    "No audio" : "אין שמע",
-    "Upload" : "העלאה",
-    "Files" : "קבצים",
-    "File to share" : "קובץ לשיתוף",
-    "Invalid path selected" : "הנתיב שנבחר שגוי",
-    "Unread messages" : "הודעות שלא נקראו",
-    "Message sent" : "הודעה נשלחה",
-    "Deleting message" : "ההודעה נמחקה",
-    "Dismiss" : "התעלמות",
-    "Reply" : "תגובה",
-    "Go to file" : "מעבר לקובץ",
-    "Translate" : "תרגום",
-    "Contact" : "איש/אשת קשר",
-    "No messages" : "אין הודעות",
-    "Today" : "היום",
-    "Yesterday" : "מחר",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Add emoji" : "הוספת אמוג׳י",
-    "Send message" : "שליחת הודעה",
-    "Write message, @ to mention someone …" : "כתבו תגובה, השתמשו ב-@ לתיוג משתמש",
-    "Group" : "קבוצה",
-    "Share files to the conversation" : "שיתוף קבצים לדיון",
-    "Create new poll" : "יצירת סקר חדש",
-    "New file" : "קובץ חדש",
-    "Settings" : "הגדרות",
-    "Create poll" : "יצירת סקר",
-    "Send" : "שליחה",
-    "Add more files" : "הוספת קבצים נוספים",
-    "Join" : "הצטרף",
-    "moderator" : "מפקח/ת",
-    "guest" : "אורח",
-    "Demote from moderator" : "הורדה מדרגת פיקוח",
-    "Promote to moderator" : "קידום לדרגת פיקוח",
-    "Remove group and members" : "הסרת קבוצה וחברים",
-    "Remove participant" : "הסרת משתתף",
-    "Add groups" : "הוספת קבוצות",
-    "Add emails" : "הוספת כתובות דוא״ל",
-    "Add circles" : "הוספת מעגלים",
-    "Integrations" : "שילובים",
-    "Searching …" : "מתבצע חיפוש…",
-    "No results" : "אין תוצאות",
-    "Add users or groups" : "הוספת משתמשים או קבוצות",
-    "Add groups or circles" : "הוספת קבוצות או מעגלים",
-    "Add other sources" : "הוספת מקורות אחרים",
-    "Participants" : "משתתפים",
-    "Chat" : "צ׳אט",
-    "Details" : "פרטים",
-    "Projects" : "מיזמים",
-    "Select conversation" : "בחירת דיון",
-    "Link to a conversation" : "קישור לדיון",
-    "Choose devices" : "בחירת התקנים",
-    "Attachments folder" : "תיקיית הקבצים המצורפים",
-    "Privacy" : "פרטיות",
-    "Keyboard shortcuts" : "קיצורי מקלדת",
-    "Search" : "חיפוש",
-    "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
-    "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
-    "Start call" : "התחלת שיחה",
-    "Open sidebar" : "פתיחת סרגל הצד",
-    "Show your screen" : "הצגת המסך שלך",
-    "Stop screensharing" : "הפסקת שיתוף המסך",
-    "Screensharing options" : "אפשרויות שיתוף מסך",
-    "Enable screensharing" : "הפעלת שיתוף מסך",
-    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
-    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
-    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
-    "Mute others" : "השתקה של אחרים",
-    "Speaker view" : "תצוגת דובר",
-    "Grid view" : "תצוגת טבלה",
-    "No unread mentions" : "אין אזכורים שלא נקראו",
-    "Say hi to your friends and colleagues!" : "על הדרך לראות מה עם חבריך לעבודה!",
-    "Start a conversation" : "התחלת דיון",
-    "Message without mention" : "הודעה ללא אזכור",
-    "Mention myself" : "אזכור עצמי",
-    "Mention room" : "אזכור חדר",
-    "The conversation does not exist" : "הדיון לא קיים",
-    "Join a conversation or start a new one!" : "הצטרפות לדיון או ליצור אחד חדש!",
-    "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
-    "Calls are not supported in your browser" : "אין תמיכה בשיחות בדפדפן שלך",
-    "Access to microphone was denied" : "הגישה למיקרופון נדחתה",
-    "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
     "Media" : "מדיה",
     "Polls" : "סקרים",
     "Locations" : "מיקומים",
     "Audio" : "שמע",
     "Other" : "אחר",
+    "Group" : "קבוצה",
+    "Error while sharing file" : "שגיאה בשיתוף הקובץ",
+    "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
     "Do not disturb" : "לא להפריע",
     "Away" : "לא פה",
-    "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "Default" : "בררת מחדל",
     "Speaker {number}" : "רמקול {number}",
     "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
@@ -588,14 +591,24 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome",
     "Error while accessing microphone & camera" : "אירעה שגיאה בעת גישה למיקרופון ולמצלמה",
     "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
-    "TURN server" : "שרת TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
-    "Signaling servers" : "שרתי איתות",
     "Android app" : "יישומון ל־Android",
     "iOS app" : "יישומון ל־iOS",
-    "More actions" : "פעולות נוספות",
-    "Link copied to the clipboard!" : "הקישור הועתק ללוח הגזירים!",
-    "Rename conversation" : "שינוי שם הדיון",
-    "Exit fullscreen (F)" : "יציאה ממסך מלא (F)"
+    "There are currently no commands available." : "אין פקודות זמינות.",
+    "The command does not exist" : "הפקודה לא קיימת",
+    "An error occurred while running the command. Please ask an administrator to check the logs." : "אירעה שגיאה בעת הפעלת הפקודה. נא לבקש מהנהלת המערכת לבדוק את יומן התיעוד.",
+    "Commands" : "פקודות",
+    "Command" : "פקודה",
+    "Script" : "סקריפט",
+    "Response to" : "תגובה אל",
+    "Enabled for" : "מופעל עבור",
+    "Moderators" : "מפקחים",
+    "Circles" : "מעגלים",
+    "Groups and circles" : "קבוצות ומעגלים",
+    "Add circles" : "הוספת מעגלים",
+    "Add groups or circles" : "הוספת קבוצות או מעגלים",
+    "Start a conversation" : "התחלת דיון",
+    "TURN server" : "שרת TURN",
+    "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
+    "Signaling servers" : "שרתי איתות"
 },
-"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
+"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
