@@ -11,18 +11,16 @@ OC.L10N.register(
     "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Þú varst í símtali við {user1}, {user2}, {user3}, {user4} og {user5}",
     "_%n other_::_%n others_" : ["%n annar","%n aðrir"],
     "{actor} invited you to {call}" : "{actor} bauð þér að taka þátt í {call}",
+    "Other activities" : "Aðrar athafnir",
     "Talk" : "Spjalla",
     "Guest" : "Gestur",
-    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Velkomin í Nextcloud Talk-spjallforritið!\nÍ þessum spjallþræði verður þú upplýst/ur um nýja eigileika sem tiltækir eru í Nextcloud Talk.",
-    "There are currently no commands available." : "Það eru engarskipanir tiltækar í augnablikinu.",
-    "The command does not exist" : "Skipunin er ekki til",
     "Talk updates ✅" : "Uppfærslur á Talk-spjallforriti ✅",
     "{actor} created the conversation" : "{actor} bjó til samtalið",
     "You created the conversation" : "Þú bjóst til samtalið",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} endurnefndi samtalið \"%1$s\" sem \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Þú endurnefndir samtalið \"%1$s\" sem \"%2$s\"",
-    "{actor} started a call" : "{actor} hóf samtal",
     "You started a call" : "Þú hófst samtal",
+    "{actor} started a call" : "{actor} hóf samtal",
     "{actor} joined the call" : "{actor} kom inn í samtalið",
     "You joined the call" : "Þú komst inn í samtalið",
     "{actor} left the call" : "{actor} hætti í samtalinu",
@@ -57,11 +55,8 @@ OC.L10N.register(
     "{actor} demoted you from moderator" : "{actor} lét þig hætta sem umsjónarmann",
     "{actor} shared a file which is no longer available" : "{actor} deildi skrá sem ekki er lengur tiltæk",
     "You shared a file which is no longer available" : "Þú deildir skrá sem ekki er lengur tiltæk",
+    "Message deleted by author" : "Skilaboðum eytt af höfundi",
     "%s (guest)" : "%s (gestur)",
-    "Call with {user1} and {user2} (Duration {duration})" : "Samtal við {user1} og {user2} (tímalengd {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Samtal við {user1}, {user2} og {user3} (tímalengd {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal við {user1}, {user2}, {user3} og {user4} (tímalengd {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal við {user1}, {user2}, {user3}, {user4} og {user5} (tímalengd {duration})",
     "Talk conversations" : "Samtöl",
     "Talk to %s" : "Tala við %s",
     "File is not shared, or shared but not with the user" : "Skránni er ekki deilt, eða henni er deilt en ekki með notandanum",
@@ -69,6 +64,7 @@ OC.L10N.register(
     "Invalid file provided" : "Ógild skrá gefin",
     "Invalid image" : "Ógild mynd",
     "Unknown filetype" : "Óþekkt skráategund",
+    "Say hi to your friends and colleagues!" : "Segðu hæ við vini þína og samstarfsmenn!",
     "%s invited you to a conversation." : "%s bauð þér að taka þátt í samtali.",
     "You were invited to a conversation." : "Þér var boðið að taka þátt í samtali.",
     "Conversation invitation" : "Boð í samtal",
@@ -78,6 +74,8 @@ OC.L10N.register(
     "Private conversation" : "Einkasamtal",
     "Deleted user (%s)" : "Eyddi notanda (%s)",
     "Dismiss notification" : "Afgreiða tilkynningu",
+    "Accept" : "Samþykkja",
+    "Decline" : "Hafna",
     "{user} sent you a private message" : "{user} sendi þér einkaskilaboð",
     "{user} sent a message in conversation {call}" : "{user} sendi skilaboð í samtali {call}",
     "A deleted user sent a message in conversation {call}" : "Eyddur notandi sendi skilaboð í samtali {call}",
@@ -97,6 +95,7 @@ OC.L10N.register(
     "Call back" : "Hringja til baka",
     "A group call has started in {call}" : "Hópsímtal er byrjað í {call}",
     "Open settings" : "Opna stillingar",
+    "error" : "villa",
     "Conversations" : "Samtöl",
     "Messages" : "Skilaboð",
     "Avatar image is not square" : "Auðkennismynd er ekki ferningslaga",
@@ -340,12 +339,11 @@ OC.L10N.register(
     "South Africa" : "Suður-Afríka",
     "Zambia" : "Sambía",
     "Zimbabwe" : "Simbabve",
+    "Federation" : "Deilt milli þjóna",
     "Invalid date, date format must be YYYY-MM-DD" : "Ógild dagsetning, dagsetningasniðið verður að vera ÁÁÁÁ-MM-DD",
     "Conversation not found" : "Samtal fannst ekki",
-    "Path is already shared with this room" : "Slóðinni er þegar deilt með þessu spjallsvæði",
     "Chat, video & audio-conferencing using WebRTC" : "Spjall, mynd- og hljóðfundir með WebRTC",
     "Leave call" : "Hætta símtali",
-    "Duplicate session" : "Duplicate session",
     "Share this file" : "Deila þessari skrá",
     "Request password" : "Biðja um lykilorð",
     "Error requesting the password." : "Villa kom upp við að biðja um lykilorð.",
@@ -358,18 +356,13 @@ OC.L10N.register(
     "Save changes" : "Vista breytingar",
     "Saving …" : "Vista …",
     "Saved!" : "Vistað!",
-    "Commands" : "Skipanir",
-    "Beta" : "BETA-prófunarútgáfa",
+    "State" : "Staða",
     "Name" : "Nafn",
-    "Command" : "Skipun",
-    "Script" : "Skrifta",
-    "Response to" : "Svar til",
-    "Enabled for" : "Virkjað fyrir",
-    "None" : "Enginn",
-    "User" : "Notandi",
+    "Description" : "Lýsing",
+    "Enabled" : "Virkt",
     "Disabled" : "Óvirkt",
-    "Moderators" : "Umsjónarmenn",
-    "Users" : "Notendur",
+    "Beta" : "BETA-prófunarútgáfa",
+    "Permissions" : "Heimildir",
     "General settings" : "Almennar stillingar",
     "All messages" : "Öll skilaboð",
     "@-mentions only" : "@-mentions only",
@@ -398,9 +391,10 @@ OC.L10N.register(
     "OK" : "Í lagi",
     "Checking …" : "Athuga …",
     "Back" : "Til baka",
+    "Cancel" : "Hætta við",
     "Confirm" : "Staðfesta",
     "Reset" : "Endurstilla",
-    "Cancel" : "Hætta við",
+    "This conversation is read-only" : "This conversation is read-only",
     "Copy link" : "Afrita tengil",
     "Connecting …" : "Tengist ...",
     "Waiting for others to join the call …" : "Bíð eftir að fleiri komi inn í símtalið …",
@@ -414,96 +408,110 @@ OC.L10N.register(
     "You" : "Þú",
     "Show screen" : "Birta skjá",
     "Collapse" : "Fella saman",
-    "This conversation is read-only" : "This conversation is read-only",
+    "Drop your files to upload" : "Slepptu skrám til að senda þær inn",
     "Favorite" : "Eftirlæti",
-    "Description" : "Lýsing",
+    "Loading …" : "Hleð inn …",
+    "Hide details" : "Fela nánari upplýsingar",
+    "Show details" : "Birta nánari upplýsingar",
+    "Date:" : "Dagsetning:",
+    "Note:" : "Athugaðu:",
+    "Disable" : "Gera óvirkt",
+    "The file must be a PNG or JPG" : "Skráin verður að vera PNG eða JPG",
+    "Choose" : "Velja",
     "Restricted" : "Takmarkað",
     "Personal" : "Persónulegt",
     "Meeting" : "Fundur",
-    "Permissions" : "Heimildir",
     "Leave conversation" : "Hætta í samtali",
     "Delete conversation" : "Eyða samtali",
-    "Submit" : "Senda inn",
     "Password protection" : "Verndun með lykilorði",
     "Start time (optional)" : "Upphafstími (valfrjálst)",
     "Save" : "Vista",
     "Edit" : "Breyta",
     "More information" : "Nánari upplýsingar",
     "Delete" : "Eyða",
-    "Password" : "Lykilorð",
-    "API token" : "API-teikn",
-    "Login" : "Innskráning",
-    "Nickname" : "Stuttnefni",
-    "Client ID" : "Biðlaraauðkenni",
+    "Log content" : "Efni atvikaskrár",
     "Notifications" : "Tilkynningar",
+    "Enter your name" : "Settu inn nafnið þitt",
+    "Login" : "Innskráning",
     "Mark as read" : "Merkja sem lesið",
     "Mark as unread" : "Merkja allt sem ólesið",
     "Remove from favorites" : "Fjarlægja úr eftirlætum",
     "Add to favorites" : "Bæta í eftirlæti",
     "You need to promote a new moderator before you can leave the conversation." : "Þú þarft að uppfæra einhvern í stöðu umsjónarmanna áður en þú getur hætt í samtalinu.",
+    "Clear filter" : "Hreinsa síu",
     "No matches found" : "Engar samsvaranir fundust",
-    "Loading" : "Hleð inn",
+    "New group conversation" : "Nýtt hópsamtal…",
+    "Users" : "Notendur",
     "Groups" : "Hópar",
-    "Circles" : "Hringir",
-    "Create a new group conversation" : "Create a new group conversation",
-    "Password protect" : "Verja með lykilorði",
-    "Enter password" : "Enter password",
-    "Add participants" : "Bæta við þátttakanda",
-    "Close" : "Loka",
-    "Conversation name" : "Heiti samtals",
+    "No search results" : "Engar leitarniðurstöður",
+    "Loading" : "Hleð inn",
     "You are currently waiting in the lobby" : "You are currently waiting in the lobby",
+    "None" : "Enginn",
     "Devices" : "Tæki",
-    "Done" : "Lokið",
     "No audio" : "Ekkert hljóð",
+    "Blur" : "Móða",
     "Upload" : "Senda inn",
     "Files" : "Skrár",
-    "File to share" : "Skrá til að deila",
     "Invalid path selected" : "Ógild slóð valin",
     "Unread messages" : "Ólesin skilaboð",
     "Message sent" : "Skilaboðin hafa verið send",
-    "Dismiss" : "Hafna",
     "Reply" : "Svara",
+    "Set reminder" : "Setja áminningu",
     "Copy message link" : "Afrita skilaboðatengil",
     "Go to file" : "Fara í skrá",
     "Translate" : "Þýða",
+    "Dismiss" : "Hafna",
+    "Translate from" : "Þýða úr",
     "Contact" : "Tengiliður",
+    "{stack} in {board}" : "{stack} á {board}",
     "Poll" : "Poll",
-    "End poll" : "End poll",
     "No messages" : "Engin skilaboð",
     "Today" : "Í dag",
     "Yesterday" : "Í gær",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "_%n day ago_::_%n days ago_" : ["fyrir %n degi síðan","fyrir %n dögum síðan"],
+    "Create a new group conversation" : "Create a new group conversation",
+    "Add participants" : "Bæta við þátttakanda",
+    "Close" : "Loka",
+    "Password protect" : "Verja með lykilorði",
+    "Enter password" : "Enter password",
+    "File to share" : "Skrá til að deila",
     "Send message" : "Senda skilaboð",
-    "Write message, @ to mention someone …" : "Write message, @ to mention someone …",
-    "Group" : "Hópur",
+    "Upload from device" : "Senda inn frá tæki",
     "Create new poll" : "Búa til nýja könnun",
+    "Smart picker" : "Snjall-veljari",
+    "Share from Files" : "Deila úr skrám",
     "New file" : "Ný skrá",
     "Blank" : "Tóm",
     "Settings" : "Stillingar",
+    "Anonymous poll" : "Nafnlaus könnun",
     "Create poll" : "Búa til könnun",
     "Send" : "Senda",
+    "End poll" : "End poll",
     "Join" : "Taka þátt",
     "moderator" : "umsjónarmaður",
     "guest" : "gestanotandi",
     "Demote from moderator" : "Láta hætta sem umsjónarmann",
     "Promote to moderator" : "Gera að umsjónarmanni",
     "Remove participant" : "Fjarlægja þátttakanda",
+    "Integrations" : "Samþættingar",
     "Searching …" : "Leita …",
     "No results" : "Engar niðurstöður",
     "Add users or groups" : "Bæta við notendum eða hópum",
     "Participants" : "Þátttakendur",
     "Chat" : "Spjall",
     "Details" : "Details",
+    "Open chat" : "Opna spjall",
     "Projects" : "Verkefni",
     "No shared items" : "No shared items",
     "Select conversation" : "Veldu samtal",
     "Link to a conversation" : "Tengill á samtal",
+    "Edit display name" : "Breyta birtingarnafni",
     "Privacy" : "Gagnaleynd",
+    "Performance" : "Afköst",
     "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
     "Search" : "Search",
     "Start call" : "Hefja samtal",
-    "Open sidebar" : "Opna hliðarspjald",
-    "Open chat" : "Opna spjall",
     "Show your screen" : "Birta skjáinn þinn",
     "Stop screensharing" : "Hætta skjádeilingu",
     "Screensharing options" : "Valkostir skjádeilingar",
@@ -514,17 +522,30 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome to share your screen." : "Veldu einhvern annan vafra eins og Firefox eða Chrome til að deila skjánum þínum.",
     "An error occurred while starting screensharing." : "Villa kom upp við að hefja skjádeilingu.",
     "Grid view" : "Reitasýn",
-    "Say hi to your friends and colleagues!" : "Segðu hæ við vini þína og samstarfsmenn!",
-    "Start a conversation" : "Hefja samtal",
+    "Select a region" : "Veldu svæði",
+    "Submit" : "Senda inn",
+    "Duplicate session" : "Duplicate session",
     "Join a conversation or start a new one" : "Taktu þátt í samtali eða byrjaðu nýtt samtal",
+    "Next week – {timeLocale}" : "Í næstu viku – {timeLocale}",
+    "This weekend – {timeLocale}" : "Þessa helgi – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Á morgun – {timeLocale}",
+    "Later today – {timeLocale}" : "Síðar í dag – {timeLocale}",
+    "Talk conversation" : "Samtal í Talk-spjalli",
+    "User" : "Notandi",
+    "Password" : "Lykilorð",
+    "API token" : "API-teikn",
+    "Nickname" : "Stuttnefni",
+    "Client ID" : "Biðlaraauðkenni",
     "Media" : "Margmiðlunargögn",
     "Polls" : "Kannanir",
     "Locations" : "Staðsetningar",
     "Audio" : "Hljóð",
     "Other" : "Annað",
+    "Show all files" : "Sýna allar skrár",
+    "Group" : "Hópur",
+    "Error while sharing file" : "Villa við deilingu skráar",
     "Do not disturb" : "Ónáðið ekki",
     "Away" : "Fjarverandi",
-    "Error while sharing file" : "Villa við deilingu skráar",
     "Default" : "Sjálfgefið",
     "Access to microphone & camera is only possible with HTTPS" : "Aðgangur að hljóðnema og myndavél er einungis mögulegur í gegnum HTTPS",
     "Please move your setup to HTTPS" : "Endilega færðu uppsetninguna þína yfir í HTTPS",
@@ -533,16 +554,27 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Veldu einhvern annan vafra eins og Firefox eða Chrome",
     "Error while accessing microphone & camera" : "Villa kom upp þegar reynt var að opna hljóðnema og myndavél",
     "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
+    "%s Talk on your mobile devices" : "%s Talaðu á snjalltækjunum þínum",
+    "Android app" : "Android-forrit",
+    "iOS app" : "iOS-forrit",
+    "There are currently no commands available." : "Það eru engarskipanir tiltækar í augnablikinu.",
+    "The command does not exist" : "Skipunin er ekki til",
+    "Call with {user1} and {user2} (Duration {duration})" : "Samtal við {user1} og {user2} (tímalengd {duration})",
+    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Samtal við {user1}, {user2} og {user3} (tímalengd {duration})",
+    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal við {user1}, {user2}, {user3} og {user4} (tímalengd {duration})",
+    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal við {user1}, {user2}, {user3}, {user4} og {user5} (tímalengd {duration})",
+    "Commands" : "Skipanir",
+    "Command" : "Skipun",
+    "Script" : "Skrifta",
+    "Response to" : "Svar til",
+    "Enabled for" : "Virkjað fyrir",
+    "Moderators" : "Umsjónarmenn",
+    "Circles" : "Hringir",
+    "Start a conversation" : "Hefja samtal",
     "Specify commands the users can use in chats" : "Tilgreindu hvaða skipanir notendur geta notað í spjalli",
     "TURN server" : "TURN-þjónn",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-miðlari er notaður sem milliþjónn umferðar þátttakenda á bak við eldvegg.",
     "Signaling servers" : "Merkjasendingaþjónar",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Mögulegt er að nota utanaðkomandi merkjasendingaþjón fyrir mjög stórar uppsetningar. Skildu þetta eftir autt til að nota innbyggða merkjasendingaþjóninn.",
-    "%s Talk on your mobile devices" : "%s Talaðu á snjalltækjunum þínum",
-    "Android app" : "Android-forrit",
-    "iOS app" : "iOS-forrit",
-    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Athugaðu að samtöl með fleiri en 4 þátttakendum og án merkjasendingaþjóns geta orðið fyrir truflunum í tengingum ásamt því að valda miklu álagi á tengdum tækjum.",
-    "More actions" : "Fleiri aðgerðir",
-    "Rename conversation" : "Endurnefna samtal"
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Mögulegt er að nota utanaðkomandi merkjasendingaþjón fyrir mjög stórar uppsetningar. Skildu þetta eftir autt til að nota innbyggða merkjasendingaþjóninn."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
