@@ -17,10 +17,13 @@ OC.L10N.register(
     "Invalid file provided" : "არასწორი ფაილი",
     "Invalid image" : "არასწორი სურათი",
     "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
+    "Accept" : "მიღება",
+    "Decline" : "ურაყოფა",
     "Join call" : "შეუერთდით ზარს",
     "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
     "Open settings" : "პარამეტრების გახსნა",
     "Avatar image is not square" : "ავატარის სურათი არაა კვადრატი",
+    "Federation" : "ფედერაცია",
     "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
     "Leave call" : "ზარის დატოვება",
     "Limit to groups" : "ლიმიტი ჯგუფებზე",
@@ -28,10 +31,10 @@ OC.L10N.register(
     "Save changes" : "ცვილებების შენახვა",
     "Saved!" : "შენახულია!",
     "Name" : "სახელი",
-    "None" : "არც ერთი",
-    "User" : "მომხმარებელი",
+    "Description" : "აღწერილობა",
+    "Enabled" : "მოქმედია",
     "Disabled" : "არაა მოქმედი",
-    "Users" : "მომხმარებლები",
+    "Permissions" : "უფლებები",
     "General settings" : "მთავარი პარამეტრები",
     "Language" : "ენა",
     "Country" : "ქვეყანა",
@@ -49,9 +52,9 @@ OC.L10N.register(
     "OK" : "კარგი",
     "Checking …" : "მოწმდება ...",
     "Back" : "უკან",
+    "Cancel" : "უარყოფა",
     "Confirm" : "დადასტურება",
     "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
-    "Cancel" : "უარყოფა",
     "Copy link" : "ბმულის კოპირება",
     "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
     "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
@@ -63,44 +66,41 @@ OC.L10N.register(
     "Show screen" : "ეკრანის ჩვენება",
     "Collapse" : "აკეცვა",
     "Favorite" : "რჩეული",
-    "Description" : "აღწერილობა",
+    "Hide details" : "დეტალების დამალვა",
+    "Disable" : "გამორთვა",
+    "Choose" : "აირჩიეთ",
     "Restricted" : "აკრძალული",
     "Personal" : "პირადი",
-    "Permissions" : "უფლებები",
-    "Submit" : "გაგზავნა",
+    "Yes" : "დიახ",
     "Password protection" : "პაროლით თავდაცვა",
     "Save" : "შენახვა",
     "Edit" : "შეცვლა",
     "Delete" : "წაშლა",
-    "Password" : "პაროლი",
-    "API token" : "API ტოკენი",
-    "Login" : "ავტორიზაცია",
-    "Nickname" : "ნიკნეიმი",
-    "Client ID" : "კლიენტის ID",
+    "Log content" : "ლოგის მოცულობა",
     "Notifications" : "შეტყობინებები",
+    "Login" : "ავტორიზაცია",
     "Mark as read" : "წაკითხულად მონიშვნა",
     "Mark as unread" : "წაუკითხავად მონიშვნა",
     "Remove from favorites" : "რჩეულებიდან ამოშლა",
     "Add to favorites" : "რჩეულებში დამატება",
-    "Loading" : "იტვირთება",
+    "Users" : "მომხმარებლები",
     "Groups" : "ჯგუფები",
-    "Circles" : "წრეები",
-    "Password protect" : "პაროლით დაცვა",
-    "Close" : "დახურვა",
-    "Conversation name" : "საუბრის სახელწოდება",
+    "Loading" : "იტვირთება",
+    "None" : "არც ერთი",
     "Devices" : "მოწყობილობები",
-    "Done" : "დასრულდა",
     "Upload" : "ატვირთვა",
     "Files" : "ფაილები",
     "Message sent" : "წერილი გაგზავნილია",
-    "Dismiss" : "დათხოვნა",
     "Reply" : "პასუხი",
     "Translate" : "გადათარგმნეთ",
+    "Dismiss" : "დათხოვნა",
     "Contact" : "კონტაქტი",
     "Today" : "დღეს",
     "Yesterday" : "გუშინ",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Group" : "ჯგუფი",
+    "_%n day ago_::_%n days ago_" : ["%n დღის წინ","%n დღის წინ"],
+    "Close" : "დახურვა",
+    "Password protect" : "პაროლით დაცვა",
     "Create new poll" : "ახალი გამოკითხვის შექმნა",
     "Settings" : "პარამეტრები",
     "Create poll" : "გამოკითხვის შექმნა",
@@ -127,9 +127,16 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
     "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
     "Grid view" : "ბადისებური ხედი",
+    "Submit" : "გაგზავნა",
+    "User" : "მომხმარებელი",
+    "Password" : "პაროლი",
+    "API token" : "API ტოკენი",
+    "Nickname" : "ნიკნეიმი",
+    "Client ID" : "კლიენტის ID",
     "Polls" : "გამოკითხვები",
     "Audio" : "აუდიო",
     "Other" : "სხვა",
+    "Group" : "ჯგუფი",
     "Default" : "საწყისი",
     "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
     "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
@@ -137,11 +144,11 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
     "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
     "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
-    "TURN server" : "TURN სერვერი",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი.",
     "Android app" : "Android აპლიკაცია",
     "iOS app" : "iOS აპლიკაცია",
-    "More actions" : "მეტი ქმედება"
+    "Circles" : "წრეები",
+    "TURN server" : "TURN სერვერი",
+    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი."
 },
 "nplurals=2; plural=(n!=1);");
