@@ -13,16 +13,15 @@ OC.L10N.register(
     "{actor} invited you to {call}" : "{actor} uzaicināja jūs uz {call}",
     "Talk" : "Runāt",
     "Guest" : "Viesis",
-    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Esiet sveicināts Nextcloud Talk!\nŠajā sarunā jūs tiksit informēts par jaunām Nextcloud Talk iespējām.",
-    "There are currently no commands available." : "Pašlaik nav pieejamas komandas.",
-    "The command does not exist" : "Šī komanda nepastāv",
+    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Viens pret vienu sarunas tagad ir pastāvīgas, un tās vairs nevar nejauši pārveidot par kopu sarunām. Kā arī, kad viens no dalībniekiem pamet sarunu, tā vairs netiek automātiski izdzēsta. Tikai ja abi dalībnieki izies, saruna tiks izdzēsta no servera",
+    "- In the sidebar you can now find an overview of the latest shared items" : "- Sānu joslā tagad var atrast pēdējo kopīgoto vienumu pārskatu",
     "Talk updates ✅" : "Talk atjauninājumi ✅",
     "{actor} created the conversation" : "{actor} izveidoja sarunu",
     "You created the conversation" : "Jūs izveidojāt sarunu",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pārdēvēja sarunu no \"%1$s\" uz \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pārdēvējāt sarunu no \"%1$s\" uz \"%2$s\"",
-    "{actor} started a call" : "{actor} sācis zvanu",
     "You started a call" : "Jūs sākāt zvanu",
+    "{actor} started a call" : "{actor} sācis zvanu",
     "{actor} joined the call" : "{actor} pievienojies zvanam",
     "You joined the call" : "Jūs pievienojaties zvanam",
     "{actor} left the call" : "{actor} atstājis zvanu",
@@ -57,18 +56,19 @@ OC.L10N.register(
     "{actor} demoted you from moderator" : "{actor} pazemināja jūs no regulētāja",
     "{actor} shared a file which is no longer available" : "{actor} kopīgoja datni, kas vairs nav pieejama",
     "You shared a file which is no longer available" : "Jūs kopīgojāt datni, kas vairs nav pieejama",
+    "Message deleted by author" : "Ziņojumu izdzēsa autors",
     "%s (guest)" : "%s (viesis)",
-    "Call with {user1} and {user2} (Duration {duration})" : "Saruna ar {user1} un {user2} ( Ilgums {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Saruna ar {user1}, {user2} un {user3} ( Ilgums {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Saruna ar {user1}, {user2}, {user3} un {user4} ( Ilgums {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Saruna ar {user1}, {user2}, {user3}, {user4} un {user5} ( Ilgums {duration})",
     "Talk conversations" : "Sarunas",
     "Talk to %s" : "Runāt ar %s",
     "File is not shared, or shared but not with the user" : "Datne nav koplietota vai koplietots, bet nav koplietots ar lietotāju",
     "File is too big" : "Datne ir par lielu",
     "Invalid file provided" : "Norādīta nederīga datne",
     "Invalid image" : "Nederīgs attēls",
-    "Unknown filetype" : "Nezināms datnes tips",
+    "Unknown filetype" : "Nezināms datnes veids",
+    "Talk mentions" : "Pieminēšana Talk",
+    "More conversations" : "Vairāk sarunu",
+    "Say hi to your friends and colleagues!" : "Sasveicinies ar saviem draugiem un kolēģiem!",
+    "No unread mentions" : "Nav nelasītu pieminēšanu",
     "%s invited you to a conversation." : "%s uzaicināja jūs uz sarunu.",
     "You were invited to a conversation." : "Jūs uzaicinājāt uz sarunu.",
     "Conversation invitation" : "Sarunas uzaicinājums",
@@ -77,6 +77,8 @@ OC.L10N.register(
     "Password request: %s" : "Paroles pieprasījums: %s",
     "Private conversation" : "Privāta saruna",
     "Dismiss notification" : "Noraidīt paziņojumu",
+    "Accept" : "Pieņemt",
+    "Decline" : "Noraidīt",
     "{user} sent you a private message" : "{user} nosūtīja jums privātu ziņojumu",
     "{user} sent a message in conversation {call}" : "{user} nosūtīja ziņu sarunā {call}",
     "A deleted user sent a message in conversation {call}" : "Izdzēsts lietotājs nosūtīja ziņojumu sarunā {call}",
@@ -89,11 +91,248 @@ OC.L10N.register(
     "Join call" : "Pievienoties zvanam",
     "{user} invited you to a group conversation: {call}" : "{user} uzaicināja jūs uz grupas sarunu: {call}",
     "A group call has started in {call}" : "Grupas zvans ir sācies {call}",
-    "Open settings" : "Atveriet iestatījumus",
+    "Open settings" : "Atvērt iestatījumus",
+    "error" : "kļūda",
     "Avatar image is not square" : "Avatar attēls nav kvadrāts",
+    "Andorra" : "Andora",
+    "United Arab Emirates" : "Apvienotie Arābu Emirāti",
+    "Afghanistan" : "Afganistāna",
+    "Antigua and Barbuda" : "Antigva un Barbuda",
+    "Anguilla" : "Anguilla",
+    "Albania" : "Albānija",
+    "Armenia" : "Armēnija",
+    "Angola" : "Angola",
+    "Antarctica" : "Antarktika",
+    "Argentina" : "Argentīna",
+    "American Samoa" : "Amerikas Samoa",
+    "Austria" : "Austija",
+    "Australia" : "Austrālija",
+    "Aruba" : "Aruba",
+    "Åland Islands" : "Ālandu salas",
+    "Azerbaijan" : "Azerbaidžāna",
+    "Bosnia and Herzegovina" : "Bosnija un Hercogovina",
+    "Barbados" : "Barbadosa",
+    "Bangladesh" : "Bangladeša",
+    "Belgium" : "Beļģija",
+    "Burkina Faso" : "Burkinafaso",
+    "Bulgaria" : "Bulgārija",
+    "Bahrain" : "Bahreina",
+    "Burundi" : "Burundija",
+    "Benin" : "Benina",
+    "Saint Barthélemy" : "Senbartelmī",
+    "Bermuda" : "Bermudu salas",
+    "Brunei Darussalam" : "Bruneja Darusalama",
+    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sintēstatiusa un Saba",
+    "Brazil" : "Brazīlija",
+    "Bahamas" : "Bahamu salas",
+    "Bhutan" : "Butāna",
+    "Bouvet Island" : "Buvē sala",
+    "Botswana" : "Botsvāna",
+    "Belarus" : "Baltkrievija",
+    "Belize" : "Beliza",
+    "Canada" : "Kanāda",
+    "Cocos (Keeling) Islands" : "Kokosu (Kīlinga) Salas",
+    "Central African Republic" : "Centrālāfrikas Republika",
+    "Congo" : "Kongo Republika",
+    "Switzerland" : "Šveice",
+    "Côte d'Ivoire" : "Kotdivuāra",
+    "Cook Islands" : "Kuka salas",
+    "Chile" : "Čīle",
+    "Cameroon" : "Kamerūna",
+    "China" : "Ķīna",
+    "Colombia" : "Kolumbija",
+    "Costa Rica" : "Kostarika",
+    "Cuba" : "Kuba",
+    "Cabo Verde" : "Kaboverde",
+    "Curaçao" : "Kirasao",
+    "Christmas Island" : "Ziemassvētku sala",
+    "Cyprus" : "Ķipra",
+    "Czechia" : "Čehija",
+    "Germany" : "Vācija",
+    "Djibouti" : "Džibutija",
+    "Denmark" : "Dānija",
+    "Dominica" : "Dominika",
+    "Dominican Republic" : "Dominikānas Republika",
+    "Algeria" : "Alžīrija",
+    "Ecuador" : "Ekvadora",
+    "Estonia" : "Igaunija",
+    "Egypt" : "Ēģipte",
+    "Western Sahara" : "Rietumsahāra",
+    "Eritrea" : "Eritreja",
+    "Spain" : "Spānija",
+    "Ethiopia" : "Etiopija",
+    "Finland" : "Somija",
+    "Fiji" : "Fidži",
+    "Falkland Islands (Malvinas)" : "Folklenda salas (Malvinas)",
+    "Faroe Islands" : "Fēru salas",
+    "France" : "Francija",
+    "Gabon" : "Gabona",
+    "United Kingdom of Great Britain and Northern Ireland" : "Lielbritānijas un Ziemeļīrijas Apvienotā Karaliste",
+    "Grenada" : "Grenādā",
+    "Georgia" : "Gruzija",
+    "French Guiana" : "Franču Gviāna",
+    "Guernsey" : "Gērnsija",
+    "Ghana" : "Gana",
+    "Gibraltar" : "Ģibraltārs",
+    "Greenland" : "Grīnlande",
+    "Gambia" : "Gambija",
+    "Guinea" : "Gvineja",
+    "Guadeloupe" : "Gvadelupa",
+    "Equatorial Guinea" : "Ekvatoriālā Gvineja",
+    "Greece" : "Grieķija",
+    "South Georgia and the South Sandwich Islands" : "Dienviddžordžija un Dienvidsendviču salas",
+    "Guatemala" : "Gvatemala",
+    "Guam" : "Guama",
+    "Guinea-Bissau" : "Gvineja-Bisava",
+    "Guyana" : "Gajana",
+    "Hong Kong" : "Honkonga",
+    "Heard Island and McDonald Islands" : "Hērda Sala un Makdonalda Salas",
+    "Honduras" : "Hondurasa",
+    "Croatia" : "Horvātija",
+    "Haiti" : "Haiti",
+    "Hungary" : "Ungārija",
+    "Indonesia" : "Indonēzija",
+    "Ireland" : "Īrija",
+    "Israel" : "Izraēla",
+    "Isle of Man" : "Menas sala",
+    "India" : "Indija",
+    "British Indian Ocean Territory" : "Britu Indijas Okeāna Teritorija",
+    "Iraq" : "Irāka",
+    "Iceland" : "Islande",
+    "Italy" : "Itālija",
+    "Jersey" : "Džērsija",
+    "Jamaica" : "Jamaika",
+    "Jordan" : "Jordānija",
+    "Japan" : "Japāna",
+    "Kenya" : "Kenija",
+    "Kyrgyzstan" : "Kirgizstāna",
+    "Cambodia" : "Kambodža",
+    "Kiribati" : "Kiribati",
+    "Comoros" : "Komoras",
+    "Saint Kitts and Nevis" : "Sentkitsa un Nevisa",
+    "Kuwait" : "Kuveita",
+    "Cayman Islands" : "Kaimanu Salas",
+    "Kazakhstan" : "Kazahstāna",
+    "Lao People's Democratic Republic" : "Laosas Tautas Demokrātiskā Republika",
+    "Lebanon" : "Lebanona",
+    "Saint Lucia" : "Sentlūsija",
+    "Liechtenstein" : "Lihtenšteina",
+    "Sri Lanka" : "Šrilanka",
+    "Liberia" : "Libērija",
+    "Lesotho" : "Lesoto",
+    "Lithuania" : "Lietuve",
+    "Luxembourg" : "Luksemburga",
+    "Latvia" : "Latvija",
+    "Libya" : "Lībija",
+    "Morocco" : "Maroka",
+    "Monaco" : "Monako",
+    "Montenegro" : "Melnkalne",
+    "Saint Martin (French part)" : "Senmartēna (Francijas teritorija)",
+    "Madagascar" : "Madagaskāra",
+    "Marshall Islands" : "Māršala salas",
+    "Mali" : "Mali",
+    "Myanmar" : "Činlande",
+    "Mongolia" : "Mongolija",
+    "Macao" : "Makao",
+    "Northern Mariana Islands" : "Ziemeļu Marianas salas",
+    "Martinique" : "Martinika",
+    "Mauritania" : "Mauritānija",
+    "Montserrat" : "Montserrata",
+    "Malta" : "Malta",
+    "Mauritius" : "Maurīcija",
+    "Maldives" : "Maldīvu salas",
+    "Malawi" : "Malāvija",
+    "Mexico" : "Meksika",
+    "Malaysia" : "Malaizija",
+    "Mozambique" : "Mozambika",
+    "Namibia" : "Namībija",
+    "New Caledonia" : "Jaunkaledonija",
+    "Niger" : "Nigēra",
+    "Norfolk Island" : "Norfolkas sala",
+    "Nigeria" : "Nigērija",
+    "Nicaragua" : "Nikaragva",
+    "Netherlands" : "Nīderlande",
+    "Norway" : "Norvēģija",
+    "Nepal" : "Nepāla",
+    "Nauru" : "Nauru",
+    "Niue" : "Niue",
+    "New Zealand" : "Jaunzēlande",
+    "Oman" : "Omāna",
+    "Panama" : "Panama",
+    "Peru" : "Peru",
+    "French Polynesia" : "Franču Polinēzija",
+    "Papua New Guinea" : "Papua-Jaungvineja",
+    "Philippines" : "Filipīnas",
+    "Pakistan" : "Paķistāna",
+    "Poland" : "Polija",
+    "Saint Pierre and Miquelon" : "Senpjēra un Mikelona",
+    "Pitcairn" : "Pitkērna",
+    "Puerto Rico" : "Puertoriko",
+    "Palestine, State of" : "Palestīna",
+    "Portugal" : "Portugāle",
+    "Palau" : "Palau",
+    "Paraguay" : "Paragvaja",
+    "Qatar" : "Katāra",
+    "Réunion" : "Reinjona",
+    "Romania" : "Rumānija",
+    "Serbia" : "Serbija",
+    "Russian Federation" : "Krievijas Federācija",
+    "Rwanda" : "Ruanda",
+    "Saudi Arabia" : "Saūda Arābija",
+    "Solomon Islands" : "Zālamana salas",
+    "Seychelles" : "Seišelas",
+    "Sudan" : "Sudāna",
+    "Sweden" : "Zviedrija",
+    "Singapore" : "Singapūra",
+    "Saint Helena, Ascension and Tristan da Cunha" : "Svētās Helēnas sala, Debesbraukšanas sala un Tristana da Kuņas salas",
+    "Slovenia" : "Slovēnija",
+    "Svalbard and Jan Mayen" : "Svalbārai un Jana Majena",
+    "Slovakia" : "Slovākija",
+    "Sierra Leone" : "Sjerraleone",
+    "San Marino" : "Sanmarīno",
+    "Senegal" : "Senegāla",
+    "Somalia" : "Somālija",
+    "Suriname" : "Surinama",
+    "South Sudan" : "Dienvidsudāna",
+    "Sao Tome and Principe" : "Santome un Prinsipi",
+    "El Salvador" : "Salvadora",
+    "Sint Maarten (Dutch part)" : "Sintmārtena (Nīderlandes teritorija)",
+    "Syrian Arab Republic" : "Sīrijas Republika",
+    "Turks and Caicos Islands" : "Tērksas un Kaikosas salas",
+    "Chad" : "Čada",
+    "French Southern Territories" : "Francijas Dienvidjūru Zemes",
+    "Togo" : "Togo",
+    "Thailand" : "Taizeme",
+    "Tajikistan" : "Tadžikistāna",
+    "Tokelau" : "Tokelau",
+    "Timor-Leste" : "Austrumtimora",
+    "Turkmenistan" : "Turkmenistāna",
+    "Tunisia" : "Tunisija",
+    "Tonga" : "Tonga",
+    "Turkey" : "Turcija",
+    "Trinidad and Tobago" : "Trinidāda un Tobāgo",
+    "Tuvalu" : "Tuvalu",
+    "Tanzania, United Republic of" : "Tanzānija, Apvienotā Republika",
+    "Ukraine" : "Ukraina",
+    "Uganda" : "Uganda",
+    "United States Minor Outlying Islands" : "ASV Mazās aizjūras salas",
+    "United States of America" : "Amerikas Savienotās Valstis",
+    "Uruguay" : "Urugvaja",
+    "Uzbekistan" : "Uzbekistāna",
+    "Holy See" : "Vatikāns",
+    "Saint Vincent and the Grenadines" : "Sentvinsenta un Grenadīnas",
+    "Viet Nam" : "Vjetnama",
+    "Vanuatu" : "Vanuatu",
+    "Wallis and Futuna" : "Volisa un Futuna",
+    "Samoa" : "Samoa",
+    "Yemen" : "Jemena",
+    "Mayotte" : "Majota",
+    "South Africa" : "Dienvidāfrika",
+    "Zambia" : "Zambija",
+    "Zimbabwe" : "Zimbabve",
+    "Federation" : "Federācija",
     "Invalid date, date format must be YYYY-MM-DD" : "Nederīgs datums, datuma formātam jābūt YYYY-MM-DD",
     "Conversation not found" : "Saruna nav atrasta",
-    "Path is already shared with this room" : "Ceļš jau ir koplietots ar šo telpu",
     "Chat, video & audio-conferencing using WebRTC" : "Video un audio konferences, izmantojot WebRTC",
     "Leave call" : "Pamest zvanu",
     "Request password" : "Pieprasīt paroli",
@@ -102,22 +341,18 @@ OC.L10N.register(
     "Limit to groups" : "Grupu ierobežojums",
     "When at least one group is selected, only people of the listed groups can be part of conversations." : "Ja ir atlasīta vismaz viena grupa, tikai personas no sarakstā minētajām grupām var piedalīties sarunās.",
     "Guests can still join public conversations." : "Viesi joprojām var pievienoties publiskām sarunām.",
+    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Lietotāji, kas vairs nevar izmantot Talk, joprojām tiks uzrādīti kā dalībnieki viņu iepriekšējās sarunās, kā arī tiks paturētas viņu ziņas.",
     "Everyone" : "Visi",
     "Save changes" : "Saglabāt izmaiņas",
     "Saving …" : "Saglabā ...",
     "Saved!" : "Saglabāts!",
-    "Commands" : "Komandas",
-    "Beta" : "Beta",
+    "State" : "Stāvoklis",
     "Name" : "Nosaukums",
-    "Command" : "Komanda",
-    "Script" : "Skripts",
-    "Response to" : "Atbilde uz",
-    "Enabled for" : "Iespējots",
-    "None" : "Nav",
-    "User" : "Lietotājs",
+    "Description" : "Apraksts",
+    "Enabled" : "Iespējots",
     "Disabled" : "Atspējots",
-    "Moderators" : "Regulētāji",
-    "Users" : "Lietotāji",
+    "Beta" : "Beta",
+    "Permissions" : "Atļaujas",
     "General settings" : "Vispārīgie iestatījumi",
     "Language" : "Valoda",
     "Country" : "Valsts",
@@ -138,11 +373,12 @@ OC.L10N.register(
     "TURN server protocols" : "TURN servera protokols",
     "Test this server" : "Testēt šo serveri",
     "TURN servers" : "TURN serveris",
+    "Failed" : "Neizdevās",
     "OK" : "Labi",
     "Back" : "Atpakaļ",
+    "Cancel" : "Atcelt",
     "Confirm" : "Apstiprināt",
     "Reset" : "Atiestatīt",
-    "Cancel" : "Atcelt",
     "Copy link" : "Kopēt saiti",
     "Waiting for others to join the call …" : "Gaidot citus pievienoties zvanam …",
     "You can invite others in the participant tab of the sidebar" : "Sānjoslā, dalībnieku cilnē var uzaicināt citus dalībniekus",
@@ -154,49 +390,56 @@ OC.L10N.register(
     "You" : "Jūs",
     "Show screen" : "Rādīt ekrānu",
     "Collapse" : "Sakļaut",
-    "Favorite" : "Favorīts",
-    "Description" : "Apraksts",
+    "Favorite" : "Izlasē",
+    "Loading …" : "Ielādē…",
+    "Hide details" : "Slēpt detaļas",
+    "Show details" : "Rādīt detaļas",
+    "Date:" : "Datums:",
+    "Disable" : "Deaktivēt",
+    "Enable" : "Iespējot",
+    "The file must be a PNG or JPG" : "Failam jābūt PNG vai JPG",
+    "Choose" : "Izvēlies",
     "Restricted" : "Ierobežota",
     "Personal" : "Personīgs",
-    "Permissions" : "Atļaujas",
+    "Setup overview" : "Uzstādīšanas pārskats",
+    "Meeting" : "Tikšanās",
     "Leave conversation" : "Atstāt sarunu",
+    "No" : "Nē",
+    "Yes" : "Jā",
     "Delete conversation" : "Dzēst sarunu",
-    "Submit" : "Iesniegt",
     "Password protection" : "Password protection",
     "Save" : "Saglabāt",
-    "Edit" : "Rediģēt",
+    "Edit" : "Labot",
     "Delete" : "Dzēst",
-    "Password" : "Parole",
-    "API token" : "API pilnvara",
-    "Login" : "Autorizēties",
-    "Nickname" : "Iesauka",
-    "Client ID" : "Klienta ID",
     "Notifications" : "Paziņojumi",
-    "Remove from favorites" : "Noņemt no favorītiem",
+    "Login" : "Autorizēties",
+    "Remove from favorites" : "Noņemt no izlases",
     "Add to favorites" : "Pievienot izlasei",
     "You need to promote a new moderator before you can leave the conversation." : "Pirms sarunas atstāšanas ir jāieceļ jauns regulētājs.",
-    "Loading" : "Ielādē",
+    "Clear filter" : "Notīrīt atlasi",
+    "Users" : "Lietotāji",
     "Groups" : "Grupas",
-    "Password protect" : "Aizsargāt ar paroli",
-    "Close" : "Aizvērt",
-    "Conversation name" : "Sarunas nosaukums",
+    "Loading" : "Ielādē",
+    "You have no unread mentions." : "Nav nelasītu pieminēšanu.",
+    "None" : "Nav",
     "Devices" : "Ierīces",
-    "Done" : "Pabeigts",
     "No audio" : "Nav audio",
     "Upload" : "Augšupielādēt",
     "Files" : "Datnes",
-    "File to share" : "Kopīgojamā datne",
-    "Dismiss" : "Atmest",
     "Reply" : "Atbildēt",
     "Go to file" : "Doties uz datni",
     "Translate" : "Tulkot",
+    "Dismiss" : "Atmest",
     "Contact" : "Kontakts",
     "Today" : "Šodien",
     "Yesterday" : "Vakar",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Write message, @ to mention someone …" : "Rakstiet ziņu, @ lai pieminētu kādu …",
-    "Group" : "Grupa",
-    "New file" : "Jauns fails",
+    "_%n day ago_::_%n days ago_" : ["%n dienas atpakaļ","%n dienas atpakaļ","%n dienām"],
+    "Close" : "Aizvērt",
+    "Password protect" : "Aizsargāt ar paroli",
+    "File to share" : "Kopīgojamā datne",
+    "Upload from device" : "Augšupielādēt no ierīces",
+    "New file" : "Jauna datne",
     "Settings" : "Iestatījumi",
     "Send" : "Sūtīt",
     "Join" : "Pievienoties",
@@ -204,6 +447,7 @@ OC.L10N.register(
     "guest" : "viesis",
     "Demote from moderator" : "Pazemināt no regulētāja",
     "Promote to moderator" : "Paaugstināt par regulētāju",
+    "Remove" : "Izņemt",
     "Remove participant" : "Noņemt dalībnieku",
     "Searching …" : "Meklē...",
     "No results" : "Nav rezultātu",
@@ -217,8 +461,9 @@ OC.L10N.register(
     "Privacy" : "Privātums",
     "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Search" : "Meklēt",
+    "Error while setting read status privacy" : "Kļūda lasīšanas stāvokļa privātuma iestatīšanas laikā",
+    "Error while setting typing status privacy" : "Kļūda rakstīšanas stāvokļa privātuma iestatīšanas laikā",
     "Start call" : "Sākt zvanu",
-    "Open sidebar" : "Atvērt sānjoslu",
     "Show your screen" : "Rādīt savu ekrānu",
     "Stop screensharing" : "Apturēt ekrāna koplietošanu",
     "Screensharing options" : "Ekrāna koplietošanas opcijas",
@@ -228,12 +473,21 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Lai koplietotu ekrānu, ir nepieciešams ekrāna koplietošanas paplašinājums.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Lai koplietotu ekrānu, lūdzu, izmantojiet citu pārlūkprogrammu, piemēram, Firefox vai Chrome.",
     "An error occurred while starting screensharing." : "Startējot ekrāna koplietošanu, radās kļūda.",
+    "Start recording" : "Uzsākt ierakstīšanu",
     "Grid view" : "Režģa izkārtojums",
-    "Say hi to your friends and colleagues!" : "Sasveicinies ar saviem draugiem un kolēģiem!",
-    "Start a conversation" : "Sākt sarunu",
+    "Select a region" : "Izvēlieties reģionu",
+    "Submit" : "Iesniegt",
     "Join a conversation or start a new one" : "Pievienoties sarunai vai sākt jaunu",
+    "User" : "Lietotājs",
+    "Password" : "Parole",
+    "API token" : "API pilnvara",
+    "Nickname" : "Iesauka",
+    "Client ID" : "Klienta ID",
     "Audio" : "Audio",
     "Other" : "Cits",
+    "Group" : "Grupa",
+    "Search in conversation: {conversation}" : "Meklēt sarunā: {conversation}",
+    "Error while sharing file" : "Kļūda datnes kopīgošanā",
     "Default" : "Noklusējuma",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tas aizņem vairāk laika, nekā paredzēts. Vai multivides atļaujas jau ir piešķirtas (vai noraidītas)? Ja atbilde ir “jā”, restartējiet pārlūkprogrammu, jo ir audio un video kļūme",
     "Access to microphone & camera is only possible with HTTPS" : "Piekļuve mikrofonam un kamerai ir iespējama izmantojot tikai HTTPS",
@@ -243,14 +497,26 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Lūdzu, izmantojiet citu pārlūkprogrammu, piemēram Firefox vai Chrome",
     "Error while accessing microphone & camera" : "Kļūda, piekļūstot mikrofonam un kamerai",
     "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
+    "%s Talk on your mobile devices" : "%s Sarunas mobilajās ierīcēs",
+    "Android app" : "Android lietotne",
+    "iOS app" : "iOS lietotne",
+    "There are currently no commands available." : "Pašlaik nav pieejamas komandas.",
+    "The command does not exist" : "Šī komanda nepastāv",
+    "Call with {user1} and {user2} (Duration {duration})" : "Saruna ar {user1} un {user2} ( Ilgums {duration})",
+    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Saruna ar {user1}, {user2} un {user3} ( Ilgums {duration})",
+    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Saruna ar {user1}, {user2}, {user3} un {user4} ( Ilgums {duration})",
+    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Saruna ar {user1}, {user2}, {user3}, {user4} un {user5} ( Ilgums {duration})",
+    "Commands" : "Komandas",
+    "Command" : "Komanda",
+    "Script" : "Skripts",
+    "Response to" : "Atbilde uz",
+    "Enabled for" : "Iespējots",
+    "Moderators" : "Regulētāji",
+    "Start a conversation" : "Sākt sarunu",
     "Specify commands the users can use in chats" : "Komandu norādīšana, kuras lietotāji var izmantot tērzēšanā",
     "TURN server" : "TURN serveris",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveris tiek izmantots, lai bloķētu dalībnieku datplūsmu aiz ugunsmūra.",
     "Signaling servers" : "Signalizēšanas serveri",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ārējo signalizēšanas serveri var pēc izvēles izmantot lielākām instalācijām. Atstājiet tukšu, lai izmantotu iekšējo signalizēšanas serveri.",
-    "%s Talk on your mobile devices" : "%s Sarunas mobilajās ierīcēs",
-    "Android app" : "Android lietotne",
-    "iOS app" : "iOS lietotne",
-    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Zvani, kuros ir vairāk nekā 4 dalībnieki bez ārējā paraksta servera, var saskarties ar savienojamības problēmām un radīt lielu slodzi iesaistītajām ierīcēm."
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ārējo signalizēšanas serveri var pēc izvēles izmantot lielākām instalācijām. Atstājiet tukšu, lai izmantotu iekšējo signalizēšanas serveri."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
