@@ -15,21 +15,32 @@ OC.L10N.register(
     "Other activities" : "Outras atividades",
     "Talk" : "Falar",
     "Guest" : "Convidado",
-    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Bem-vindo ao Nextcloud Talk!\nNesta conversa será informado sobre novas funcionalidades disponíveis no Nextcloud Talk.",
+    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Bem-vindo ao Nextcloud Talk!\nNesta conversa será informado sobre as novidades disponíveis no Nextcloud Talk.",
+    "## New in Talk %s" : "## Novo no Talk %s",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- O Microsoft Edge e o Safari podem, agora, ser utilizados para participar em chamadas áudio e vídeo.",
+    "Talk updates ✅" : "Atualizações do Falar ✅",
+    "System created the conversation" : "O sistema criou a conversa",
+    "Message deleted by author" : "Mensagem apagada pelo autor",
     "Talk conversations" : "Conversas no Talk",
     "Talk to %s" : "Falar com %s",
     "File is too big" : "O ficheiro é demasiado grande",
     "Invalid file provided" : "Fornecido ficheiro inválido",
     "Invalid image" : "Imagem inválida",
     "Unknown filetype" : "Tipo de ficheiro desconhecido",
+    "Talk mentions" : "Menções no Falar",
+    "No unread mentions" : "Nenhuma menção por ler",
     "Dismiss notification" : "Dispensar notificação",
+    "Accept" : "Aceitar",
+    "Decline" : "Recusar",
     "Join call" : "Juntar-se à chamada",
     "A group call has started in {call}" : "Uma chamada de grupo começou em {call}",
     "Open settings" : "Abrir definições",
+    "error" : "erro",
     "Conversations" : "Conversações",
     "Messages" : "Mensagens",
     "Avatar image is not square" : "A imagem do avatar não é quadrada.",
+    "Note to self" : "Nota a mim",
+    "A place for your private notes, thoughts and ideas" : "Um local para os seus pensamentos, notas e ideias privados",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Emirados Árabes Unidos",
     "Afghanistan" : "Afeganistão",
@@ -210,6 +221,7 @@ OC.L10N.register(
     "South Africa" : "África do Sul",
     "Zambia" : "Zâmbia",
     "Zimbabwe" : "Zimbábue ",
+    "Federation" : "Federação",
     "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
     "Leave call" : "Sair da chamada",
     "Limit to groups" : "Limitado a grupos",
@@ -217,11 +229,11 @@ OC.L10N.register(
     "Save changes" : "Guardar alterações",
     "Saving …" : "A guardar...",
     "Saved!" : "Gravado!",
+    "State" : "Estado",
     "Name" : "Nome",
-    "None" : "Nenhum",
-    "User" : "Utilizador",
+    "Description" : "Descrição",
+    "Enabled" : "Activo",
     "Disabled" : "Desactivado",
-    "Users" : "Utilizadores",
     "General settings" : "Definições Gerais",
     "Language" : "Idioma",
     "Country" : "País",
@@ -237,9 +249,9 @@ OC.L10N.register(
     "OK" : "Ok",
     "Checking …" : "A verificar...",
     "Back" : "Anterior",
+    "Cancel" : "Cancelar",
     "Confirm" : "Confirmar",
     "Reset" : "Reiniciar",
-    "Cancel" : "Cancelar",
     "Copy link" : "Copiar ligação",
     "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
     "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
@@ -251,43 +263,51 @@ OC.L10N.register(
     "Show screen" : "Mostrar ecrã",
     "Collapse" : "Expandir",
     "Favorite" : "Favorito",
-    "Description" : "Descrição",
+    "Hide details" : "Ocultar detalhes",
+    "Show details" : "Mostrar detalhes",
+    "Date:" : "Data:",
+    "Disable" : "Desativar",
+    "Enable" : "Activar",
+    "Choose" : "Escolher",
     "Restricted" : "Restrito",
     "Personal" : "Pessoal",
     "Leave conversation" : "Sair da conversação",
     "Delete conversation" : "Eliminar conversação",
-    "Submit" : "Submeter",
     "Password protection" : "Protegido por palavra-passe",
     "Save" : "Guardar",
     "Edit" : "Editar",
     "Delete" : "Apagar",
-    "Password" : "Palavra-passe",
-    "API token" : "Token de API",
-    "Login" : "Iniciar sessão",
-    "Nickname" : "Alcunha",
-    "Client ID" : "Id. do Cliente",
     "Notifications" : "Notificações",
+    "Login" : "Iniciar sessão",
     "Remove from favorites" : "Remover de favoritos",
     "Add to favorites" : "Adicionar aos favoritos",
-    "Loading" : "A carregar",
+    "Create a new conversation" : "Criar nova conversa",
+    "Join open conversations" : "Juntar-me a conversas abertas",
+    "Clear filter" : "Limpar filtro",
+    "Users" : "Utilizadores",
     "Groups" : "Grupos",
-    "Circles" : "Círculos",
-    "Password protect" : "Proteger com palavra-passe",
-    "Close" : "Fechar",
-    "Conversation name" : "Nome da conversação",
-    "Done" : "Concluído",
+    "Teams" : "Grupos",
+    "Loading" : "A carregar",
+    "Talk settings" : "Definições do Falar",
+    "None" : "Nenhum",
     "Upload" : "Enviar",
     "Files" : "Ficheiros",
-    "Dismiss" : "Dispensar",
+    "Invalid path selected" : "Caminho inválido selecionado",
     "Reply" : "Resposta",
     "Translate" : "Traduzir",
+    "Message forwarded to \"Note to self\"" : "Mensagem reencaminhada para \"Nota a mim\"",
+    "Error while forwarding message to \"Note to self\"" : "Erro ao reencaminhar mensagem para \"Nota a mim\"",
+    "Dismiss" : "Dispensar",
     "Contact" : "Contacto",
     "No messages" : "Sem mensagens",
     "Today" : "Hoje",
     "Yesterday" : "Ontem",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás","%n dias atrás"],
+    "Create a new group conversation" : "Criar nova conversa de grupo",
+    "Close" : "Fechar",
+    "Password protect" : "Proteger com palavra-passe",
     "Send message" : "Enviar mensagem",
-    "Group" : "Grupo",
     "New file" : "Ficheiro novo",
     "Settings" : "Definições",
     "Send" : "Enviar",
@@ -296,6 +316,7 @@ OC.L10N.register(
     "guest" : "convidado",
     "Demote from moderator" : "Relegar de moderador",
     "Promote to moderator" : "Promover a moderador",
+    "Remove" : "Remover",
     "Remove participant" : "Remover participante",
     "Searching …" : "À procura …",
     "No results" : "Sem resultados",
@@ -303,10 +324,10 @@ OC.L10N.register(
     "Participants" : "Participantes",
     "Chat" : "Conversa",
     "Details" : "Detalhes",
+    "No shared items" : "Sem itens partilhados",
     "Privacy" : "Privacidade",
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Search" : "Pesquisa sobre",
-    "Open sidebar" : "Abrir barra lateral",
     "Screensharing options" : "Opções de partilha de ecrã",
     "Enable screensharing" : "Activar partilha de ecrã",
     "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
@@ -315,14 +336,21 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã.",
     "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
     "Grid view" : "Vista em grelha",
-    "Start a conversation" : "Iniciar uma conversação",
+    "Select a region" : "Selecione uma região",
+    "Submit" : "Submeter",
+    "User" : "Utilizador",
+    "Password" : "Palavra-passe",
+    "API token" : "Token de API",
+    "Nickname" : "Alcunha",
+    "Client ID" : "Id. do Cliente",
     "Media" : "Media",
     "Locations" : "Localizações",
     "Audio" : "Áudio",
     "Other" : "Outro",
+    "Group" : "Grupo",
+    "Error while sharing file" : "Erro ao partilhar ficheiro",
     "Do not disturb" : "Não incomodar",
     "Away" : "Ausente",
-    "Error while sharing file" : "Erro ao partilhar ficheiro",
     "Default" : "Predefinida",
     "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
     "Access to microphone & camera was denied" : "Acesso recusado ao microfone & câmera",
@@ -332,7 +360,7 @@ OC.L10N.register(
     "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
     "Android app" : "Aplicação Android",
     "iOS app" : "Aplicação iOS",
-    "More actions" : "Mais acções",
-    "Rename conversation" : "Renomear conversação"
+    "Circles" : "Círculos",
+    "Start a conversation" : "Iniciar uma conversação"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
