@@ -8,7 +8,10 @@ OC.L10N.register(
     "Invalid image" : "Figurë e pavlefshme",
     "Unknown filetype" : "Lloj i panjohur skedari",
     "Dismiss notification" : "Hiq lajmërimin",
+    "Accept" : "Prano",
+    "Decline" : "Refuzo",
     "Open settings" : "Hap rregullimet",
+    "error" : "gabim",
     "Conversations" : "Bisedat",
     "Avatar image is not square" : "Imazhi avatar nuk është katror",
     "Andorra" : "Andorra",
@@ -149,17 +152,19 @@ OC.L10N.register(
     "United States of America" : "Shtetet e Bashkuara të Amerikës",
     "Uruguay" : "Uruguaj",
     "Zambia" : "Zambia",
+    "Federation" : "Federim",
     "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
     "Leave call" : "Lini një thirrje",
     "Limit to groups" : "Kufizo grupet",
     "Everyone" : "Kushdo",
     "Save changes" : "Ruaj ndryshimet",
     "Saved!" : "I/E ruajtur!",
+    "State" : "Gjendja",
     "Name" : "Emri",
-    "None" : "Asnjë",
-    "User" : "Përdorues",
+    "Description" : "Përshkrim",
+    "Enabled" : "E aktivizuar",
     "Disabled" : "I çaktivizuar",
-    "Users" : "Përdoruesit",
+    "Permissions" : "Lejet",
     "General settings" : "Opsjonet e Pergjithshme",
     "Language" : "Gjuha",
     "Country" : "Vend",
@@ -172,9 +177,9 @@ OC.L10N.register(
     "OK" : "OK",
     "Checking …" : "Duke kontrolluar ...",
     "Back" : "Prapa",
+    "Cancel" : "Anullo",
     "Confirm" : "Konfirmo",
     "Reset" : "Rivendos",
-    "Cancel" : "Anullo",
     "Copy link" : "Kopjo linkun",
     "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
     "Mute audio" : "Mute audio",
@@ -182,59 +187,57 @@ OC.L10N.register(
     "You" : "Ju",
     "Collapse" : "Tkurre",
     "Favorite" : "I/E Preferuar",
-    "Description" : "Përshkrim",
+    "Hide details" : "Fsheh detajet",
+    "Disable" : "Çaktivizoje",
+    "Enable" : "Aktivizoje",
+    "Choose" : "Zgjidhni",
     "Restricted" : "I/E kufizuar",
     "Personal" : "Personale",
-    "Permissions" : "Lejet",
     "Leave conversation" : "Largohuni nga biseda",
+    "Yes" : "Po",
     "Delete conversation" : "Fshijeni bisedën",
-    "Submit" : "Dërgo",
     "Password protection" : "Password protection",
     "Save" : "Ruaj",
     "Edit" : "Përpuno",
     "Delete" : "Fshij",
-    "Password" : "Fjalëkalim",
-    "API token" : "Çelës identifikues i API-t ",
-    "Login" : "Hyrje",
-    "Nickname" : "Nofkë",
-    "Client ID" : "ID klienti",
+    "Log content" : "Përmbajtja e hyrjes",
     "Notifications" : "Njoftimet",
+    "Login" : "Hyrje",
     "Mark as read" : "Shënoje si të lexuar",
     "Mark as unread" : "Shënoje si të palexuar",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Shtoje tek të parapëlqyerat",
-    "Loading" : "Duke ngarkuar",
+    "Users" : "Përdoruesit",
     "Groups" : "Grupet",
-    "Circles" : "Rrethet",
-    "Password protect" : "Mbroje me fjalëkalim",
-    "Close" : "Mbylleni",
-    "Conversation name" : "Emri i bisedës",
+    "Loading" : "Duke ngarkuar",
+    "None" : "Asnjë",
     "Devices" : "Pajisjet",
-    "Done" : "U bë",
     "Upload" : "Ngarkoni",
     "Files" : "Skedarët",
     "Message sent" : "Mesazhi u dërgua",
-    "Dismiss" : "Hiq",
     "Reply" : "Përgjigju",
     "Translate" : "Përkthe",
+    "Dismiss" : "Hiq",
     "Contact" : "Kontakt",
     "Today" : "Sot",
     "Yesterday" : "Dje",
+    "_%n day ago_::_%n days ago_" : ["%n ditë më parë","%n ditë më parë"],
+    "Close" : "Mbylleni",
+    "Password protect" : "Mbroje me fjalëkalim",
     "Send message" : "Dërgo mesazh",
-    "Group" : "Grup",
     "Create new poll" : "Krijo sondazh të ri",
     "New file" : "Skedë e re",
     "Settings" : "Rregullimet",
     "Create poll" : "Krijo sondazh",
     "Send" : "Dërgo",
     "guest" : "vizitor",
+    "Remove" : "Hiqe",
     "No results" : "Asnjë rezultat",
     "Add users or groups" : "Add users or groups",
     "Details" : "Detajet",
     "Privacy" : "Privatësia",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Search" : "Kërko",
-    "Open sidebar" : "Hapni sidebar-in",
     "Show your screen" : "Shfaq ekranin tënd",
     "Stop screensharing" : "Ndalo ndarjen e ekranit",
     "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
@@ -243,11 +246,17 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
     "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
     "Grid view" : "Pamje galeri",
-    "Start a conversation" : "Filloni një bisedë",
+    "Submit" : "Dërgo",
+    "User" : "Përdorues",
+    "Password" : "Fjalëkalim",
+    "API token" : "Çelës identifikues i API-t ",
+    "Nickname" : "Nofkë",
+    "Client ID" : "ID klienti",
     "Media" : "Media",
     "Polls" : "Sondazhe",
     "Audio" : "Audio",
     "Other" : "Tjetër",
+    "Group" : "Grup",
     "Default" : "E paracaktuar",
     "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
     "Access to microphone & camera was denied" : "Aksesi tek mikrofoni & kamera u mohua",
@@ -255,11 +264,11 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Ju lutem zgjidhni një shfletues tjetër si Firefox apo Chrome",
     "Error while accessing microphone & camera" : "gabim ",
     "The password is wrong. Try again." : "Fjalëkalim i gabuar. Provojeni sërish.",
-    "TURN server" : "Serveri TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli.",
     "Android app" : "Aplikacion Android",
     "iOS app" : "Aplikacion iOS",
-    "More actions" : "Më tepër veprime ",
-    "Rename conversation" : "Riemërtojeni bisedën"
+    "Circles" : "Rrethet",
+    "Start a conversation" : "Filloni një bisedë",
+    "TURN server" : "Serveri TURN",
+    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli."
 },
 "nplurals=2; plural=(n != 1);");
