@@ -2,25 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Morris Jobke <hey@morrisjobke.de>
- *
- * @author Morris Jobke <hey@morrisjobke.de>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\BackgroundJob;
@@ -28,6 +11,7 @@ namespace OCA\Talk\BackgroundJob;
 use OCA\Talk\DataObjects\AccountId;
 use OCA\Talk\Exceptions\HostedSignalingServerAPIException;
 use OCA\Talk\Service\HostedSignalingServerService;
+use OCP\AppFramework\Http;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\BackgroundJob\IJob;
 use OCP\BackgroundJob\TimedJob;
@@ -39,21 +23,15 @@ use OCP\Notification\IManager;
 use Psr\Log\LoggerInterface;
 
 class CheckHostedSignalingServer extends TimedJob {
-	private HostedSignalingServerService $hostedSignalingServerService;
-	private IConfig $config;
-	private IManager $notificationManager;
-	private IGroupManager $groupManager;
-	private IURLGenerator $urlGenerator;
-	private LoggerInterface $logger;
 
 	public function __construct(
 		ITimeFactory $timeFactory,
-		HostedSignalingServerService $hostedSignalingServerService,
-		IConfig $config,
-		IManager $notificationManager,
-		IGroupManager $groupManager,
-		IURLGenerator $urlGenerator,
-		LoggerInterface $logger,
+		private HostedSignalingServerService $hostedSignalingServerService,
+		private IConfig $config,
+		private IManager $notificationManager,
+		private IGroupManager $groupManager,
+		private IURLGenerator $urlGenerator,
+		private LoggerInterface $logger,
 	) {
 		parent::__construct($timeFactory);
 
@@ -61,12 +39,6 @@ class CheckHostedSignalingServer extends TimedJob {
 		$this->setInterval(3600);
 		$this->setTimeSensitivity(IJob::TIME_SENSITIVE);
 
-		$this->hostedSignalingServerService = $hostedSignalingServerService;
-		$this->config = $config;
-		$this->notificationManager = $notificationManager;
-		$this->groupManager = $groupManager;
-		$this->urlGenerator = $urlGenerator;
-		$this->logger = $logger;
 	}
 
 	protected function run($argument): void {
@@ -79,9 +51,17 @@ class CheckHostedSignalingServer extends TimedJob {
 		$accountId = new AccountId($accountId);
 		try {
 			$accountInfo = $this->hostedSignalingServerService->fetchAccountInfo($accountId);
-		} catch (HostedSignalingServerAPIException $e) { // API or connection issues
-			// do nothing and just try again later
-			return;
+		} catch (HostedSignalingServerAPIException $e) {
+			if ($e->getCode() === Http::STATUS_NOT_FOUND) {
+				// Account was deleted, so remove the information locally
+				$accountInfo = ['status' => 'deleted'];
+			} elseif ($e->getCode() === Http::STATUS_UNAUTHORIZED) {
+				// Account is expired and deletion is pending unless it's reactivated.
+				$accountInfo = ['status' => 'expired'];
+			} else {
+				// API or connection issues - do nothing and just try again later
+				return;
+			}
 		}
 
 		$oldStatus = $oldAccountInfo['status'] ?? '';
@@ -92,15 +72,13 @@ class CheckHostedSignalingServer extends TimedJob {
 
 		// the status has changed
 		if ($oldStatus !== $newStatus) {
-			if ($oldStatus === 'active') {
+			if ($newStatus === 'deleted') {
 				// remove signaling servers if account is not active anymore
 				$this->config->deleteAppValue('spreed', 'signaling_mode');
 				$this->config->deleteAppValue('spreed', 'signaling_servers');
 
 				$notificationSubject = 'removed';
-			}
-
-			if ($newStatus === 'active') {
+			} elseif ($newStatus === 'active') {
 				// add signaling servers if account got active
 				$this->config->deleteAppValue('spreed', 'signaling_mode');
 				$this->config->setAppValue('spreed', 'signaling_servers', json_encode([
