@@ -2,24 +2,8 @@
 
 declare(strict_types=1);
 /**
- *
- * @copyright Copyright (c) 2017, Daniel Calviño Sánchez (danxuliu@gmail.com)
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Chat;
@@ -27,10 +11,16 @@ namespace OCA\Talk\Chat;
 use DateInterval;
 use OC\Memcache\ArrayCache;
 use OC\Memcache\NullCache;
-use OCA\Talk\Events\ChatEvent;
-use OCA\Talk\Events\ChatParticipantEvent;
+use OCA\Talk\CachePrefix;
+use OCA\Talk\Events\BeforeChatMessageSentEvent;
+use OCA\Talk\Events\BeforeSystemMessageSentEvent;
+use OCA\Talk\Events\ChatMessageSentEvent;
+use OCA\Talk\Events\SystemMessageSentEvent;
+use OCA\Talk\Exceptions\InvalidRoomException;
+use OCA\Talk\Exceptions\MessagingNotAllowedException;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Model\Attendee;
+use OCA\Talk\Model\Message;
 use OCA\Talk\Model\Poll;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
@@ -43,17 +33,22 @@ use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Collaboration\Reference\IReferenceManager;
 use OCP\Comments\IComment;
-use OCP\Comments\ICommentsManager;
+use OCP\Comments\MessageTooLongException;
 use OCP\Comments\NotFoundException;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\ICache;
 use OCP\ICacheFactory;
 use OCP\IDBConnection;
+use OCP\IL10N;
+use OCP\IRequest;
 use OCP\IUser;
 use OCP\Notification\IManager as INotificationManager;
+use OCP\Security\RateLimiting\ILimiter;
+use OCP\Security\RateLimiting\IRateLimitExceededException;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IManager;
 use OCP\Share\IShare;
+use Psr\Log\LoggerInterface;
 
 /**
  * Basic polling chat manager.
@@ -66,14 +61,11 @@ use OCP\Share\IShare;
  * pending notifications are removed if the messages are deleted.
  */
 class ChatManager {
-	public const EVENT_BEFORE_SYSTEM_MESSAGE_SEND = self::class . '::preSendSystemMessage';
-	public const EVENT_AFTER_SYSTEM_MESSAGE_SEND = self::class . '::postSendSystemMessage';
-	public const EVENT_AFTER_MULTIPLE_SYSTEM_MESSAGE_SEND = self::class . '::postSendMultipleSystemMessage';
-	public const EVENT_BEFORE_MESSAGE_SEND = self::class . '::preSendMessage';
-	public const EVENT_AFTER_MESSAGE_SEND = self::class . '::postSendMessage';
-
 	public const MAX_CHAT_LENGTH = 32000;
 
+	public const RATE_LIMIT_GUEST_MENTIONS_LIMIT = 50;
+	public const RATE_LIMIT_GUEST_MENTIONS_PERIOD = 24 * 60 * 60;
+
 	public const GEO_LOCATION_VALIDATOR = '/^geo:-?\d{1,2}(\.\d+)?,-?\d{1,3}(\.\d+)?(,-?\d+(\.\d+)?)?(;crs=wgs84)?(;u=\d+(\.\d+)?)?$/i';
 	public const VERB_MESSAGE = 'comment';
 	public const VERB_SYSTEM = 'system';
@@ -82,73 +74,64 @@ class ChatManager {
 	public const VERB_MESSAGE_DELETED = 'comment_deleted';
 	public const VERB_REACTION = 'reaction';
 	public const VERB_REACTION_DELETED = 'reaction_deleted';
+	public const VERB_VOICE_MESSAGE = 'voice-message';
+	public const VERB_RECORD_AUDIO = 'record-audio';
+	public const VERB_RECORD_VIDEO = 'record-video';
+
+	/**
+	 * Last read message ID of -1 is set on the attendee table as default.
+	 * The real value is inserted on user request after the migration from
+	 * `comments_read_markers` to `talk_attendees` with @see Version7000Date20190724121136
+	 *
+	 * @since 21.0.0 (But -1 was used in the database since 7.0.0)
+	 */
+	public const UNREAD_MIGRATION = -1;
+
+	/**
+	 * Frontend and Desktop don't get chat context with ID 0,
+	 * so we collectively tested and decided that -2 should be used instead,
+	 * when marking the first message in a chat as unread.
+	 *
+	 * @since 21.0.0
+	 */
+	public const UNREAD_FIRST_MESSAGE = -2;
 
-	private CommentsManager $commentsManager;
-	private IEventDispatcher $dispatcher;
-	private IDBConnection $connection;
-	private INotificationManager $notificationManager;
-	private IManager $shareManager;
-	private RoomShareProvider $shareProvider;
-	private ParticipantService $participantService;
-	private RoomService $roomService;
-	private PollService $pollService;
-	private Notifier $notifier;
-	protected ITimeFactory $timeFactory;
 	protected ICache $cache;
 	protected ICache $unreadCountCache;
-	protected AttachmentService $attachmentService;
-	protected IReferenceManager $referenceManager;
 
 	public function __construct(
-		CommentsManager $commentsManager,
-		IEventDispatcher $dispatcher,
-		IDBConnection $connection,
-		INotificationManager $notificationManager,
-		IManager $shareManager,
-		RoomShareProvider $shareProvider,
-		ParticipantService $participantService,
-		RoomService $roomService,
-		PollService $pollService,
-		Notifier $notifier,
+		private CommentsManager $commentsManager,
+		private IEventDispatcher $dispatcher,
+		private IDBConnection $connection,
+		private INotificationManager $notificationManager,
+		private IManager $shareManager,
+		private RoomShareProvider $shareProvider,
+		private ParticipantService $participantService,
+		private RoomService $roomService,
+		private PollService $pollService,
+		private Notifier $notifier,
 		ICacheFactory $cacheFactory,
-		ITimeFactory $timeFactory,
-		AttachmentService $attachmentService,
-		IReferenceManager $referenceManager,
+		protected ITimeFactory $timeFactory,
+		protected AttachmentService $attachmentService,
+		protected IReferenceManager $referenceManager,
+		protected ILimiter $rateLimiter,
+		protected IRequest $request,
+		protected IL10N $l,
+		protected LoggerInterface $logger,
 	) {
-		$this->commentsManager = $commentsManager;
-		$this->dispatcher = $dispatcher;
-		$this->connection = $connection;
-		$this->notificationManager = $notificationManager;
-		$this->shareManager = $shareManager;
-		$this->shareProvider = $shareProvider;
-		$this->participantService = $participantService;
-		$this->roomService = $roomService;
-		$this->pollService = $pollService;
-		$this->notifier = $notifier;
-		$this->cache = $cacheFactory->createDistributed('talk/lastmsgid');
-		$this->unreadCountCache = $cacheFactory->createDistributed('talk/unreadcount');
-		$this->timeFactory = $timeFactory;
-		$this->attachmentService = $attachmentService;
-		$this->referenceManager = $referenceManager;
+		$this->cache = $cacheFactory->createDistributed(CachePrefix::CHAT_LAST_MESSAGE_ID);
+		$this->unreadCountCache = $cacheFactory->createDistributed(CachePrefix::CHAT_UNREAD_COUNT);
 	}
 
 	/**
 	 * Sends a new message to the given chat.
 	 *
-	 * @param Room $chat
-	 * @param string $actorType
-	 * @param string $actorId
-	 * @param string $message
-	 * @param \DateTime $creationDateTime
-	 * @param bool $sendNotifications
-	 * @param string|null $referenceId
-	 * @param int|null $parentId
 	 * @param bool $shouldSkipLastMessageUpdate If multiple messages will be posted
-	 *             (e.g. when adding multiple users to a room) we can skip the last
-	 *             message and last activity update until the last entry was created
-	 *             and then update with those values.
-	 *             This will replace O(n) with 1 database update.
-	 * @return IComment
+	 *                                          (e.g. when adding multiple users to a room) we can skip the last
+	 *                                          message and last activity update until the last entry was created
+	 *                                          and then update with those values.
+	 *                                          This will replace O(n) with 1 database update.
+	 * @throws MessagingNotAllowedException
 	 */
 	public function addSystemMessage(
 		Room $chat,
@@ -158,10 +141,17 @@ class ChatManager {
 		\DateTime $creationDateTime,
 		bool $sendNotifications,
 		?string $referenceId = null,
-		?int $parentId = null,
-		bool $shouldSkipLastMessageUpdate = false
+		?IComment $replyTo = null,
+		bool $shouldSkipLastMessageUpdate = false,
+		bool $silent = false,
 	): IComment {
-		$comment = $this->commentsManager->create($actorType, $actorId, 'chat', (string) $chat->getId());
+		if ($chat->isFederatedConversation()) {
+			$e = new MessagingNotAllowedException();
+			$this->logger->error('Attempt to post system message into proxy conversation', ['exception' => $e]);
+			throw $e;
+		}
+
+		$comment = $this->commentsManager->create($actorType, $actorId, 'chat', (string)$chat->getId());
 		$comment->setMessage($message, self::MAX_CHAT_LENGTH);
 		$comment->setCreationDateTime($creationDateTime);
 		if ($referenceId !== null) {
@@ -170,8 +160,8 @@ class ChatManager {
 				$comment->setReferenceId($referenceId);
 			}
 		}
-		if ($parentId !== null) {
-			$comment->setParentId((string) $parentId);
+		if ($replyTo !== null) {
+			$comment->setParentId($replyTo->getId());
 		}
 
 		$messageDecoded = json_decode($message, true);
@@ -183,10 +173,18 @@ class ChatManager {
 			$comment->setVerb(self::VERB_SYSTEM);
 		}
 
+		if ($silent) {
+			$comment->setMetaData([
+				Message::METADATA_SILENT => true,
+			]);
+		}
+
 		$this->setMessageExpiration($chat, $comment);
 
-		$event = new ChatEvent($chat, $comment, $shouldSkipLastMessageUpdate);
-		$this->dispatcher->dispatch(self::EVENT_BEFORE_SYSTEM_MESSAGE_SEND, $event);
+		$shouldFlush = $this->notificationManager->defer();
+
+		$event = new BeforeSystemMessageSentEvent($chat, $comment, silent: $silent, parent: $replyTo, skipLastActivityUpdate: $shouldSkipLastMessageUpdate);
+		$this->dispatcher->dispatchTyped($event);
 		try {
 			$this->commentsManager->save($comment);
 
@@ -197,7 +195,36 @@ class ChatManager {
 			}
 
 			if ($sendNotifications) {
-				$this->notifier->notifyOtherParticipant($chat, $comment, [], false);
+				/** @var ?IComment $captionComment */
+				$captionComment = null;
+				$alreadyNotifiedUsers = $usersDirectlyMentioned = $federatedUsersDirectlyMentioned = [];
+				if ($messageType === 'file_shared') {
+					if (isset($messageDecoded['parameters']['metaData']['caption'])) {
+						$captionComment = clone $comment;
+						$captionComment->setMessage($messageDecoded['parameters']['metaData']['caption'], self::MAX_CHAT_LENGTH);
+						$usersDirectlyMentioned = $this->notifier->getMentionedUserIds($captionComment);
+						$federatedUsersDirectlyMentioned = $this->notifier->getMentionedCloudIds($captionComment);
+					}
+					if ($replyTo instanceof IComment) {
+						$alreadyNotifiedUsers = $this->notifier->notifyReplyToAuthor($chat, $comment, $replyTo, $silent);
+						if ($replyTo->getActorType() === Attendee::ACTOR_USERS) {
+							$usersDirectlyMentioned[] = $replyTo->getActorId();
+						} elseif ($replyTo->getActorType() === Attendee::ACTOR_FEDERATED_USERS) {
+							$federatedUsersDirectlyMentioned[] = $replyTo->getActorId();
+						}
+					}
+				}
+
+				$alreadyNotifiedUsers = $this->notifier->notifyMentionedUsers($chat, $captionComment ?? $comment, $alreadyNotifiedUsers, $silent);
+				if (!empty($alreadyNotifiedUsers)) {
+					$userIds = array_column($alreadyNotifiedUsers, 'id');
+					$this->participantService->markUsersAsMentioned($chat, Attendee::ACTOR_USERS, $userIds, (int)$comment->getId(), $usersDirectlyMentioned);
+				}
+				if (!empty($federatedUsersDirectlyMentioned)) {
+					$this->participantService->markUsersAsMentioned($chat, Attendee::ACTOR_FEDERATED_USERS, $federatedUsersDirectlyMentioned, (int)$comment->getId(), $federatedUsersDirectlyMentioned);
+				}
+
+				$this->notifier->notifyOtherParticipant($chat, $comment, [], $silent);
 			}
 
 			if (!$shouldSkipLastMessageUpdate && $sendNotifications) {
@@ -205,17 +232,22 @@ class ChatManager {
 				// e.g. sharing an item to the chat
 				try {
 					$participant = $this->participantService->getParticipantByActor($chat, $actorType, $actorId);
-					$this->participantService->updateLastReadMessage($participant, (int) $comment->getId());
+					$this->participantService->updateLastReadMessage($participant, (int)$comment->getId());
 				} catch (ParticipantNotFoundException) {
 					// Participant not found => No read-marker update needed
 				}
 			}
 
-			$this->dispatcher->dispatch(self::EVENT_AFTER_SYSTEM_MESSAGE_SEND, $event);
+			$event = new SystemMessageSentEvent($chat, $comment, silent: $silent, parent: $replyTo, skipLastActivityUpdate: $shouldSkipLastMessageUpdate);
+			$this->dispatcher->dispatchTyped($event);
 		} catch (NotFoundException $e) {
 		}
 		$this->cache->remove($chat->getToken());
 
+		if ($shouldFlush) {
+			$this->notificationManager->flush();
+		}
+
 		if ($messageType === 'object_shared' || $messageType === 'file_shared') {
 			$this->attachmentService->createAttachmentEntry($chat, $comment, $messageType, $messageDecoded['parameters'] ?? []);
 		}
@@ -231,14 +263,14 @@ class ChatManager {
 	 * @return IComment
 	 */
 	public function addChangelogMessage(Room $chat, string $message): IComment {
-		$comment = $this->commentsManager->create(Attendee::ACTOR_GUESTS, 'changelog', 'chat', (string) $chat->getId());
+		$comment = $this->commentsManager->create(Attendee::ACTOR_GUESTS, Attendee::ACTOR_ID_CHANGELOG, 'chat', (string)$chat->getId());
 
 		$comment->setMessage($message, self::MAX_CHAT_LENGTH);
 		$comment->setCreationDateTime($this->timeFactory->getDateTime());
-		$comment->setVerb(self::VERB_MESSAGE); // Has to be comment, so it counts as unread message
+		$comment->setVerb(self::VERB_MESSAGE); // Has to be 'comment', so it counts as unread message
 
-		$event = new ChatEvent($chat, $comment);
-		$this->dispatcher->dispatch(self::EVENT_BEFORE_SYSTEM_MESSAGE_SEND, $event);
+		$event = new BeforeSystemMessageSentEvent($chat, $comment);
+		$this->dispatcher->dispatchTyped($event);
 		try {
 			$this->commentsManager->save($comment);
 
@@ -246,7 +278,8 @@ class ChatManager {
 			$this->roomService->setLastMessage($chat, $comment);
 			$this->unreadCountCache->clear($chat->getId() . '-');
 
-			$this->dispatcher->dispatch(self::EVENT_AFTER_SYSTEM_MESSAGE_SEND, $event);
+			$event = new SystemMessageSentEvent($chat, $comment);
+			$this->dispatcher->dispatchTyped($event);
 		} catch (NotFoundException $e) {
 		}
 		$this->cache->remove($chat->getToken());
@@ -257,18 +290,29 @@ class ChatManager {
 	/**
 	 * Sends a new message to the given chat.
 	 *
-	 * @param Room $chat
-	 * @param Participant $participant
-	 * @param string $actorType
-	 * @param string $actorId
-	 * @param string $message
-	 * @param \DateTime $creationDateTime
-	 * @param IComment|null $replyTo
-	 * @param string $referenceId
-	 * @return IComment
+	 * @throws IRateLimitExceededException Only when $rateLimitGuestMentions is true and the author is a guest participant
+	 * @throws MessageTooLongException
+	 * @throws MessagingNotAllowedException
 	 */
-	public function sendMessage(Room $chat, Participant $participant, string $actorType, string $actorId, string $message, \DateTime $creationDateTime, ?IComment $replyTo, string $referenceId, bool $silent): IComment {
-		$comment = $this->commentsManager->create($actorType, $actorId, 'chat', (string) $chat->getId());
+	public function sendMessage(
+		Room $chat,
+		?Participant $participant,
+		string $actorType,
+		string $actorId,
+		string $message,
+		\DateTime $creationDateTime,
+		?IComment $replyTo = null,
+		string $referenceId = '',
+		bool $silent = false,
+		bool $rateLimitGuestMentions = true,
+	): IComment {
+		if ($chat->isFederatedConversation()) {
+			$e = new MessagingNotAllowedException();
+			$this->logger->error('Attempt to post system message into proxy conversation', ['exception' => $e]);
+			throw $e;
+		}
+
+		$comment = $this->commentsManager->create($actorType, $actorId, 'chat', (string)$chat->getId());
 		$comment->setMessage($message, self::MAX_CHAT_LENGTH);
 		$comment->setCreationDateTime($creationDateTime);
 		// A verb ('comment', 'like'...) must be provided to be able to save a
@@ -285,17 +329,42 @@ class ChatManager {
 		}
 		$this->setMessageExpiration($chat, $comment);
 
-		$event = new ChatParticipantEvent($chat, $comment, $participant, $silent);
-		$this->dispatcher->dispatch(self::EVENT_BEFORE_MESSAGE_SEND, $event);
+		if ($rateLimitGuestMentions && $participant instanceof Participant && $participant->isGuest()) {
+			$mentions = $comment->getMentions();
+			if (!empty($mentions)) {
+				$this->rateLimiter->registerAnonRequest(
+					'talk-mentions',
+					self::RATE_LIMIT_GUEST_MENTIONS_LIMIT,
+					self::RATE_LIMIT_GUEST_MENTIONS_PERIOD,
+					$this->request->getRemoteAddress(),
+				);
+			}
+		}
+
+		$metadata = [];
+		if ($silent) {
+			$metadata[Message::METADATA_SILENT] = true;
+		}
+		if ($chat->getMentionPermissions() === Room::MENTION_PERMISSIONS_EVERYONE || $participant?->hasModeratorPermissions()) {
+			$metadata[Message::METADATA_CAN_MENTION_ALL] = true;
+		}
+		$comment->setMetaData($metadata);
+
+		$event = new BeforeChatMessageSentEvent($chat, $comment, $participant, $silent, $replyTo);
+		$this->dispatcher->dispatchTyped($event);
 
 		$shouldFlush = $this->notificationManager->defer();
 		try {
 			$this->commentsManager->save($comment);
 
-			$this->participantService->updateLastReadMessage($participant, (int) $comment->getId());
+			if ($participant instanceof Participant) {
+				$this->participantService->updateLastReadMessage($participant, (int)$comment->getId());
+			}
 
 			// Update last_message
-			if ($comment->getActorType() !== 'bots' || $comment->getActorId() === 'changelog') {
+			if ($comment->getActorType() !== Attendee::ACTOR_BOTS
+				|| $comment->getActorId() === Attendee::ACTOR_ID_CHANGELOG
+				|| str_starts_with($comment->getActorId(), Attendee::ACTOR_BOT_PREFIX)) {
 				$this->roomService->setLastMessage($chat, $comment);
 				$this->unreadCountCache->clear($chat->getId() . '-');
 			} else {
@@ -304,23 +373,30 @@ class ChatManager {
 
 			$alreadyNotifiedUsers = [];
 			$usersDirectlyMentioned = $this->notifier->getMentionedUserIds($comment);
+			$federatedUsersDirectlyMentioned = $this->notifier->getMentionedCloudIds($comment);
 			if ($replyTo instanceof IComment) {
 				$alreadyNotifiedUsers = $this->notifier->notifyReplyToAuthor($chat, $comment, $replyTo, $silent);
 				if ($replyTo->getActorType() === Attendee::ACTOR_USERS) {
 					$usersDirectlyMentioned[] = $replyTo->getActorId();
+				} elseif ($replyTo->getActorType() === Attendee::ACTOR_FEDERATED_USERS) {
+					$federatedUsersDirectlyMentioned[] = $replyTo->getActorId();
 				}
 			}
 
-			$alreadyNotifiedUsers = $this->notifier->notifyMentionedUsers($chat, $comment, $alreadyNotifiedUsers, $silent);
+			$alreadyNotifiedUsers = $this->notifier->notifyMentionedUsers($chat, $comment, $alreadyNotifiedUsers, $silent, $participant);
 			if (!empty($alreadyNotifiedUsers)) {
 				$userIds = array_column($alreadyNotifiedUsers, 'id');
-				$this->participantService->markUsersAsMentioned($chat, $userIds, (int) $comment->getId(), $usersDirectlyMentioned);
+				$this->participantService->markUsersAsMentioned($chat, Attendee::ACTOR_USERS, $userIds, (int)$comment->getId(), $usersDirectlyMentioned);
+			}
+			if (!empty($federatedUsersDirectlyMentioned)) {
+				$this->participantService->markUsersAsMentioned($chat, Attendee::ACTOR_FEDERATED_USERS, $federatedUsersDirectlyMentioned, (int)$comment->getId(), $federatedUsersDirectlyMentioned);
 			}
 
 			// User was not mentioned, send a normal notification
 			$this->notifier->notifyOtherParticipant($chat, $comment, $alreadyNotifiedUsers, $silent);
 
-			$this->dispatcher->dispatch(self::EVENT_AFTER_MESSAGE_SEND, $event);
+			$event = new ChatMessageSentEvent($chat, $comment, $participant, $silent, $replyTo);
+			$this->dispatcher->dispatchTyped($event);
 		} catch (NotFoundException $e) {
 		}
 		$this->cache->remove($chat->getToken());
@@ -373,9 +449,6 @@ class ChatManager {
 	}
 
 	/**
-	 * @param Room $room
-	 * @param Participant $participant
-	 * @param array $messageData
 	 * @throws ShareNotFound
 	 */
 	public function removePollOnMessageDelete(Room $room, Participant $participant, array $messageData, \DateTime $deletionTime): void {
@@ -405,7 +478,7 @@ class ChatManager {
 					],
 				], JSON_THROW_ON_ERROR),
 				'chat',
-				[(string) $room->getId()],
+				[(string)$room->getId()],
 				'system',
 				0
 			);
@@ -449,12 +522,25 @@ class ChatManager {
 			])
 		);
 		$comment->setVerb(self::VERB_MESSAGE_DELETED);
+
+		$metaData = $comment->getMetaData() ?? [];
+		if (isset($metaData[Message::METADATA_LAST_EDITED_BY_TYPE])) {
+			unset(
+				$metaData[Message::METADATA_LAST_EDITED_BY_TYPE],
+				$metaData[Message::METADATA_LAST_EDITED_BY_ID],
+				$metaData[Message::METADATA_LAST_EDITED_TIME],
+			);
+			$comment->setMetaData($metaData);
+		}
+
 		$this->commentsManager->save($comment);
 
-		$this->attachmentService->deleteAttachmentByMessageId((int) $comment->getId());
+		$this->attachmentService->deleteAttachmentByMessageId((int)$comment->getId());
 
 		$this->referenceManager->invalidateCache($chat->getToken());
 
+		$this->unreadCountCache->clear($chat->getId() . '-');
+
 		return $this->addSystemMessage(
 			$chat,
 			$participant->getAttendee()->getActorType(),
@@ -463,13 +549,109 @@ class ChatManager {
 			$this->timeFactory->getDateTime(),
 			false,
 			null,
-			(int) $comment->getId(),
+			$comment,
 			true
 		);
 	}
 
+	/**
+	 * @param Room $chat
+	 * @param IComment $comment
+	 * @param Participant $participant
+	 * @param \DateTime $editTime
+	 * @param string $message
+	 * @return IComment
+	 * @throws MessageTooLongException
+	 * @throws \InvalidArgumentException When the message is empty or the shared object is not a file share with caption
+	 */
+	public function editMessage(Room $chat, IComment $comment, Participant $participant, \DateTime $editTime, string $message): IComment {
+		if (trim($message) === '') {
+			throw new \InvalidArgumentException('message');
+		}
+
+		if ($comment->getVerb() === ChatManager::VERB_OBJECT_SHARED) {
+			$messageData = json_decode($comment->getMessage(), true);
+			if (!isset($messageData['message']) || $messageData['message'] !== 'file_shared') {
+				// Not a file share
+				throw new \InvalidArgumentException('object_share');
+			}
+
+			$messageData['parameters'] ??= [];
+			$messageData['parameters']['metaData'] ??= [];
+			$messageData['parameters']['metaData']['caption'] = $message;
+			$message = json_encode($messageData);
+		}
+
+		$metaData = $comment->getMetaData() ?? [];
+		$metaData[Message::METADATA_LAST_EDITED_BY_TYPE] = $participant->getAttendee()->getActorType();
+		$metaData[Message::METADATA_LAST_EDITED_BY_ID] = $participant->getAttendee()->getActorId();
+		$metaData[Message::METADATA_LAST_EDITED_TIME] = $editTime->getTimestamp();
+		$comment->setMetaData($metaData);
+
+		$wasSilent = $metaData[Message::METADATA_SILENT] ?? false;
+
+		if (!$wasSilent) {
+			$mentionsBefore = $comment->getMentions();
+			$usersDirectlyMentionedBefore = $this->notifier->getMentionedUserIds($comment);
+			$usersToNotifyBefore = $this->notifier->getUsersToNotify($chat, $comment, []);
+		}
+		$comment->setMessage($message, self::MAX_CHAT_LENGTH);
+		if (!$wasSilent) {
+			$mentionsAfter = $comment->getMentions();
+		}
+
+		$this->commentsManager->save($comment);
+		$this->referenceManager->invalidateCache($chat->getToken());
+
+		if (!$wasSilent) {
+			$removedMentions = empty($mentionsAfter) ? $mentionsBefore : array_udiff($mentionsBefore, $mentionsAfter, [$this, 'compareMention']);
+			$addedMentions = empty($mentionsBefore) ? $mentionsAfter : array_udiff($mentionsAfter, $mentionsBefore, [$this, 'compareMention']);
+
+			if (!empty($removedMentions)) {
+				$usersToNotifyAfter = $this->notifier->getUsersToNotify($chat, $comment, []);
+				$removedUsersMentioned = array_udiff($usersToNotifyBefore, $usersToNotifyAfter, [$this, 'compareMention']);
+				$userIds = array_column($removedUsersMentioned, 'id');
+				$this->notifier->removeMentionNotificationAfterEdit($chat, $comment, $userIds);
+			}
+
+			if (!empty($addedMentions)) {
+				$usersDirectlyMentionedAfter = $this->notifier->getMentionedUserIds($comment);
+				$federatedUsersDirectlyMentionedAfter = $this->notifier->getMentionedCloudIds($comment);
+				$addedUsersDirectMentioned = array_diff($usersDirectlyMentionedAfter, $usersDirectlyMentionedBefore);
+
+				$alreadyNotifiedUsers = $this->notifier->notifyMentionedUsers($chat, $comment, $usersToNotifyBefore, silent: false);
+				if (!empty($alreadyNotifiedUsers)) {
+					$userIds = array_column($alreadyNotifiedUsers, 'id');
+					$this->participantService->markUsersAsMentioned($chat, Attendee::ACTOR_USERS, $userIds, (int)$comment->getId(), $addedUsersDirectMentioned);
+				}
+				if (!empty($federatedUsersDirectlyMentionedAfter)) {
+					$this->participantService->markUsersAsMentioned($chat, Attendee::ACTOR_FEDERATED_USERS, $federatedUsersDirectlyMentionedAfter, (int)$comment->getId(), $federatedUsersDirectlyMentionedAfter);
+				}
+			}
+		}
+
+		return $this->addSystemMessage(
+			$chat,
+			$participant->getAttendee()->getActorType(),
+			$participant->getAttendee()->getActorId(),
+			json_encode(['message' => 'message_edited', 'parameters' => ['message' => $comment->getId()]]),
+			$this->timeFactory->getDateTime(),
+			false,
+			null,
+			$comment,
+			true
+		);
+	}
+
+	protected static function compareMention(array $mention1, array $mention2): int {
+		if ($mention1['type'] === $mention2['type']) {
+			return $mention1['id'] <=> $mention2['id'];
+		}
+		return $mention1['type'] <=> $mention2['type'];
+	}
+
 	public function clearHistory(Room $chat, string $actorType, string $actorId): IComment {
-		$this->commentsManager->deleteCommentsAtObject('chat', (string) $chat->getId());
+		$this->commentsManager->deleteCommentsAtObject('chat', (string)$chat->getId());
 
 		$this->shareProvider->deleteInRoom($chat->getToken());
 
@@ -498,7 +680,7 @@ class ChatManager {
 	public function getParentComment(Room $chat, string $parentId): IComment {
 		$comment = $this->commentsManager->get($parentId);
 
-		if ($comment->getObjectType() !== 'chat' || $comment->getObjectId() !== (string) $chat->getId()) {
+		if ($comment->getObjectType() !== 'chat' || $comment->getObjectId() !== (string)$chat->getId()) {
 			throw new NotFoundException('Parent not found in the right context');
 		}
 
@@ -512,9 +694,13 @@ class ChatManager {
 	 * @throws NotFoundException
 	 */
 	public function getComment(Room $chat, string $messageId): IComment {
+		if ($chat->isFederatedConversation()) {
+			throw new InvalidRoomException('Can not call ChatManager::getComment() with a federated chat.');
+		}
+
 		$comment = $this->commentsManager->get($messageId);
 
-		if ($comment->getObjectType() !== 'chat' || $comment->getObjectId() !== (string) $chat->getId()) {
+		if ($comment->getObjectType() !== 'chat' || $comment->getObjectId() !== (string)$chat->getId()) {
 			throw new NotFoundException('Message not found in the right context');
 		}
 
@@ -522,12 +708,12 @@ class ChatManager {
 	}
 
 	public function getLastReadMessageFromLegacy(Room $chat, IUser $user): int {
-		$marker = $this->commentsManager->getReadMark('chat', (string) $chat->getId(), $user);
+		$marker = $this->commentsManager->getReadMark('chat', (string)$chat->getId(), $user);
 		if ($marker === null) {
 			return 0;
 		}
 
-		return $this->commentsManager->getLastCommentBeforeDate('chat', (string) $chat->getId(), $marker, self::VERB_MESSAGE);
+		return $this->commentsManager->getLastCommentBeforeDate('chat', (string)$chat->getId(), $marker, self::VERB_MESSAGE);
 	}
 
 	public function getUnreadCount(Room $chat, int $lastReadMessage): int {
@@ -539,7 +725,7 @@ class ChatManager {
 		$key = $chat->getId() . '-' . $lastReadMessage;
 		$unreadCount = $this->unreadCountCache->get($key);
 		if ($unreadCount === null) {
-			$unreadCount = $this->commentsManager->getNumberOfCommentsWithVerbsForObjectSinceComment('chat', (string) $chat->getId(), $lastReadMessage, [self::VERB_MESSAGE, 'object_shared']);
+			$unreadCount = $this->commentsManager->getNumberOfCommentsWithVerbsForObjectSinceComment('chat', (string)$chat->getId(), $lastReadMessage, [self::VERB_MESSAGE, self::VERB_OBJECT_SHARED]);
 			$this->unreadCountCache->set($key, $unreadCount, 1800);
 		}
 		return $unreadCount;
@@ -564,11 +750,11 @@ class ChatManager {
 	 * @param int $limit
 	 * @param bool $includeLastKnown
 	 * @return IComment[] the messages found (only the id, actor type and id,
-	 *         creation date and message are relevant), or an empty array if the
-	 *         timeout expired.
+	 *                    creation date and message are relevant), or an empty array if the
+	 *                    timeout expired.
 	 */
 	public function getHistory(Room $chat, int $offset, int $limit, bool $includeLastKnown): array {
-		return $this->commentsManager->getForObjectSince('chat', (string) $chat->getId(), $offset, 'desc', $limit, $includeLastKnown);
+		return $this->commentsManager->getForObjectSince('chat', (string)$chat->getId(), $offset, 'desc', $limit, $includeLastKnown);
 	}
 
 	/**
@@ -582,7 +768,7 @@ class ChatManager {
 	public function getPreviousMessageWithVerb(Room $chat, int $offset, array $verbs, bool $offsetIsVerbMatch): IComment {
 		$messages = $this->commentsManager->getCommentsWithVerbForObjectSinceComment(
 			'chat',
-			(string) $chat->getId(),
+			(string)$chat->getId(),
 			$verbs,
 			$offset,
 			'desc',
@@ -614,8 +800,8 @@ class ChatManager {
 	 * @param bool $includeLastKnown
 	 * @param bool $markNotificationsAsRead (defaults to true)
 	 * @return IComment[] the messages found (only the id, actor type and id,
-	 *         creation date and message are relevant), or an empty array if the
-	 *         timeout expired.
+	 *                    creation date and message are relevant), or an empty array if the
+	 *                    timeout expired.
 	 */
 	public function waitForNewMessages(Room $chat, int $offset, int $limit, int $timeout, ?IUser $user, bool $includeLastKnown, bool $markNotificationsAsRead = true): array {
 		if ($markNotificationsAsRead && $user instanceof IUser) {
@@ -673,7 +859,7 @@ class ChatManager {
 		}
 
 		// Load data from the database
-		$comments = $this->commentsManager->getForObjectSince('chat', (string) $chat->getId(), $offset, 'asc', $limit, $includeLastKnown);
+		$comments = $this->commentsManager->getForObjectSince('chat', (string)$chat->getId(), $offset, 'asc', $limit, $includeLastKnown);
 
 		if (empty($comments)) {
 			// We only write the cache when there were no new comments,
@@ -699,13 +885,13 @@ class ChatManager {
 	protected function waitForNewMessagesWithDatabase(Room $chat, int $offset, int $limit, int $timeout, bool $includeLastKnown): array {
 		$elapsedTime = 0;
 
-		$comments = $this->commentsManager->getForObjectSince('chat', (string) $chat->getId(), $offset, 'asc', $limit, $includeLastKnown);
+		$comments = $this->commentsManager->getForObjectSince('chat', (string)$chat->getId(), $offset, 'asc', $limit, $includeLastKnown);
 
 		while (empty($comments) && $elapsedTime < $timeout) {
 			sleep(1);
 			$elapsedTime++;
 
-			$comments = $this->commentsManager->getForObjectSince('chat', (string) $chat->getId(), $offset, 'asc', $limit, $includeLastKnown);
+			$comments = $this->commentsManager->getForObjectSince('chat', (string)$chat->getId(), $offset, 'asc', $limit, $includeLastKnown);
 		}
 
 		return $comments;
@@ -717,7 +903,7 @@ class ChatManager {
 	 * @param Room $chat
 	 */
 	public function deleteMessages(Room $chat): void {
-		$this->commentsManager->deleteCommentsAtObject('chat', (string) $chat->getId());
+		$this->commentsManager->deleteCommentsAtObject('chat', (string)$chat->getId());
 
 		$this->shareProvider->deleteInRoom($chat->getToken());
 
@@ -729,13 +915,13 @@ class ChatManager {
 	}
 
 	/**
-	 * Search for comments with a given content
+	 * Get messages for the given chat by ID
 	 *
 	 * @param Room $chat
 	 * @param int[] $commentIds
 	 * @return IComment[]
 	 */
-	public function getMessagesById(Room $chat, array $commentIds): array {
+	public function getMessagesForRoomById(Room $chat, array $commentIds): array {
 		$comments = $this->commentsManager->getCommentsById(array_map('strval', $commentIds));
 
 		$comments = array_filter($comments, static function (IComment $comment) use ($chat) {
@@ -746,6 +932,16 @@ class ChatManager {
 		return $comments;
 	}
 
+	/**
+	 * Get messages by ID
+	 *
+	 * @param int[] $commentIds
+	 * @return IComment[] Key is the message id
+	 */
+	public function getMessagesById(array $commentIds): array {
+		return $this->commentsManager->getCommentsById(array_map('strval', $commentIds));
+	}
+
 	/**
 	 * Search for comments with a given content
 	 *
@@ -760,10 +956,26 @@ class ChatManager {
 		return $this->commentsManager->searchForObjects($search, 'chat', $objectIds, $verb, $offset, $limit);
 	}
 
+	/**
+	 * Search for comments on one or more objects with a given content
+	 *
+	 * @param string $search content to search for
+	 * @param string[] $objectIds Limit the search by object ids
+	 * @param string $verb Limit the verb of the comment
+	 * @return list<IComment>
+	 */
+	public function searchForObjectsWithFilters(string $search, array $objectIds, string $verb, ?\DateTimeImmutable $since, ?\DateTimeImmutable $until, ?string $actorType, ?string $actorId, int $offset, int $limit = 50): array {
+		return $this->commentsManager->searchForObjectsWithFilters($search, 'chat', $objectIds, $verb, $since, $until, $actorType, $actorId, $offset, $limit);
+	}
+
 	public function addConversationNotify(array $results, string $search, Room $room, Participant $participant): array {
 		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 			return $results;
 		}
+		if ($room->getMentionPermissions() === Room::MENTION_PERMISSIONS_MODERATORS && !$participant->hasModeratorPermissions()) {
+			return $results;
+		}
+
 		$attendee = $participant->getAttendee();
 		if ($attendee->getActorType() === Attendee::ACTOR_USERS) {
 			$roomDisplayName = $room->getDisplayName($attendee->getActorId());
@@ -771,11 +983,14 @@ class ChatManager {
 			$roomDisplayName = $room->getDisplayName('');
 		}
 		if ($search === '' || $this->searchIsPartOfConversationNameOrAtAll($search, $roomDisplayName)) {
-			array_unshift($results, [
+			$participantCount = $this->participantService->getNumberOfUsers($room);
+			$results[] = [
 				'id' => 'all',
 				'label' => $roomDisplayName,
+				'details' => $this->l->n('All %n participant', 'All %n participants', $participantCount),
 				'source' => 'calls',
-			]);
+				'mentionId' => 'all',
+			];
 		}
 		return $results;
 	}
@@ -784,10 +999,16 @@ class ChatManager {
 		if (stripos($roomDisplayName, $search) !== false) {
 			return true;
 		}
-		if (strpos('all', $search) === 0) {
+		/**
+		 * @psalm-suppress InvalidLiteralArgument
+		 */
+		if (str_starts_with('all', $search)) {
 			return true;
 		}
-		if (strpos('here', $search) === 0) {
+		/**
+		 * @psalm-suppress InvalidLiteralArgument
+		 */
+		if (str_starts_with('here', $search)) {
 			return true;
 		}
 		return false;
