@@ -2,31 +2,14 @@
 
 declare(strict_types=1);
 /**
- *
- * @copyright Copyright (c) 2017, Daniel Calviño Sánchez (danxuliu@gmail.com)
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Chat;
 
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Files\Util;
-use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Session;
 use OCA\Talk\Participant;
@@ -50,33 +33,15 @@ use OCP\Notification\INotification;
  * prepares the notifications for display.
  */
 class Notifier {
-	private INotificationManager $notificationManager;
-	private IUserManager $userManager;
-	private IGroupManager $groupManager;
-	private ParticipantService $participantService;
-	private Manager $manager;
-	private IConfig $config;
-	private ITimeFactory $timeFactory;
-	private Util $util;
-
 	public function __construct(
-		INotificationManager $notificationManager,
-		IUserManager $userManager,
-		IGroupManager $groupManager,
-		ParticipantService $participantService,
-		Manager $manager,
-		IConfig $config,
-		ITimeFactory $timeFactory,
-		Util $util,
+		private INotificationManager $notificationManager,
+		private IUserManager $userManager,
+		private IGroupManager $groupManager,
+		private ParticipantService $participantService,
+		private IConfig $config,
+		private ITimeFactory $timeFactory,
+		private Util $util,
 	) {
-		$this->notificationManager = $notificationManager;
-		$this->userManager = $userManager;
-		$this->groupManager = $groupManager;
-		$this->participantService = $participantService;
-		$this->manager = $manager;
-		$this->config = $config;
-		$this->timeFactory = $timeFactory;
-		$this->util = $util;
 	}
 
 	/**
@@ -91,12 +56,14 @@ class Notifier {
 	 * @param Room $chat
 	 * @param IComment $comment
 	 * @param array[] $alreadyNotifiedUsers
-	 * @psalm-param array<int, array{id: string, type: string, reason: string}> $alreadyNotifiedUsers
+	 * @psalm-param array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}> $alreadyNotifiedUsers
+	 * @param bool $silent
+	 * @param Participant|null $participant
 	 * @return string[] Users that were mentioned
 	 * @psalm-return array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}>
 	 */
-	public function notifyMentionedUsers(Room $chat, IComment $comment, array $alreadyNotifiedUsers, bool $silent): array {
-		$usersToNotify = $this->getUsersToNotify($chat, $comment, $alreadyNotifiedUsers);
+	public function notifyMentionedUsers(Room $chat, IComment $comment, array $alreadyNotifiedUsers, bool $silent, ?Participant $participant = null): array {
+		$usersToNotify = $this->getUsersToNotify($chat, $comment, $alreadyNotifiedUsers, $participant);
 
 		if (!$usersToNotify) {
 			return $alreadyNotifiedUsers;
@@ -109,7 +76,6 @@ class Notifier {
 			$shouldFlush = $this->notificationManager->defer();
 		}
 
-
 		foreach ($usersToNotify as $mentionedUser) {
 			if ($this->shouldMentionedUserBeNotified($mentionedUser['id'], $comment, $chat, $mentionedUser['attendee'] ?? null)) {
 				if (!$silent) {
@@ -138,14 +104,15 @@ class Notifier {
 	 * @param Room $chat
 	 * @param IComment $comment
 	 * @param array $alreadyNotifiedUsers
-	 * @psalm-param array<int, array{id: string, type: string, reason?: string}> $alreadyNotifiedUsers
+	 * @psalm-param array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}> $alreadyNotifiedUsers
+	 * @param Participant|null $participant
 	 * @return array
-	 * @psalm-return array<int, array{id: string, type: string, reason?: string, sourceId?: string, attendee?: Attendee}>
+	 * @psalm-return array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}>
 	 */
-	private function getUsersToNotify(Room $chat, IComment $comment, array $alreadyNotifiedUsers): array {
+	public function getUsersToNotify(Room $chat, IComment $comment, array $alreadyNotifiedUsers, ?Participant $participant = null): array {
 		$usersToNotify = $this->getMentionedUsers($comment);
 		$usersToNotify = $this->getMentionedGroupMembers($chat, $comment, $usersToNotify);
-		$usersToNotify = $this->addMentionAllToList($chat, $usersToNotify);
+		$usersToNotify = $this->addMentionAllToList($chat, $usersToNotify, $participant);
 		$usersToNotify = $this->removeAlreadyNotifiedUsers($usersToNotify, $alreadyNotifiedUsers);
 
 		return $usersToNotify;
@@ -153,11 +120,11 @@ class Notifier {
 
 	/**
 	 * @param array $usersToNotify
-	 * @psalm-param array<int, array{id: string, type: string, reason?: string, sourceId?: string, attendee?: Attendee}> $usersToNotify
+	 * @psalm-param array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}> $usersToNotify
 	 * @param array $alreadyNotifiedUsers
-	 * @psalm-param array<int, array{id: string, type: string, reason?: string}> $alreadyNotifiedUsers
+	 * @psalm-param array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}> $alreadyNotifiedUsers
 	 * @return array
-	 * @psalm-return array<int, array{id: string, type: string, reason?: string, sourceId?: string, attendee?: Attendee}>
+	 * @psalm-return array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}>
 	 */
 	private function removeAlreadyNotifiedUsers(array $usersToNotify, array $alreadyNotifiedUsers): array {
 		return array_filter($usersToNotify, static function (array $userToNotify) use ($alreadyNotifiedUsers): bool {
@@ -174,10 +141,11 @@ class Notifier {
 	 * @param Room $chat
 	 * @param array $list
 	 * @psalm-param array<int, array{id: string, type: string, reason: string, sourceId?: string}> $list
+	 * @param Participant|null $participant
 	 * @return array
 	 * @psalm-return array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}>
 	 */
-	private function addMentionAllToList(Room $chat, array $list): array {
+	private function addMentionAllToList(Room $chat, array $list, ?Participant $participant = null): array {
 		$usersToNotify = array_filter($list, static function (array $entry): bool {
 			return $entry['type'] !== Attendee::ACTOR_USERS || $entry['id'] !== 'all';
 		});
@@ -185,6 +153,9 @@ class Notifier {
 		if (count($list) === count($usersToNotify)) {
 			return $usersToNotify;
 		}
+		if ($chat->getMentionPermissions() === Room::MENTION_PERMISSIONS_MODERATORS && (!$participant instanceof Participant || !$participant->hasModeratorPermissions())) {
+			return $usersToNotify;
+		}
 
 		$attendees = $this->participantService->getActorsByType($chat, Attendee::ACTOR_USERS);
 		foreach ($attendees as $attendee) {
@@ -223,11 +194,21 @@ class Notifier {
 	 * @psalm-return array<int, array{id: string, type: string, reason: string}>
 	 */
 	public function notifyReplyToAuthor(Room $chat, IComment $comment, IComment $replyTo, bool $silent): array {
-		if ($replyTo->getActorType() !== Attendee::ACTOR_USERS) {
-			// No reply notification when the replyTo-author was not a user
+		if ($replyTo->getActorType() !== Attendee::ACTOR_USERS && $replyTo->getActorType() !== Attendee::ACTOR_FEDERATED_USERS) {
+			// No reply notification when the replyTo-author was not a user or federated user
 			return [];
 		}
 
+		if ($replyTo->getActorType() === Attendee::ACTOR_FEDERATED_USERS) {
+			return [
+				[
+					'id' => $replyTo->getActorId(),
+					'type' => $replyTo->getActorType(),
+					'reason' => 'reply',
+				],
+			];
+		}
+
 		if (!$this->shouldMentionedUserBeNotified($replyTo->getActorId(), $comment, $chat)) {
 			return [];
 		}
@@ -328,8 +309,6 @@ class Notifier {
 
 	/**
 	 * Removes all the pending notifications for the room with the given ID.
-	 *
-	 * @param Room $chat
 	 */
 	public function removePendingNotificationsForRoom(Room $chat, bool $chatOnly = false): void {
 		$notification = $this->notificationManager->createNotification();
@@ -340,6 +319,7 @@ class Notifier {
 
 		$objectTypes = [
 			'chat',
+			'reminder',
 		];
 		if (!$chatOnly) {
 			$objectTypes = [
@@ -386,6 +366,36 @@ class Notifier {
 		}
 	}
 
+	/**
+	 * Remove all mention notifications of users that got their mention removed
+	 *
+	 * @param list<string> $userIds
+	 */
+	public function removeMentionNotificationAfterEdit(Room $chat, IComment $comment, array $userIds): void {
+		$shouldFlush = $this->notificationManager->defer();
+		$notification = $this->notificationManager->createNotification();
+
+		$notification
+			->setApp('spreed')
+			->setObject('chat', $chat->getToken())
+			// FIXME message_parameters are not handled by notification app, so this removes all notifications :(
+			->setMessage('comment', [
+				'commentId' => $comment->getId(),
+			]);
+
+		foreach (['mention_all', 'mention_direct'] as $subject) {
+			$notification->setSubject($subject);
+			foreach ($userIds as $userId) {
+				$notification->setUser($userId);
+				$this->notificationManager->markProcessed($notification);
+			}
+		}
+
+		if ($shouldFlush) {
+			$this->notificationManager->flush();
+		}
+	}
+
 	/**
 	 * Returns the IDs of the users mentioned in the given comment.
 	 *
@@ -399,6 +409,19 @@ class Notifier {
 		}, $mentionedUsers);
 	}
 
+	/**
+	 * Returns the cloud IDs of the federated users mentioned in the given comment.
+	 *
+	 * @param IComment $comment
+	 * @return string[] the mentioned cloud IDs
+	 */
+	public function getMentionedCloudIds(IComment $comment): array {
+		$mentionedFederatedUsers = $this->getMentionedFederatedUsers($comment);
+		return array_map(static function ($mentionedUser) {
+			return $mentionedUser['id'];
+		}, $mentionedFederatedUsers);
+	}
+
 	/**
 	 * @param IComment $comment
 	 * @return array[]
@@ -419,7 +442,34 @@ class Notifier {
 
 			$mentionedUsers[] = [
 				'id' => $mention['id'],
-				'type' => 'users',
+				'type' => Attendee::ACTOR_USERS,
+				'reason' => 'direct',
+			];
+		}
+		return $mentionedUsers;
+	}
+
+	/**
+	 * @param IComment $comment
+	 * @return array[]
+	 * @psalm-return array<int, array{type: string, id: string, reason: string}>
+	 */
+	private function getMentionedFederatedUsers(IComment $comment): array {
+		$mentions = $comment->getMentions();
+
+		if (empty($mentions)) {
+			return [];
+		}
+
+		$mentionedUsers = [];
+		foreach ($mentions as $mention) {
+			if ($mention['type'] !== 'federated_user') {
+				continue;
+			}
+
+			$mentionedUsers[] = [
+				'id' => $mention['id'],
+				'type' => Attendee::ACTOR_FEDERATED_USERS,
 				'reason' => 'direct',
 			];
 		}
@@ -485,12 +535,6 @@ class Notifier {
 	/**
 	 * Creates a notification for the given chat message comment and mentioned
 	 * user ID.
-	 *
-	 * @param Room $chat
-	 * @param IComment $comment
-	 * @param string $subject
-	 * @param array $subjectData
-	 * @return INotification
 	 */
 	private function createNotification(Room $chat, IComment $comment, string $subject, array $subjectData = [], ?IComment $reaction = null): INotification {
 		$subjectData['userType'] = $reaction ? $reaction->getActorType() : $comment->getActorType();
@@ -510,7 +554,7 @@ class Notifier {
 	}
 
 	protected function getDefaultGroupNotification(): int {
-		return (int) $this->config->getAppValue('spreed', 'default_group_notification', (string) Participant::NOTIFY_MENTION);
+		return (int)$this->config->getAppValue('spreed', 'default_group_notification', (string)Participant::NOTIFY_MENTION);
 	}
 
 	/**
@@ -520,12 +564,6 @@ class Notifier {
 	 * 2. The user must exist
 	 * 3. The user must be a participant of the room
 	 * 4. The user must not be active in the room
-	 *
-	 * @param string $userId
-	 * @param IComment $comment
-	 * @param Room $room
-	 * @param Attendee|null $attendee
-	 * @return bool
 	 */
 	protected function shouldMentionedUserBeNotified(string $userId, IComment $comment, Room $room, ?Attendee $attendee = null): bool {
 		if ($comment->getActorType() === Attendee::ACTOR_USERS && $userId === $comment->getActorId()) {
