@@ -3,24 +3,8 @@
 declare(strict_types=1);
 
 /**
- * @copyright Copyright (c) 2022 Joas Schilling <coding@schilljs.com>
- *
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Collaboration\Reference;
@@ -32,14 +16,17 @@ use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\RoomNotFoundException;
 use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
+use OCA\Talk\Model\ProxyCacheMessageMapper;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Service\AvatarService;
 use OCA\Talk\Service\ParticipantService;
+use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\Collaboration\Reference\ADiscoverableReferenceProvider;
 use OCP\Collaboration\Reference\IReference;
 use OCP\Collaboration\Reference\ISearchableReferenceProvider;
 use OCP\Collaboration\Reference\Reference;
+use OCP\Comments\NotFoundException;
 use OCP\IL10N;
 use OCP\IURLGenerator;
 
@@ -47,33 +34,18 @@ use OCP\IURLGenerator;
  * @psalm-type ReferenceMatch = array{token: string, message: int|null}
  */
 class TalkReferenceProvider extends ADiscoverableReferenceProvider implements ISearchableReferenceProvider {
-	protected IURLGenerator $urlGenerator;
-	protected Manager $roomManager;
-	protected ParticipantService $participantService;
-	protected ChatManager $chatManager;
-	protected AvatarService $avatarService;
-	protected MessageParser $messageParser;
-	protected IL10N $l;
-	protected ?string $userId;
 
 	public function __construct(
-		IURLGenerator $urlGenerator,
-		Manager $manager,
-		ParticipantService $participantService,
-		ChatManager $chatManager,
-		AvatarService $avatarService,
-		MessageParser $messageParser,
-		IL10N $l,
-		?string $userId,
+		protected IURLGenerator $urlGenerator,
+		protected Manager $roomManager,
+		protected ParticipantService $participantService,
+		protected ChatManager $chatManager,
+		protected ProxyCacheMessageMapper $proxyCacheMessageMapper,
+		protected AvatarService $avatarService,
+		protected MessageParser $messageParser,
+		protected IL10N $l,
+		protected ?string $userId,
 	) {
-		$this->urlGenerator = $urlGenerator;
-		$this->roomManager = $manager;
-		$this->participantService = $participantService;
-		$this->chatManager = $chatManager;
-		$this->avatarService = $avatarService;
-		$this->messageParser = $messageParser;
-		$this->l = $l;
-		$this->userId = $userId;
 	}
 
 
@@ -121,7 +93,7 @@ class TalkReferenceProvider extends ADiscoverableReferenceProvider implements IS
 		if ($hashPosition !== false) {
 			$afterHash = substr($urlOfInterest, $hashPosition + 1);
 			if (preg_match('/^message_(\d+)$/', $afterHash, $matches)) {
-				$messageId = (int) $matches[1];
+				$messageId = (int)$matches[1];
 			}
 		}
 
@@ -191,10 +163,26 @@ class TalkReferenceProvider extends ADiscoverableReferenceProvider implements IS
 		 * Description is the plain text chat message
 		 */
 		if ($participant && !empty($referenceMatch['message'])) {
-			$messageId = (string) $referenceMatch['message'];
-			$comment = $this->chatManager->getComment($room, $messageId);
-			$message = $this->messageParser->createMessage($room, $participant, $comment, $this->l);
-			$this->messageParser->parseMessage($message);
+			$messageId = (string)$referenceMatch['message'];
+			if (!$room->isFederatedConversation()) {
+				try {
+					$comment = $this->chatManager->getComment($room, $messageId);
+				} catch (NotFoundException) {
+					throw new RoomNotFoundException();
+				}
+				$message = $this->messageParser->createMessage($room, $participant, $comment, $this->l);
+				$this->messageParser->parseMessage($message);
+			} else {
+				try {
+					$proxy = $this->proxyCacheMessageMapper->findById($room, (int)$messageId);
+					if ($proxy->getLocalToken() !== $room->getToken()) {
+						throw new RoomNotFoundException();
+					}
+				} catch (DoesNotExistException) {
+					throw new RoomNotFoundException();
+				}
+				$message = $this->messageParser->createMessageFromProxyCache($room, $participant, $proxy, $this->l);
+			}
 
 			$placeholders = $replacements = [];
 			foreach ($message->getMessageParameters() as $placeholder => $parameter) {
@@ -213,7 +201,7 @@ class TalkReferenceProvider extends ADiscoverableReferenceProvider implements IS
 			}
 
 			$displayName = $message->getActorDisplayName();
-			if ($message->getActorType() === Attendee::ACTOR_GUESTS) {
+			if (in_array($message->getActorType(), [Attendee::ACTOR_GUESTS, Attendee::ACTOR_EMAILS], true)) {
 				if ($displayName === '') {
 					$displayName = $this->l->t('Guest');
 				} else {
