@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2018 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Collaboration\Resources;
@@ -38,24 +23,14 @@ use OCP\IUser;
 use OCP\IUserSession;
 
 class ConversationProvider implements IProvider {
-	protected Manager $manager;
-	protected ParticipantService $participantService;
-	protected AvatarService $avatarService;
-	protected IUserSession $userSession;
-	protected IURLGenerator $urlGenerator;
 
 	public function __construct(
-		Manager $manager,
-		AvatarService $avatarService,
-		ParticipantService $participantService,
-		IUserSession $userSession,
-		IURLGenerator $urlGenerator,
+		protected Manager $manager,
+		protected AvatarService $avatarService,
+		protected ParticipantService $participantService,
+		protected IUserSession $userSession,
+		protected IURLGenerator $urlGenerator,
 	) {
-		$this->manager = $manager;
-		$this->avatarService = $avatarService;
-		$this->participantService = $participantService;
-		$this->userSession = $userSession;
-		$this->urlGenerator = $urlGenerator;
 	}
 
 	public function getResourceRichObject(IResource $resource): array {
@@ -64,7 +39,7 @@ class ConversationProvider implements IProvider {
 			$userId = $user instanceof IUser ? $user->getUID() : '';
 			$room = $this->manager->getRoomByToken($resource->getId(), $userId);
 
-			$iconURL = $this->avatarService->getAvatarUrl($room, $userId);
+			$iconURL = $this->avatarService->getAvatarUrl($room);
 			/**
 			 * Disabled for now, because it would show a square avatar
 			 * if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
@@ -85,7 +60,7 @@ class ConversationProvider implements IProvider {
 		}
 	}
 
-	public function canAccessResource(IResource $resource, IUser $user = null): bool {
+	public function canAccessResource(IResource $resource, ?IUser $user = null): bool {
 		$userId = $user instanceof IUser ? $user->getUID() : null;
 		if ($userId === null) {
 			throw new ResourceException('Guests are not supported at the moment');
