@@ -2,25 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Julien Veyssier <eneiluj@posteo.net>
- *
- * @author Julien Veyssier <eneiluj@posteo.net>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Controller;
@@ -29,31 +12,36 @@ use OCA\Talk\Exceptions\ImpossibleToKillException;
 use OCA\Talk\Manager;
 use OCA\Talk\MatterbridgeManager;
 use OCA\Talk\Middleware\Attribute\RequireLoggedInModeratorParticipant;
+use OCA\Talk\ResponseDefinitions;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\Attribute\NoAdminRequired;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\IRequest;
 
+/**
+ * @psalm-import-type TalkMatterbridge from ResponseDefinitions
+ * @psalm-import-type TalkMatterbridgeConfigFields from ResponseDefinitions
+ * @psalm-import-type TalkMatterbridgeProcessState from ResponseDefinitions
+ * @psalm-import-type TalkMatterbridgeWithProcessState from ResponseDefinitions
+ */
 class MatterbridgeController extends AEnvironmentAwareController {
-	protected ?string $userId;
-	protected Manager $manager;
-	protected MatterbridgeManager $bridgeManager;
 
 	public function __construct(
 		string $appName,
-		?string $UserId,
+		protected ?string $userId,
 		IRequest $request,
-		Manager $manager,
-		MatterbridgeManager $bridgeManager,
+		protected Manager $manager,
+		protected MatterbridgeManager $bridgeManager,
 	) {
 		parent::__construct($appName, $request);
-		$this->userId = $UserId;
-		$this->manager = $manager;
-		$this->bridgeManager = $bridgeManager;
 	}
 
 	/**
 	 * Get bridge information of one room
+	 *
+	 * @return DataResponse<Http::STATUS_OK, TalkMatterbridgeWithProcessState, array{}>
+	 *
+	 * 200: Return list of configured bridges
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInModeratorParticipant]
@@ -68,6 +56,10 @@ class MatterbridgeController extends AEnvironmentAwareController {
 
 	/**
 	 * Get bridge process information
+	 *
+	 * @return DataResponse<Http::STATUS_OK, TalkMatterbridgeProcessState, array{}>
+	 *
+	 * 200: Return list of running processes
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInModeratorParticipant]
@@ -78,6 +70,13 @@ class MatterbridgeController extends AEnvironmentAwareController {
 
 	/**
 	 * Edit bridge information of one room
+	 *
+	 * @param bool $enabled If the bridge should be enabled
+	 * @param TalkMatterbridgeConfigFields $parts New parts
+	 * @return DataResponse<Http::STATUS_OK, TalkMatterbridgeProcessState, array{}>|DataResponse<Http::STATUS_NOT_ACCEPTABLE, array{error: string}, array{}>
+	 *
+	 * 200: Bridge edited successfully
+	 * 406: Editing bridge is not possible
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInModeratorParticipant]
@@ -92,6 +91,11 @@ class MatterbridgeController extends AEnvironmentAwareController {
 
 	/**
 	 * Delete bridge of one room
+	 *
+	 * @return DataResponse<Http::STATUS_OK, bool, array{}>|DataResponse<Http::STATUS_NOT_ACCEPTABLE, array{error: string}, array{}>
+	 *
+	 * 200: Bridge deleted successfully
+	 * 406: Deleting bridge is not possible
 	 */
 	#[NoAdminRequired]
 	#[RequireLoggedInModeratorParticipant]
