@@ -2,24 +2,8 @@
 
 declare(strict_types=1);
 /**
- *
- * @copyright Copyright (c) 2018, Daniel Calviño Sánchez (danxuliu@gmail.com)
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Controller;
@@ -27,6 +11,7 @@ namespace OCA\Talk\Controller;
 use OCA\Talk\Room;
 use OCA\Talk\Service\RoomService;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\Attribute\OpenAPI;
 use OCP\AppFramework\Http\Attribute\PublicPage;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\OCSController;
@@ -39,28 +24,20 @@ use OCP\Share\IManager as IShareManager;
 use OCP\Share\IShare;
 
 class PublicShareAuthController extends OCSController {
-	private IUserManager $userManager;
-	private IShareManager $shareManager;
-	private IUserSession $userSession;
-	private RoomService $roomService;
 
 	public function __construct(
 		string $appName,
 		IRequest $request,
-		IUserManager $userManager,
-		IShareManager $shareManager,
-		IUserSession $userSession,
-		RoomService $roomService,
+		private IUserManager $userManager,
+		private IShareManager $shareManager,
+		private IUserSession $userSession,
+		private RoomService $roomService,
 	) {
 		parent::__construct($appName, $request);
-		$this->userManager = $userManager;
-		$this->shareManager = $shareManager;
-		$this->userSession = $userSession;
-		$this->roomService = $roomService;
 	}
 
 	/**
-	 * Creates a new room for requesting the password of a share.
+	 * Creates a new room for video verification (requesting the password of a share)
 	 *
 	 * The new room is a public room associated with a "share:password" object
 	 * with the ID of the share token. Unlike normal rooms in which the owner is
@@ -71,12 +48,14 @@ class PublicShareAuthController extends OCSController {
 	 * The share must have "send password by Talk" enabled; an error is returned
 	 * otherwise.
 	 *
-	 * @param string $shareToken
-	 * @return DataResponse the status code is "201 Created" if a new room is
-	 *         created, "200 OK" if an existing room is returned, or "404 Not
-	 *         found" if the given share was invalid.
+	 * @param string $shareToken Token of the file share
+	 * @return DataResponse<Http::STATUS_CREATED, array{token: string, name: string, displayName: string}, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array<empty>, array{}>
+	 *
+	 * 201: Room created successfully
+	 * 404: Share not found
 	 */
 	#[PublicPage]
+	#[OpenAPI(tags: ['files_integration'])]
 	public function createRoom(string $shareToken): DataResponse {
 		try {
 			$share = $this->shareManager->getShareByToken($shareToken);
