@@ -2,45 +2,35 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2016 Lukas Reschke <lukas@statuscode.ch>
- *
- * @author Lukas Reschke <lukas@statuscode.ch>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Controller;
 
 use GuzzleHttp\Exception\ConnectException;
 use OCA\Talk\Config;
-use OCA\Talk\Events\SignalingEvent;
+use OCA\Talk\Events\AAttendeeRemovedEvent;
+use OCA\Talk\Events\BeforeSignalingResponseSentEvent;
+use OCA\Talk\Exceptions\ForbiddenException;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\RoomNotFoundException;
+use OCA\Talk\Federation\Authenticator;
 use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Session;
 use OCA\Talk\Participant;
+use OCA\Talk\ResponseDefinitions;
 use OCA\Talk\Room;
+use OCA\Talk\Service\BanService;
+use OCA\Talk\Service\CertificateService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\SessionService;
 use OCA\Talk\Signaling\Messages;
 use OCA\Talk\TalkSession;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\Attribute\BruteForceProtection;
+use OCP\AppFramework\Http\Attribute\OpenAPI;
 use OCP\AppFramework\Http\Attribute\PublicPage;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\OCSController;
@@ -48,70 +38,42 @@ use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\DB\Exception;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\Http\Client\IClientService;
-use OCP\IConfig;
 use OCP\IDBConnection;
 use OCP\IRequest;
 use OCP\IUser;
 use OCP\IUserManager;
-use OCP\Security\Bruteforce\IThrottler;
 use Psr\Log\LoggerInterface;
 
+/**
+ * @psalm-import-type TalkSignalingSession from ResponseDefinitions
+ * @psalm-import-type TalkSignalingSettings from ResponseDefinitions
+ */
 class SignalingController extends OCSController {
 	/** @var int */
 	private const PULL_MESSAGES_TIMEOUT = 30;
 
-	public const EVENT_BACKEND_SIGNALING_ROOMS = self::class . '::signalingBackendRoom';
-
-	private Config $talkConfig;
-	private \OCA\Talk\Signaling\Manager $signalingManager;
-	private TalkSession $session;
-	private Manager $manager;
-	private ParticipantService $participantService;
-	private SessionService $sessionService;
-	private IDBConnection $dbConnection;
-	private Messages $messages;
-	private IUserManager $userManager;
-	private IEventDispatcher $dispatcher;
-	private ITimeFactory $timeFactory;
-	private IClientService $clientService;
-	private LoggerInterface $logger;
-	private ?string $userId;
-
 	public function __construct(
 		string $appName,
 		IRequest $request,
-		IConfig $serverConfig,
-		Config $talkConfig,
-		\OCA\Talk\Signaling\Manager $signalingManager,
-		TalkSession $session,
-		Manager $manager,
-		ParticipantService $participantService,
-		SessionService $sessionService,
-		IDBConnection $connection,
-		Messages $messages,
-		IUserManager $userManager,
-		IEventDispatcher $dispatcher,
-		ITimeFactory $timeFactory,
-		IClientService $clientService,
-		IThrottler $throttler,
-		LoggerInterface $logger,
-		?string $UserId,
+		private Config $talkConfig,
+		private \OCA\Talk\Signaling\Manager $signalingManager,
+		private TalkSession $session,
+		private Manager $manager,
+		private CertificateService $certificateService,
+		private ParticipantService $participantService,
+		private SessionService $sessionService,
+		private IDBConnection $dbConnection,
+		private Messages $messages,
+		private IUserManager $userManager,
+		private IEventDispatcher $dispatcher,
+		private ITimeFactory $timeFactory,
+		private IClientService $clientService,
+		private BanService $banService,
+		private LoggerInterface $logger,
+		protected Authenticator $federationAuthenticator,
+		private ?string $userId,
 	) {
 		parent::__construct($appName, $request);
-		$this->talkConfig = $talkConfig;
-		$this->signalingManager = $signalingManager;
-		$this->session = $session;
-		$this->dbConnection = $connection;
-		$this->manager = $manager;
-		$this->participantService = $participantService;
-		$this->sessionService = $sessionService;
-		$this->messages = $messages;
-		$this->userManager = $userManager;
-		$this->dispatcher = $dispatcher;
-		$this->timeFactory = $timeFactory;
-		$this->clientService = $clientService;
-		$this->logger = $logger;
-		$this->userId = $UserId;
 	}
 
 	/**
@@ -129,21 +91,33 @@ class SignalingController extends OCSController {
 	private function validateRecordingBackendRequest(string $data): bool {
 		$random = $this->request->getHeader('Talk-Recording-Random');
 		if (empty($random) || strlen($random) < 32) {
-			$this->logger->debug("Missing random");
+			$this->logger->debug('Missing random');
 			return false;
 		}
 		$checksum = $this->request->getHeader('Talk-Recording-Checksum');
 		if (empty($checksum)) {
-			$this->logger->debug("Missing checksum");
+			$this->logger->debug('Missing checksum');
 			return false;
 		}
 		$hash = hash_hmac('sha256', $random . $data, $this->talkConfig->getRecordingSecret());
 		return hash_equals($hash, strtolower($checksum));
 	}
 
+	/**
+	 * Get the signaling settings
+	 *
+	 * @param string $token Token of the room
+	 * @return DataResponse<Http::STATUS_OK, TalkSignalingSettings, array{}>|DataResponse<Http::STATUS_UNAUTHORIZED|Http::STATUS_NOT_FOUND, array<empty>, array{}>
+	 *
+	 * 200: Signaling settings returned
+	 * 401: Recording request invalid
+	 * 404: Room not found
+	 */
 	#[PublicPage]
 	#[BruteForceProtection(action: 'talkRoomToken')]
 	#[BruteForceProtection(action: 'talkRecordingSecret')]
+	#[BruteForceProtection(action: 'talkFederationAccess')]
+	#[OpenAPI(tags: ['internal_signaling', 'external_signaling'])]
 	public function getSettings(string $token = ''): DataResponse {
 		$isRecordingRequest = false;
 
@@ -157,18 +131,35 @@ class SignalingController extends OCSController {
 			$isRecordingRequest = true;
 		}
 
+		$isTalkFederation = $this->federationAuthenticator->isFederationRequest();
+
 		try {
+			$action = 'talkRoomToken';
 			if ($token !== '' && $isRecordingRequest) {
 				$room = $this->manager->getRoomByToken($token);
+			} elseif ($token !== '' && $isTalkFederation) {
+				$action = 'talkFederationAccess';
+				$room = $this->manager->getRoomByRemoteAccess(
+					$token,
+					Attendee::ACTOR_FEDERATED_USERS,
+					$this->federationAuthenticator->getCloudId(),
+					$this->federationAuthenticator->getAccessToken(),
+				);
+				$participant = $this->participantService->getParticipantByActor(
+					$room,
+					Attendee::ACTOR_FEDERATED_USERS,
+					$this->federationAuthenticator->getCloudId()
+				);
+				$this->federationAuthenticator->authenticated($room, $participant);
 			} elseif ($token !== '') {
 				$room = $this->manager->getRoomForUserByToken($token, $this->userId);
 			} else {
 				// FIXME Soft-fail for legacy support in mobile apps
 				$room = null;
 			}
-		} catch (RoomNotFoundException $e) {
+		} catch (RoomNotFoundException|ParticipantNotFoundException) {
 			$response = new DataResponse([], Http::STATUS_NOT_FOUND);
-			$response->throttle(['token' => $token, 'action' => 'talkRoomToken']);
+			$response->throttle(['token' => $token, 'action' => $action]);
 			return $response;
 		}
 
@@ -196,21 +187,23 @@ class SignalingController extends OCSController {
 
 			$turn[] = [
 				'urls' => $turnUrls,
-				'username' => $turnServer['username'],
-				'credential' => $turnServer['password'],
+				'username' => (string)$turnServer['username'],
+				'credential' => (string)$turnServer['password'],
 			];
 		}
 
 		$signalingMode = $this->talkConfig->getSignalingMode();
 		$signaling = $this->signalingManager->getSignalingServerLinkForConversation($room);
 
+		$helloAuthParams20UserId = $isTalkFederation ? null : $this->userId;
+		$helloAuthParams20CloudId = $isTalkFederation ? $this->federationAuthenticator->getCloudId() : null;
 		$helloAuthParams = [
 			'1.0' => [
 				'userid' => $this->userId,
 				'ticket' => $this->talkConfig->getSignalingTicket(Config::SIGNALING_TICKET_V1, $this->userId),
 			],
 			'2.0' => [
-				'token' => $this->talkConfig->getSignalingTicket(Config::SIGNALING_TICKET_V2, $this->userId),
+				'token' => $this->talkConfig->getSignalingTicket(Config::SIGNALING_TICKET_V2, $helloAuthParams20UserId, $helloAuthParams20CloudId),
 			],
 		];
 		$data = [
@@ -220,6 +213,7 @@ class SignalingController extends OCSController {
 			'server' => $signaling,
 			'ticket' => $helloAuthParams['1.0']['ticket'],
 			'helloAuthParams' => $helloAuthParams,
+			'federation' => $this->getFederationSettings($room),
 			'stunservers' => $stun,
 			'turnservers' => $turn,
 			'sipDialinInfo' => $this->talkConfig->isSIPConfigured() ? $this->talkConfig->getDialInInfo() : '',
@@ -228,13 +222,52 @@ class SignalingController extends OCSController {
 		return new DataResponse($data);
 	}
 
+	private function getFederationSettings(?Room $room): array {
+		if ($room === null || !$room->isFederatedConversation()) {
+			return [];
+		}
+
+		try {
+			$participant = $this->participantService->getParticipant($room, $this->userId);
+		} catch (ParticipantNotFoundException $e) {
+			return [];
+		}
+
+		/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\SignalingController $proxy */
+		$proxy = \OCP\Server::get(\OCA\Talk\Federation\Proxy\TalkV1\Controller\SignalingController::class);
+		$response = $proxy->getSettings($room, $participant);
+
+		if ($response->getStatus() === Http::STATUS_NOT_FOUND) {
+			return [];
+		}
+
+		/** @var TalkSignalingSettings $data */
+		$data = $response->getData();
+
+		return [
+			'server' => $data['server'],
+			'nextcloudServer' => $room->getRemoteServer(),
+			'helloAuthParams' => [
+				'token' => $data['helloAuthParams']['2.0']['token'],
+			],
+			'roomId' => $room->getRemoteToken(),
+		];
+	}
+
 	/**
+	 * Get the welcome message from a signaling server
+	 *
 	 * Only available for logged-in users because guests can not use the apps
 	 * right now.
 	 *
-	 * @param int $serverId
-	 * @return DataResponse
+	 * @param int $serverId ID of the signaling server
+	 * @psalm-param non-negative-int $serverId
+	 * @return DataResponse<Http::STATUS_OK, array<string, mixed>, array{}>|DataResponse<Http::STATUS_NOT_FOUND, array<empty>, array{}>|DataResponse<Http::STATUS_INTERNAL_SERVER_ERROR, array{error: string, version?: string}, array{}>
+	 *
+	 * 200: Welcome message returned
+	 * 404: Signaling server not found
 	 */
+	#[OpenAPI(scope: OpenAPI::SCOPE_ADMINISTRATION, tags: ['settings'])]
 	public function getWelcomeMessage(int $serverId): DataResponse {
 		$signalingServers = $this->talkConfig->getSignalingServers();
 		if (empty($signalingServers) || !isset($signalingServers[$serverId])) {
@@ -242,19 +275,30 @@ class SignalingController extends OCSController {
 		}
 
 		$url = rtrim($signalingServers[$serverId]['server'], '/');
+		$url = strtolower($url);
 
-		if (strpos($url, 'wss://') === 0) {
+		if (str_starts_with($url, 'wss://')) {
 			$url = 'https://' . substr($url, 6);
 		}
 
-		if (strpos($url, 'ws://') === 0) {
+		if (str_starts_with($url, 'ws://')) {
 			$url = 'http://' . substr($url, 5);
 		}
 
+		$verifyServer = (bool)$signalingServers[$serverId]['verify'];
+
+		if ($verifyServer && str_contains($url, 'https://')) {
+			$expiration = $this->certificateService->getCertificateExpirationInDays($url);
+
+			if ($expiration < 0) {
+				return new DataResponse(['error' => 'CERTIFICATE_EXPIRED'], Http::STATUS_INTERNAL_SERVER_ERROR);
+			}
+		}
+
 		$client = $this->clientService->newClient();
 		try {
 			$response = $client->get($url . '/api/v1/welcome', [
-				'verify' => (bool) $signalingServers[$serverId]['verify'],
+				'verify' => $verifyServer,
 				'nextcloud' => [
 					'allow_local_address' => true,
 				],
@@ -283,16 +327,36 @@ class SignalingController extends OCSController {
 				], Http::STATUS_INTERNAL_SERVER_ERROR);
 			}
 
+			$missingFeatures = $this->signalingManager->getSignalingServerMissingFeatures($response);
+			if (!empty($missingFeatures)) {
+				return new DataResponse([
+					'warning' => 'UPDATE_OPTIONAL',
+					'features' => $missingFeatures,
+					'version' => $data['version'] ?? '',
+				]);
+			}
+
 			return new DataResponse($data);
 		} catch (ConnectException $e) {
 			return new DataResponse(['error' => 'CAN_NOT_CONNECT'], Http::STATUS_INTERNAL_SERVER_ERROR);
 		} catch (\Exception $e) {
-			return new DataResponse(['error' => $e->getCode()], Http::STATUS_INTERNAL_SERVER_ERROR);
+			return new DataResponse(['error' => (string)$e->getCode()], Http::STATUS_INTERNAL_SERVER_ERROR);
 		}
 	}
 
+	/**
+	 * Send signaling messages
+	 *
+	 * @param string $token Token of the room
+	 * @param string $messages JSON encoded messages
+	 * @return DataResponse<Http::STATUS_OK, array<empty>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, string, array{}>
+	 *
+	 * 200: Signaling message sent successfully
+	 * 400: Sending signaling message is not possible
+	 */
 	#[PublicPage]
-	public function signaling(string $token, string $messages): DataResponse {
+	#[OpenAPI(tags: ['internal_signaling'])]
+	public function sendMessages(string $token, string $messages): DataResponse {
 		if ($this->talkConfig->getSignalingMode() !== Config::SIGNALING_INTERNAL) {
 			return new DataResponse('Internal signaling disabled.', Http::STATUS_BAD_REQUEST);
 		}
@@ -320,6 +384,23 @@ class SignalingController extends OCSController {
 						if (!$participant->hasModeratorPermissions(false)) {
 							break;
 						}
+					} elseif ($decodedMessage['type'] === 'offer' || $decodedMessage['type'] === 'answer') {
+						$room = $this->manager->getRoomForSession($this->userId, $message['sessionId']);
+						$participant = $this->participantService->getParticipantBySession($room, $message['sessionId']);
+
+						if (!($participant->getPermissions() & Attendee::PERMISSIONS_PUBLISH_AUDIO) && $decodedMessage['roomType'] === 'video'
+								&& $this->isTryingToPublishMedia($decodedMessage['payload']['sdp'], 'audio')) {
+							break;
+						}
+						if (!($participant->getPermissions() & Attendee::PERMISSIONS_PUBLISH_VIDEO) && $decodedMessage['roomType'] === 'video'
+								&& $this->isTryingToPublishMedia($decodedMessage['payload']['sdp'], 'video')) {
+							break;
+						}
+						if (!($participant->getPermissions() & Attendee::PERMISSIONS_PUBLISH_SCREEN) && $decodedMessage['roomType'] === 'screen'
+								&& ($this->isTryingToPublishMedia($decodedMessage['payload']['sdp'], 'audio')
+									|| $this->isTryingToPublishMedia($decodedMessage['payload']['sdp'], 'video'))) {
+							break;
+						}
 					}
 
 					$this->messages->addMessage($message['sessionId'], $decodedMessage['to'], json_encode($decodedMessage));
@@ -331,7 +412,97 @@ class SignalingController extends OCSController {
 		return new DataResponse($response);
 	}
 
+	/**
+	 * Returns whether the SDP is trying to publish the given media based on the
+	 * media direction.
+	 *
+	 * The SDP is trying to publish if the related media description contains a
+	 * media direction of either "sendrecv" or "sendonly". If no media direction
+	 * is provided in a media description the media direction in the session
+	 * description is used instead. If that is not provided either then
+	 * "sendrecv" is assumed.
+	 *
+	 * See https://www.rfc-editor.org/rfc/rfc8866.html#name-media-direction-attributes
+	 *
+	 * @param string $sdp the SDP to check
+	 * @param string $media the media to check, either "audio" or "video"
+	 * @return bool true if it is trying to publish, false otherwise
+	 */
+	private function isTryingToPublishMedia(string $sdp, string $media): bool {
+		$lines = preg_split('/\r\n|\n|\r/', $sdp);
+
+		$sessionMediaDirectionIndex = -1;
+		$mediaDirectionIndex = -1;
+		$mediaDescriptionIndex = -1;
+		$matchingMediaDescriptionIndex = -1;
+
+		for ($i = 0; $i < count($lines); $i++) {
+			if (strpos($lines[$i], 'a=sendrecv') === 0
+				|| strpos($lines[$i], 'a=sendonly') === 0
+				|| strpos($lines[$i], 'a=recvonly') === 0
+				|| strpos($lines[$i], 'a=inactive') === 0) {
+				$mediaDirectionIndex = $i;
+
+				if ($mediaDescriptionIndex < 0) {
+					$sessionMediaDirectionIndex = $mediaDirectionIndex;
+				}
+
+				if ($matchingMediaDescriptionIndex >= 0
+					&& $matchingMediaDescriptionIndex >= $mediaDescriptionIndex
+					&& $mediaDirectionIndex > $matchingMediaDescriptionIndex
+					&& (strpos($lines[$mediaDirectionIndex], 'a=sendrecv') === 0
+						|| strpos($lines[$mediaDirectionIndex], 'a=sendonly') === 0)) {
+					return true;
+				}
+			} elseif (strpos($lines[$i], 'm=') === 0) {
+				// No media direction in previous matching media description,
+				// fallback to media direction in the session description or, if
+				// not set, default to "sendrecv".
+				if ($matchingMediaDescriptionIndex >= 0
+					&& $matchingMediaDescriptionIndex >= $mediaDescriptionIndex
+					&& $mediaDirectionIndex < $matchingMediaDescriptionIndex
+					&& ($sessionMediaDirectionIndex < 0
+						|| strpos($lines[$sessionMediaDirectionIndex], 'a=sendrecv') === 0
+						|| strpos($lines[$sessionMediaDirectionIndex], 'a=sendonly') === 0)) {
+					return true;
+				}
+
+				$mediaDescriptionIndex = $i;
+
+				if (strpos($lines[$i], 'm=' . $media) === 0) {
+					$matchingMediaDescriptionIndex = $i;
+				}
+			}
+		}
+
+		// No media direction in last matching media description, fallback to
+		// media direction in the session description or, if not set, default to
+		// "sendrecv".
+		if ($matchingMediaDescriptionIndex >= 0
+			&& $matchingMediaDescriptionIndex >= $mediaDescriptionIndex
+			&& $mediaDirectionIndex < $matchingMediaDescriptionIndex
+			&& ($sessionMediaDirectionIndex < 0
+				|| strpos($lines[$sessionMediaDirectionIndex], 'a=sendrecv') === 0
+				|| strpos($lines[$sessionMediaDirectionIndex], 'a=sendonly') === 0)) {
+			return true;
+		}
+
+		return false;
+	}
+
+	/**
+	 * Get signaling messages
+	 *
+	 * @param string $token Token of the room
+	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_NOT_FOUND|Http::STATUS_CONFLICT, list<array{type: string, data: TalkSignalingSession[]|string}>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, string, array{}>
+	 *
+	 * 200: Signaling messages returned
+	 * 400: Getting signaling messages is not possible
+	 * 404: Session, room or participant not found
+	 * 409: Session killed
+	 */
 	#[PublicPage]
+	#[OpenAPI(tags: ['internal_signaling'])]
 	public function pullMessages(string $token): DataResponse {
 		if ($this->talkConfig->getSignalingMode() !== Config::SIGNALING_INTERNAL) {
 			return new DataResponse('Internal signaling disabled.', Http::STATUS_BAD_REQUEST);
@@ -354,7 +525,8 @@ class SignalingController extends OCSController {
 			if ($participant->getSession() instanceof Session) {
 				$this->sessionService->updateLastPing($participant->getSession(), $pingTimestamp);
 			}
-		} catch (RoomNotFoundException $e) {
+		} catch (RoomNotFoundException) {
+			$this->banIpIfGuestGotBanned($token);
 			return new DataResponse([['type' => 'usersInRoom', 'data' => []]], Http::STATUS_NOT_FOUND);
 		}
 
@@ -366,10 +538,11 @@ class SignalingController extends OCSController {
 				return $message['data'] !== 'refresh-participant-list';
 			});
 
+			// Make sure the array is a json array not a json object,
+			// because the index list has a gap
+			$data = array_values($data);
+
 			if ($messageCount !== count($data)) {
-				// Make sure the array is a json array not a json object,
-				// because the index list has a gap
-				$data = array_values($data);
 				// Participant list changed, bail out and deliver the info to the user
 				break;
 			}
@@ -394,7 +567,8 @@ class SignalingController extends OCSController {
 			// Add an update of the room participants at the end of the waiting
 			$room = $this->manager->getRoomForSession($this->userId, $sessionId);
 			$data[] = ['type' => 'usersInRoom', 'data' => $this->getUsersInRoom($room, $pingTimestamp)];
-		} catch (RoomNotFoundException $e) {
+		} catch (RoomNotFoundException) {
+			$this->banIpIfGuestGotBanned($token);
 			$data[] = ['type' => 'usersInRoom', 'data' => []];
 
 			// Was the session killed or the complete conversation?
@@ -423,7 +597,7 @@ class SignalingController extends OCSController {
 	/**
 	 * @param Room $room
 	 * @param int $pingTimestamp
-	 * @return array[]
+	 * @return TalkSignalingSession[]
 	 */
 	protected function getUsersInRoom(Room $room, int $pingTimestamp): array {
 		$usersInRoom = [];
@@ -454,12 +628,31 @@ class SignalingController extends OCSController {
 				'sessionId' => $session->getSessionId(),
 				'inCall' => $session->getInCall(),
 				'participantPermissions' => $participant->getPermissions(),
+				'actorType' => $participant->getAttendee()->getActorType(),
+				'actorId' => $participant->getAttendee()->getActorId(),
 			];
 		}
 
 		return $usersInRoom;
 	}
 
+	protected function banIpIfGuestGotBanned(string $token): void {
+		if ($this->userId !== null) {
+			return;
+		}
+
+		try {
+			$room = $this->manager->getRoomByToken($token);
+		} catch (RoomNotFoundException) {
+			return;
+		}
+
+		try {
+			$this->banService->throwIfActorIsBanned($room, null);
+		} catch (ForbiddenException) {
+		}
+	}
+
 	/**
 	 * Check if the current request is coming from an allowed backend.
 	 *
@@ -501,13 +694,16 @@ class SignalingController extends OCSController {
 
 	/**
 	 * Backend API to query information required for standalone signaling
-	 * servers.
+	 * servers
 	 *
 	 * See sections "Backend validation" in
 	 * https://nextcloud-spreed-signaling.readthedocs.io/en/latest/standalone-signaling-api-v1/#backend-requests
 	 *
-	 * @return DataResponse
+	 * @return DataResponse<Http::STATUS_OK, array{type: string, error?: array{code: string, message: string}, auth?: array{version: string, userid?: string, user?: array<string, mixed>}, room?: array{version: string, roomid?: string, properties?: array<string, mixed>, permissions?: string[], session?: array<string, mixed>}}, array{}>
+	 *
+	 * 200: Always, sorry about that
 	 */
+	#[OpenAPI(scope: 'backend-signaling')]
 	#[PublicPage]
 	#[BruteForceProtection(action: 'talkSignalingSecret')]
 	public function backend(): DataResponse {
@@ -546,6 +742,9 @@ class SignalingController extends OCSController {
 		}
 	}
 
+	/**
+	 * @return DataResponse<Http::STATUS_OK, array{type: string, error?: array{code: string, message: string}, auth?: array{version: string, userid?: string, user?: array<string, mixed>}}, array{}>
+	 */
 	private function backendAuth(array $auth): DataResponse {
 		$params = $auth['params'];
 		$userId = $params['userid'];
@@ -597,6 +796,9 @@ class SignalingController extends OCSController {
 		return new DataResponse($response);
 	}
 
+	/**
+	 * @return DataResponse<Http::STATUS_OK, array{type: string, error?: array{code: string, message: string}, room?: array{version: string, roomid: string, properties: array<string, mixed>, permissions: string[], session?: array<string, mixed>}}, array{}>
+	 */
 	private function backendRoom(array $roomRequest): DataResponse {
 		$token = $roomRequest['roomid']; // It's actually the room token
 		$userId = $roomRequest['userid'];
@@ -616,6 +818,7 @@ class SignalingController extends OCSController {
 					'actorType' => $actorType ?? 'null',
 					'actorId' => $actorId ?? 'null',
 					'app' => 'spreed-hpb',
+					'hpbRequest' => json_encode($roomRequest),
 				]);
 				return new DataResponse([
 					'type' => 'error',
@@ -653,6 +856,7 @@ class SignalingController extends OCSController {
 				$this->logger->debug('Failed to get room by token {token}', [
 					'token' => $token,
 					'app' => 'spreed-hpb',
+					'hpbRequest' => json_encode($roomRequest),
 				]);
 				return new DataResponse([
 					'type' => 'error',
@@ -681,6 +885,7 @@ class SignalingController extends OCSController {
 			$this->logger->debug('Failed to get room {token} with participant', [
 				'token' => $token,
 				'app' => 'spreed-hpb',
+				'hpbRequest' => json_encode($roomRequest),
 			]);
 			// Return generic error to avoid leaking which rooms exist.
 			return new DataResponse([
@@ -720,60 +925,56 @@ class SignalingController extends OCSController {
 			// Emails are retained as their PIN needs to remain and stay
 			// valid.
 			if ($participant->getAttendee()->getActorType() === Attendee::ACTOR_GUESTS) {
-				$this->participantService->removeAttendee($room, $participant, Room::PARTICIPANT_LEFT);
+				$this->participantService->removeAttendee($room, $participant, AAttendeeRemovedEvent::REASON_LEFT);
 			} else {
 				$this->participantService->leaveRoomAsSession($room, $participant);
 			}
 		}
 
-		$permissions = [];
-		if ($participant instanceof Participant) {
-			$this->logger->debug('Room request to "{action}" room {token} by actor {actorType}/{actorId}', [
-				'token' => $token,
-				'action' => $action ?? 'null',
-				'actorType' => $participant->getAttendee()->getActorType(),
-				'actorId' => $participant->getAttendee()->getActorId(),
-				'app' => 'spreed-hpb',
-			]);
+		$this->logger->debug('Room request to "{action}" room {token} by actor {actorType}/{actorId}', [
+			'token' => $token,
+			'action' => $action ?? 'null',
+			'actorType' => $participant->getAttendee()->getActorType(),
+			'actorId' => $participant->getAttendee()->getActorId(),
+			'app' => 'spreed-hpb',
+			'hpbRequest' => json_encode($roomRequest),
+		]);
 
-			if ($participant->getPermissions() & Attendee::PERMISSIONS_PUBLISH_AUDIO) {
-				$permissions[] = 'publish-audio';
-			}
-			if ($participant->getPermissions() & Attendee::PERMISSIONS_PUBLISH_VIDEO) {
-				$permissions[] = 'publish-video';
-			}
-			if ($participant->getPermissions() & Attendee::PERMISSIONS_PUBLISH_SCREEN) {
-				$permissions[] = 'publish-screen';
-			}
-			if ($participant->hasModeratorPermissions(false)) {
-				$permissions[] = 'control';
-			}
-		} else {
-			$this->logger->debug('Room request to "{action}" room {token} without session', [
-				'token' => $token,
-				'action' => $action ?? 'null',
-				'app' => 'spreed-hpb',
-			]);
+		$permissions = [];
+		if ($participant->getPermissions() & Attendee::PERMISSIONS_PUBLISH_AUDIO) {
+			$permissions[] = 'publish-audio';
+		}
+		if ($participant->getPermissions() & Attendee::PERMISSIONS_PUBLISH_VIDEO) {
+			$permissions[] = 'publish-video';
+		}
+		if ($participant->getPermissions() & Attendee::PERMISSIONS_PUBLISH_SCREEN) {
+			$permissions[] = 'publish-screen';
+		}
+		if ($participant->hasModeratorPermissions(false)) {
+			$permissions[] = 'control';
 		}
 
-		$event = new SignalingEvent($room, $participant, $action);
-		$this->dispatcher->dispatch(self::EVENT_BACKEND_SIGNALING_ROOMS, $event);
+		$event = new BeforeSignalingResponseSentEvent($room, $participant, $action);
+		$this->dispatcher->dispatchTyped($event);
 
 		$response = [
 			'type' => 'room',
 			'room' => [
 				'version' => '1.0',
 				'roomid' => $room->getToken(),
-				'properties' => $room->getPropertiesForSignaling((string) $userId),
+				'properties' => $room->getPropertiesForSignaling((string)$userId),
 				'permissions' => $permissions,
 			],
 		];
-		if ($event->getSession()) {
+		if (!empty($event->getSession())) {
 			$response['room']['session'] = $event->getSession();
 		}
 		return new DataResponse($response);
 	}
 
+	/**
+	 * @return DataResponse<Http::STATUS_OK, array{type: string, room: array{version: string}}, array{}>
+	 */
 	private function backendPing(array $request): DataResponse {
 		$pingSessionIds = [];
 		$now = $this->timeFactory->getTime();
