@@ -2,25 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2016 Lukas Reschke <lukas@statuscode.ch>
- *
- * @author Lukas Reschke <lukas@statuscode.ch>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Controller;
@@ -29,6 +12,7 @@ use OC\Files\Filesystem;
 use OC\NotSquareException;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\Attribute\NoAdminRequired;
+use OCP\AppFramework\Http\Attribute\OpenAPI;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\OCSController;
 use OCP\IAvatarManager;
@@ -37,27 +21,28 @@ use OCP\IRequest;
 use Psr\Log\LoggerInterface;
 
 class TempAvatarController extends OCSController {
-	private IAvatarManager $avatarManager;
-	private IL10N $l;
-	private LoggerInterface $logger;
-	private string $userId;
 
 	public function __construct(
 		string $appName,
 		IRequest $request,
-		IAvatarManager $avatarManager,
-		IL10N $l,
-		LoggerInterface $logger,
-		string $userId,
+		private IAvatarManager $avatarManager,
+		private IL10N $l,
+		private LoggerInterface $logger,
+		private string $userId,
 	) {
 		parent::__construct($appName, $request);
-		$this->avatarManager = $avatarManager;
-		$this->logger = $logger;
-		$this->l = $l;
-		$this->userId = $userId;
 	}
 
+	/**
+	 * Upload your avatar as a user
+	 *
+	 * @return DataResponse<Http::STATUS_OK, array<empty>, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{message: string}, array{}>
+	 *
+	 * 200: Avatar uploaded successfully
+	 * 400: Uploading avatar is not possible
+	 */
 	#[NoAdminRequired]
+	#[OpenAPI(tags: ['user_avatar'])]
 	public function postAvatar(): DataResponse {
 		$files = $this->request->getUploadedFile('files');
 
@@ -123,7 +108,16 @@ class TempAvatarController extends OCSController {
 		}
 	}
 
+	/**
+	 * Delete your avatar as a user
+	 *
+	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_BAD_REQUEST, array<empty>, array{}>
+	 *
+	 * 200: Avatar deleted successfully
+	 * 400: Deleting avatar is not possible
+	 */
 	#[NoAdminRequired]
+	#[OpenAPI(tags: ['user_avatar'])]
 	public function deleteAvatar(): DataResponse {
 		try {
 			$avatar = $this->avatarManager->getAvatar($this->userId);
