@@ -2,39 +2,23 @@
 
 declare(strict_types=1);
 /**
- *
- * @copyright Copyright (c) 2018, Daniel Calviño Sánchez (danxuliu@gmail.com)
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Files;
 
-use OCA\Talk\Events\JoinRoomGuestEvent;
-use OCA\Talk\Events\JoinRoomUserEvent;
+use OCA\Talk\Events\BeforeGuestJoinedRoomEvent;
+use OCA\Talk\Events\BeforeUserJoinedRoomEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\UnauthorizedException;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\TalkSession;
-use OCP\EventDispatcher\IEventDispatcher;
+use OCP\EventDispatcher\Event;
+use OCP\EventDispatcher\IEventListener;
 use OCP\IUserManager;
-use OCP\Server;
 
 /**
  * Custom behaviour for rooms for files.
@@ -51,48 +35,41 @@ use OCP\Server;
  * These rooms are associated to a "file" object, and their custom behaviour is
  * provided by calling the methods of this class as a response to different room
  * events.
+ *
+ * @template-implements IEventListener<Event>
  */
-class Listener {
-	protected Util $util;
-	protected ParticipantService $participantService;
-	protected IUserManager $userManager;
-	protected TalkSession $talkSession;
+class Listener implements IEventListener {
 
 	public function __construct(
-		Util $util,
-		ParticipantService $participantService,
-		IUserManager $userManager,
-		TalkSession $talkSession,
+		protected Util $util,
+		protected ParticipantService $participantService,
+		protected IUserManager $userManager,
+		protected TalkSession $talkSession,
 	) {
-		$this->util = $util;
-		$this->participantService = $participantService;
-		$this->userManager = $userManager;
-		$this->talkSession = $talkSession;
 	}
 
-	public static function register(IEventDispatcher $dispatcher): void {
-		$listener = static function (JoinRoomUserEvent $event): void {
-			$listener = Server::get(self::class);
-
-			try {
-				$listener->preventUsersWithoutAccessToTheFileFromJoining($event->getRoom(), $event->getUser()->getUID());
-				$listener->addUserAsPersistentParticipant($event->getRoom(), $event->getUser()->getUID());
-			} catch (UnauthorizedException $e) {
-				$event->setCancelJoin(true);
-			}
+	public function handle(Event $event): void {
+		match (get_class($event)) {
+			BeforeUserJoinedRoomEvent::class => $this->beforeUserJoinedRoomEvent($event),
+			BeforeGuestJoinedRoomEvent::class => $this->beforeGuestJoinedRoomEvent($event),
 		};
-		$dispatcher->addListener(Room::EVENT_BEFORE_ROOM_CONNECT, $listener);
+	}
 
-		$listener = static function (JoinRoomGuestEvent $event): void {
-			$listener = Server::get(self::class);
+	protected function beforeUserJoinedRoomEvent(BeforeUserJoinedRoomEvent $event): void {
+		try {
+			$this->preventUsersWithoutAccessToTheFileFromJoining($event->getRoom(), $event->getUser()->getUID());
+			$this->addUserAsPersistentParticipant($event->getRoom(), $event->getUser()->getUID());
+		} catch (UnauthorizedException) {
+			$event->setCancelJoin(true);
+		}
+	}
 
-			try {
-				$listener->preventGuestsFromJoiningIfNotPubliclyAccessible($event->getRoom());
-			} catch (UnauthorizedException $e) {
-				$event->setCancelJoin(true);
-			}
-		};
-		$dispatcher->addListener(Room::EVENT_BEFORE_GUEST_CONNECT, $listener);
+	protected function beforeGuestJoinedRoomEvent(BeforeGuestJoinedRoomEvent $event): void {
+		try {
+			$this->preventGuestsFromJoiningIfNotPubliclyAccessible($event->getRoom());
+		} catch (UnauthorizedException) {
+			$event->setCancelJoin(true);
+		}
 	}
 
 	/**
@@ -111,7 +88,7 @@ class Listener {
 	 * @param string $userId
 	 * @throws UnauthorizedException
 	 */
-	public function preventUsersWithoutAccessToTheFileFromJoining(Room $room, string $userId): void {
+	protected function preventUsersWithoutAccessToTheFileFromJoining(Room $room, string $userId): void {
 		if ($room->getObjectType() !== 'file') {
 			return;
 		}
@@ -140,7 +117,7 @@ class Listener {
 	 * @param Room $room
 	 * @param string $userId
 	 */
-	public function addUserAsPersistentParticipant(Room $room, string $userId): void {
+	protected function addUserAsPersistentParticipant(Room $room, string $userId): void {
 		if ($room->getObjectType() !== 'file') {
 			return;
 		}
