@@ -2,31 +2,18 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2016 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk;
 
 use OCA\Talk\Chat\CommentsManager;
-use OCA\Talk\Events\RoomEvent;
+use OCA\Talk\Events\AAttendeeRemovedEvent;
+use OCA\Talk\Events\RoomCreatedEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\RoomNotFoundException;
+use OCA\Talk\Federation\Authenticator;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\AttendeeMapper;
 use OCA\Talk\Model\SelectHelper;
@@ -38,7 +25,6 @@ use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
 use OCP\Comments\ICommentsManager;
 use OCP\Comments\NotFoundException;
-use OCP\DB\Exception as DBException;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\ICache;
@@ -51,61 +37,32 @@ use OCP\IUserManager;
 use OCP\Security\IHasher;
 use OCP\Security\ISecureRandom;
 use OCP\Server;
+use SensitiveParameter;
 
 class Manager {
-	public const EVENT_TOKEN_GENERATE = self::class . '::generateNewToken';
 
-	protected IDBConnection $db;
-	protected IConfig $config;
-	protected Config $talkConfig;
-	protected IAppManager $appManager;
-	protected AttendeeMapper $attendeeMapper;
-	protected SessionMapper $sessionMapper;
-	protected ParticipantService $participantService;
-	protected ISecureRandom $secureRandom;
-	protected IUserManager $userManager;
-	protected IGroupManager $groupManager;
 	protected ICommentsManager $commentsManager;
-	protected TalkSession $talkSession;
-	protected IEventDispatcher $dispatcher;
-	protected ITimeFactory $timeFactory;
-	protected IHasher $hasher;
-	protected IL10N $l;
 
 	public function __construct(
-		IDBConnection $db,
-		IConfig $config,
-		Config $talkConfig,
-		IAppManager $appManager,
-		AttendeeMapper $attendeeMapper,
-		SessionMapper $sessionMapper,
-		ParticipantService $participantService,
-		ISecureRandom $secureRandom,
-		IUserManager $userManager,
-		IGroupManager $groupManager,
+		protected IDBConnection $db,
+		protected IConfig $config,
+		protected Config $talkConfig,
+		protected IAppManager $appManager,
+		protected AttendeeMapper $attendeeMapper,
+		protected SessionMapper $sessionMapper,
+		protected ParticipantService $participantService,
+		protected ISecureRandom $secureRandom,
+		protected IUserManager $userManager,
+		protected IGroupManager $groupManager,
 		CommentsManager $commentsManager,
-		TalkSession $talkSession,
-		IEventDispatcher $dispatcher,
-		ITimeFactory $timeFactory,
-		IHasher $hasher,
-		IL10N $l,
+		protected TalkSession $talkSession,
+		protected IEventDispatcher $dispatcher,
+		protected ITimeFactory $timeFactory,
+		protected IHasher $hasher,
+		protected IL10N $l,
+		protected Authenticator $federationAuthenticator,
 	) {
-		$this->db = $db;
-		$this->config = $config;
-		$this->talkConfig = $talkConfig;
-		$this->appManager = $appManager;
-		$this->attendeeMapper = $attendeeMapper;
-		$this->sessionMapper = $sessionMapper;
-		$this->participantService = $participantService;
-		$this->secureRandom = $secureRandom;
-		$this->userManager = $userManager;
-		$this->groupManager = $groupManager;
 		$this->commentsManager = $commentsManager;
-		$this->talkSession = $talkSession;
-		$this->dispatcher = $dispatcher;
-		$this->timeFactory = $timeFactory;
-		$this->hasher = $hasher;
-		$this->l = $l;
 	}
 
 	public function forAllRooms(callable $callback): void {
@@ -148,7 +105,6 @@ class Manager {
 			'avatar' => '',
 			'remote_server' => '',
 			'remote_token' => '',
-			'active_guests' => 0,
 			'default_permissions' => 0,
 			'call_permissions' => 0,
 			'call_flag' => 0,
@@ -162,6 +118,9 @@ class Manager {
 			'breakout_room_mode' => 0,
 			'breakout_room_status' => 0,
 			'call_recording' => 0,
+			'recording_consent' => 0,
+			'has_federation' => 0,
+			'mention_permissions' => 0,
 		], $data));
 	}
 
@@ -192,7 +151,7 @@ class Manager {
 
 		$assignedSignalingServer = $row['assigned_hpb'];
 		if ($assignedSignalingServer !== null) {
-			$assignedSignalingServer = (int) $assignedSignalingServer;
+			$assignedSignalingServer = (int)$assignedSignalingServer;
 		}
 
 		return new Room(
@@ -200,35 +159,37 @@ class Manager {
 			$this->db,
 			$this->dispatcher,
 			$this->timeFactory,
-			(int) $row['r_id'],
-			(int) $row['type'],
-			(int) $row['read_only'],
-			(int) $row['listable'],
-			(int) $row['message_expiration'],
-			(int) $row['lobby_state'],
-			(int) $row['sip_enabled'],
+			(int)$row['r_id'],
+			(int)$row['type'],
+			(int)$row['read_only'],
+			(int)$row['listable'],
+			(int)$row['message_expiration'],
+			(int)$row['lobby_state'],
+			(int)$row['sip_enabled'],
 			$assignedSignalingServer,
-			(string) $row['token'],
-			(string) $row['name'],
-			(string) $row['description'],
-			(string) $row['password'],
-			(string) $row['avatar'],
-			(string) $row['remote_server'],
-			(string) $row['remote_token'],
-			(int) $row['active_guests'],
-			(int) $row['default_permissions'],
-			(int) $row['call_permissions'],
-			(int) $row['call_flag'],
+			(string)$row['token'],
+			(string)$row['name'],
+			(string)$row['description'],
+			(string)$row['password'],
+			(string)$row['avatar'],
+			(string)$row['remote_server'],
+			(string)$row['remote_token'],
+			(int)$row['default_permissions'],
+			(int)$row['call_permissions'],
+			(int)$row['call_flag'],
 			$activeSince,
 			$lastActivity,
-			(int) $row['last_message'],
+			(int)$row['last_message'],
 			$lastMessage,
 			$lobbyTimer,
-			(string) $row['object_type'],
-			(string) $row['object_id'],
-			(int) $row['breakout_room_mode'],
-			(int) $row['breakout_room_status'],
-			(int) $row['call_recording']
+			(string)$row['object_type'],
+			(string)$row['object_id'],
+			(int)$row['breakout_room_mode'],
+			(int)$row['breakout_room_status'],
+			(int)$row['call_recording'],
+			(int)$row['recording_consent'],
+			(int)$row['has_federation'],
+			(int)$row['mention_permissions'],
 		);
 	}
 
@@ -266,6 +227,7 @@ class Manager {
 			'latest_child_timestamp' => $row['comment_latest_child_timestamp'],
 			'reactions' => $row['comment_reactions'],
 			'expire_date' => $row['comment_expire_date'],
+			'meta_data' => $row['comment_meta_data'],
 		]);
 	}
 
@@ -301,7 +263,7 @@ class Manager {
 	 * @param int|null $offset
 	 * @return Room[]
 	 */
-	public function searchRoomsByToken(string $searchToken = '', int $limit = null, int $offset = null): array {
+	public function searchRoomsByToken(string $searchToken = '', ?int $limit = null, ?int $offset = null): array {
 		$query = $this->db->getQueryBuilder();
 		$helper = new SelectHelper();
 		$helper->selectRoomsTable($query);
@@ -333,6 +295,28 @@ class Manager {
 		return $rooms;
 	}
 
+	/**
+	 * @return Room[]
+	 */
+	public function getRoomsLongerActiveSince(\DateTime $maxActiveSince): array {
+		$query = $this->db->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
+			->where($query->expr()->isNotNull('r.active_since'))
+			->andWhere($query->expr()->lte('r.active_since', $query->createNamedParameter($maxActiveSince, IQueryBuilder::PARAM_DATE)))
+			->orderBy('r.id', 'ASC');
+		$result = $query->executeQuery();
+
+		$rooms = [];
+		while ($row = $result->fetch()) {
+			$rooms[] = $this->createRoomObject($row);
+		}
+		$result->closeCursor();
+
+		return $rooms;
+	}
+
 	/**
 	 * @param string $userId
 	 * @param array $sessionIds A list of talk sessions to consider for loading (otherwise no session is loaded)
@@ -385,7 +369,9 @@ class Manager {
 
 			$room = $this->createRoomObject($row);
 			if ($actorType === Attendee::ACTOR_USERS && isset($row['actor_id'])) {
-				$room->setParticipant($row['actor_id'], $this->createParticipantObject($room, $row));
+				$participant = $this->createParticipantObject($room, $row);
+				$this->participantService->cacheParticipant($room, $participant);
+				$room->setParticipant($row['actor_id'], $participant);
 			}
 			$rooms[] = $room;
 		}
@@ -422,25 +408,39 @@ class Manager {
 		return $rooms;
 	}
 
-	public function removeUserFromAllRooms(IUser $user): void {
+	public function removeUserFromAllRooms(IUser $user, bool $privateOnly = false): void {
 		$rooms = $this->getRoomsForUser($user->getUID());
 		foreach ($rooms as $room) {
+			if ($privateOnly) {
+				if ($room->getType() === Room::TYPE_ONE_TO_ONE
+					|| $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER
+					|| $room->getType() === Room::TYPE_PUBLIC) {
+					continue;
+				}
+
+				if ($this->isRoomListableByUser($room, $user->getUID())) {
+					continue;
+				}
+			}
+
 			if ($this->participantService->getNumberOfUsers($room) === 1) {
 				Server::get(RoomService::class)->deleteRoom($room);
 			} else {
-				$this->participantService->removeUser($room, $user, Room::PARTICIPANT_REMOVED_ALL);
+				$this->participantService->removeUser($room, $user, AAttendeeRemovedEvent::REASON_REMOVED_ALL);
 			}
 		}
 
-		$leftRooms = $this->getLeftOneToOneRoomsForUser($user->getUID());
-		foreach ($leftRooms as $room) {
-			// We are changing the room type and name so a potential follow-up
-			// user with the same user-id can not reopen the one-to-one conversation.
-			/** @var RoomService $roomService */
-			$roomService = Server::get(RoomService::class);
-			$roomService->setType($room, Room::TYPE_ONE_TO_ONE_FORMER, true);
-			$roomService->setName($room, $user->getDisplayName(), '');
-			$roomService->setReadOnly($room, Room::READ_ONLY);
+		if (!$privateOnly) {
+			$leftRooms = $this->getLeftOneToOneRoomsForUser($user->getUID());
+			foreach ($leftRooms as $room) {
+				// We are changing the room type and name so a potential follow-up
+				// user with the same user-id can not reopen the one-to-one conversation.
+				/** @var RoomService $roomService */
+				$roomService = Server::get(RoomService::class);
+				$roomService->setType($room, Room::TYPE_ONE_TO_ONE_FORMER, true);
+				$roomService->setName($room, $user->getDisplayName(), '');
+				$roomService->setReadOnly($room, Room::READ_ONLY);
+			}
 		}
 	}
 
@@ -501,7 +501,7 @@ class Manager {
 		if ($term !== '') {
 			$query->andWhere(
 				$query->expr()->iLike('name', $query->createNamedParameter(
-					'%' . $this->db->escapeLikeParameter($term). '%'
+					'%' . $this->db->escapeLikeParameter($term) . '%'
 				))
 			);
 		}
@@ -558,7 +558,9 @@ class Manager {
 
 		$room = $this->createRoomObject($row);
 		if ($userId !== null && isset($row['actor_id'])) {
-			$room->setParticipant($row['actor_id'], $this->createParticipantObject($room, $row));
+			$participant = $this->createParticipantObject($room, $row);
+			$this->participantService->cacheParticipant($room, $participant);
+			$room->setParticipant($row['actor_id'], $participant);
 		}
 
 		if ($userId === null && $room->getType() !== Room::TYPE_PUBLIC) {
@@ -629,7 +631,9 @@ class Manager {
 
 		$room = $this->createRoomObject($row);
 		if ($userId !== null && isset($row['actor_id'])) {
-			$room->setParticipant($row['actor_id'], $this->createParticipantObject($room, $row));
+			$participant = $this->createParticipantObject($room, $row);
+			$this->participantService->cacheParticipant($room, $participant);
+			$room->setParticipant($row['actor_id'], $participant);
 		}
 
 		if ($isSIPBridgeRequest || $room->getType() === Room::TYPE_PUBLIC) {
@@ -643,7 +647,6 @@ class Manager {
 			}
 
 			// never joined before but found in listing
-			$listable = (int)$row['listable'];
 			if ($this->isRoomListableByUser($room, $userId)) {
 				return $room;
 			}
@@ -681,11 +684,6 @@ class Manager {
 	}
 
 	/**
-	 * @param string $token
-	 * @param string $actorType
-	 * @param string $actorId
-	 * @param string|null $sessionId
-	 * @return Room
 	 * @throws RoomNotFoundException
 	 */
 	public function getRoomByActor(string $token, string $actorType, string $actorId, ?string $sessionId = null, ?string $serverUrl = null): Room {
@@ -732,7 +730,9 @@ class Manager {
 
 		$room = $this->createRoomObject($row);
 		if ($actorType === Attendee::ACTOR_USERS && isset($row['actor_id'])) {
-			$room->setParticipant($row['actor_id'], $this->createParticipantObject($room, $row));
+			$participant = $this->createParticipantObject($room, $row);
+			$this->participantService->cacheParticipant($room, $participant);
+			$room->setParticipant($row['actor_id'], $participant);
 		}
 
 		return $room;
@@ -740,10 +740,90 @@ class Manager {
 
 	/**
 	 * @param string $token
-	 * @param string|null $preloadUserId Load this participant's information if possible
+	 * @param string $actorType
+	 * @param string $actorId
+	 * @param string $remoteAccess
+	 * @param ?string $sessionId
 	 * @return Room
 	 * @throws RoomNotFoundException
 	 */
+	public function getRoomByRemoteAccess(
+		string $token,
+		string $actorType,
+		string $actorId,
+		#[SensitiveParameter]
+		string $remoteAccess,
+		?string $sessionId = null,
+	): Room {
+		return $this->getRoomByAccessToken($token, $actorType, $actorId, $remoteAccess, $sessionId);
+	}
+
+	/**
+	 * @param string $token
+	 * @param string $actorType
+	 * @param string $actorId
+	 * @param string $remoteAccess
+	 * @param ?string $sessionId
+	 * @return Room
+	 * @throws RoomNotFoundException
+	 */
+	public function getRoomByAccessToken(
+		string $token,
+		string $actorType,
+		string $actorId,
+		#[SensitiveParameter]
+		string $accessToken,
+		?string $sessionId = null,
+	): Room {
+		$query = $this->db->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$helper->selectAttendeesTable($query);
+		$query->from('talk_rooms', 'r')
+			->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
+				$query->expr()->eq('a.actor_type', $query->createNamedParameter($actorType)),
+				$query->expr()->eq('a.actor_id', $query->createNamedParameter($actorId)),
+				$query->expr()->eq('a.access_token', $query->createNamedParameter($accessToken)),
+				$query->expr()->eq('a.room_id', 'r.id')
+			))
+			->where($query->expr()->eq('r.token', $query->createNamedParameter($token)));
+
+		if ($sessionId !== null) {
+			$helper->selectSessionsTable($query);
+			$query->leftJoin('a', 'talk_sessions', 's', $query->expr()->andX(
+				$query->expr()->eq('s.session_id', $query->createNamedParameter($sessionId)),
+				$query->expr()->eq('a.id', 's.attendee_id')
+			));
+		}
+
+		$result = $query->executeQuery();
+		$row = $result->fetch();
+		$result->closeCursor();
+
+		if ($row === false) {
+			throw new RoomNotFoundException();
+		}
+
+		if ($row['token'] === null) {
+			// FIXME Temporary solution for the Talk6 release
+			throw new RoomNotFoundException();
+		}
+
+		$room = $this->createRoomObject($row);
+		if (isset($row['actor_id'])) {
+			$participant = $this->createParticipantObject($room, $row);
+			$this->participantService->cacheParticipant($room, $participant);
+		} else {
+			throw new RoomNotFoundException();
+		}
+
+		return $room;
+	}
+
+	/**
+	 * @param string|null $preloadUserId Load this participant's information if possible
+	 * @throws RoomNotFoundException
+	 */
 	public function getRoomByToken(string $token, ?string $preloadUserId = null, ?string $serverUrl = null): Room {
 		$preloadUserId = $preloadUserId === '' ? null : $preloadUserId;
 		if ($preloadUserId !== null) {
@@ -812,9 +892,7 @@ class Manager {
 	}
 
 	/**
-	 * @param string $objectType
-	 * @param string $objectId
-	 * @return Room[]
+	 * @return list<Room>
 	 */
 	public function getMultipleRoomsByObject(string $objectType, string $objectId, bool $orderById = false): array {
 		$query = $this->db->getQueryBuilder();
@@ -839,6 +917,28 @@ class Manager {
 		return $rooms;
 	}
 
+	/**
+	 * @param string[] $tokens
+	 * @return array<string, Room>
+	 */
+	public function getRoomsByToken(array $tokens): array {
+		$query = $this->db->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
+			->where($query->expr()->in('r.token', $query->createNamedParameter($tokens, IQueryBuilder::PARAM_STR_ARRAY)));
+
+		$result = $query->executeQuery();
+		$rooms = [];
+		while ($row = $result->fetch()) {
+			$room = $this->createRoomObject($row);
+			$rooms[$room->getToken()] = $room;
+		}
+		$result->closeCursor();
+
+		return $rooms;
+	}
+
 	/**
 	 * @param string|null $userId
 	 * @param string|null $sessionId
@@ -874,7 +974,7 @@ class Manager {
 				throw new RoomNotFoundException();
 			}
 		} else {
-			if ($row['actor_type'] !== Attendee::ACTOR_GUESTS) {
+			if ($row['actor_type'] !== Attendee::ACTOR_GUESTS && $row['actor_type'] !== Attendee::ACTOR_EMAILS) {
 				throw new RoomNotFoundException();
 			}
 		}
@@ -886,6 +986,7 @@ class Manager {
 
 		$room = $this->createRoomObject($row);
 		$participant = $this->createParticipantObject($room, $row);
+		$this->participantService->cacheParticipant($room, $participant);
 		$room->setParticipant($row['actor_id'], $participant);
 
 		if ($room->getType() === Room::TYPE_PUBLIC || !in_array($participant->getAttendee()->getParticipantType(), [Participant::GUEST, Participant::GUEST_MODERATOR, Participant::USER_SELF_JOINED], true)) {
@@ -1012,18 +1113,12 @@ class Manager {
 			'object_id' => $objectId,
 		]);
 
-		$event = new RoomEvent($room);
-		$this->dispatcher->dispatch(Room::EVENT_AFTER_ROOM_CREATE, $event);
+		$event = new RoomCreatedEvent($room);
+		$this->dispatcher->dispatchTyped($event);
 
 		return $room;
 	}
 
-	/**
-	 * @param int $type
-	 * @param string $name
-	 * @return Room
-	 * @throws DBException
-	 */
 	public function createRemoteRoom(int $type, string $name, string $remoteToken, string $remoteServer): Room {
 		$token = $this->getNewToken();
 
@@ -1060,11 +1155,17 @@ class Manager {
 			return $this->l->t('Talk updates ✅');
 		}
 
-		if ($forceName) {
-			return $room->getName();
+		if ($this->federationAuthenticator->isFederationRequest()) {
+			try {
+				$authenticatedRoom = $this->federationAuthenticator->getRoom();
+				if ($authenticatedRoom->getId() === $room->getId()) {
+					return $room->getName();
+				}
+			} catch (RoomNotFoundException) {
+			}
 		}
 
-		if ($userId === '' && $room->getType() !== Room::TYPE_PUBLIC) {
+		if (!$forceName && $userId === '' && $room->getType() !== Room::TYPE_PUBLIC) {
 			return $this->l->t('Private conversation');
 		}
 
@@ -1105,6 +1206,10 @@ class Manager {
 			return $otherParticipant;
 		}
 
+		if ($forceName) {
+			return $room->getName();
+		}
+
 		if (!$this->isRoomListableByUser($room, $userId)) {
 			try {
 				if ($userId === '') {
@@ -1164,7 +1269,7 @@ class Manager {
 	 * @return string
 	 */
 	protected function getNewToken(): string {
-		$entropy = (int) $this->config->getAppValue('spreed', 'token_entropy', '8');
+		$entropy = (int)$this->config->getAppValue('spreed', 'token_entropy', '8');
 		$entropy = max(8, $entropy); // For update cases
 		$digitsOnly = $this->talkConfig->isSIPConfigured();
 		if ($digitsOnly) {
@@ -1195,7 +1300,7 @@ class Manager {
 		}
 
 		$entropy++;
-		$this->config->setAppValue('spreed', 'token_entropy', (string) $entropy);
+		$this->config->setAppValue('spreed', 'token_entropy', (string)$entropy);
 		return $this->generateNewToken($query, $entropy, $digitsOnly);
 	}
 
@@ -1242,8 +1347,7 @@ class Manager {
 	}
 
 	/**
-	 * Returns whether the given user id is a guest user from
-	 * the guest app
+	 * Returns whether the given user id is a user created with the Guests app
 	 *
 	 * @param string $userId user id to check
 	 * @return bool true if the user is a guest, false otherwise
@@ -1257,7 +1361,10 @@ class Manager {
 	}
 
 	protected function loadLastMessageInfo(IQueryBuilder $query): void {
-		$query->leftJoin('r', 'comments', 'c', $query->expr()->eq('r.last_message', 'c.id'));
+		$query->leftJoin('r', 'comments', 'c', $query->expr()->andX(
+			$query->expr()->eq('r.last_message', 'c.id'),
+			$query->expr()->emptyString('r.remote_server'),
+		));
 		$query->selectAlias('c.id', 'comment_id');
 		$query->selectAlias('c.parent_id', 'comment_parent_id');
 		$query->selectAlias('c.topmost_parent_id', 'comment_topmost_parent_id');
@@ -1276,5 +1383,6 @@ class Manager {
 		$query->selectAlias('c.latest_child_timestamp', 'comment_latest_child_timestamp');
 		$query->selectAlias('c.reactions', 'comment_reactions');
 		$query->selectAlias('c.expire_date', 'comment_expire_date');
+		$query->selectAlias('c.meta_data', 'comment_meta_data');
 	}
 }
