@@ -2,92 +2,87 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2019 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Middleware;
 
 use OCA\Talk\Controller\AEnvironmentAwareController;
+use OCA\Talk\Exceptions\CannotReachRemoteException;
+use OCA\Talk\Exceptions\ForbiddenException;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\PermissionsException;
 use OCA\Talk\Exceptions\RoomNotFoundException;
+use OCA\Talk\Federation\Authenticator;
 use OCA\Talk\Manager;
+use OCA\Talk\Middleware\Attribute\AllowWithoutParticipantWhenPendingInvitation;
+use OCA\Talk\Middleware\Attribute\FederationSupported;
+use OCA\Talk\Middleware\Attribute\RequireAuthenticatedParticipant;
+use OCA\Talk\Middleware\Attribute\RequireFederatedParticipant;
 use OCA\Talk\Middleware\Attribute\RequireLoggedInModeratorParticipant;
 use OCA\Talk\Middleware\Attribute\RequireLoggedInParticipant;
 use OCA\Talk\Middleware\Attribute\RequireModeratorOrNoLobby;
 use OCA\Talk\Middleware\Attribute\RequireModeratorParticipant;
 use OCA\Talk\Middleware\Attribute\RequireParticipant;
+use OCA\Talk\Middleware\Attribute\RequireParticipantOrLoggedInAndListedConversation;
 use OCA\Talk\Middleware\Attribute\RequirePermission;
 use OCA\Talk\Middleware\Attribute\RequireReadWriteConversation;
 use OCA\Talk\Middleware\Attribute\RequireRoom;
+use OCA\Talk\Middleware\Exceptions\FederationUnsupportedFeatureException;
 use OCA\Talk\Middleware\Exceptions\LobbyException;
 use OCA\Talk\Middleware\Exceptions\NotAModeratorException;
 use OCA\Talk\Middleware\Exceptions\ReadOnlyException;
 use OCA\Talk\Model\Attendee;
+use OCA\Talk\Model\InvitationMapper;
+use OCA\Talk\Model\Session;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
+use OCA\Talk\Service\BanService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\TalkSession;
 use OCA\Talk\Webinary;
 use OCP\AppFramework\Controller;
+use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\Attribute\BruteForceProtection;
-use OCP\AppFramework\Http\RedirectToDefaultAppResponse;
+use OCP\AppFramework\Http\RedirectResponse;
 use OCP\AppFramework\Http\Response;
 use OCP\AppFramework\Middleware;
 use OCP\AppFramework\OCS\OCSException;
 use OCP\AppFramework\OCSController;
+use OCP\Federation\ICloudIdManager;
 use OCP\IRequest;
+use OCP\IURLGenerator;
 use OCP\Security\Bruteforce\IThrottler;
+use OCP\Security\Bruteforce\MaxDelayReached;
+use Psr\Log\LoggerInterface;
 
 class InjectionMiddleware extends Middleware {
-	protected IRequest $request;
-	protected ParticipantService $participantService;
-	protected TalkSession $talkSession;
-	protected Manager $manager;
-	protected IThrottler $throttler;
-	protected ?string $userId;
-
 	public function __construct(
-		IRequest $request,
-		ParticipantService $participantService,
-		TalkSession $talkSession,
-		Manager $manager,
-		IThrottler $throttler,
-		?string $userId,
+		protected IRequest $request,
+		protected ParticipantService $participantService,
+		protected TalkSession $talkSession,
+		protected Manager $manager,
+		protected ICloudIdManager $cloudIdManager,
+		protected IThrottler $throttler,
+		protected IURLGenerator $url,
+		protected InvitationMapper $invitationMapper,
+		protected Authenticator $federationAuthenticator,
+		protected BanService $banService,
+		protected LoggerInterface $logger,
+		protected ?string $userId,
 	) {
-		$this->request = $request;
-		$this->participantService = $participantService;
-		$this->talkSession = $talkSession;
-		$this->manager = $manager;
-		$this->throttler = $throttler;
-		$this->userId = $userId;
 	}
 
 	/**
-	 * @param Controller $controller
-	 * @param string $methodName
+	 * @throws FederationUnsupportedFeatureException
 	 * @throws LobbyException
 	 * @throws NotAModeratorException
 	 * @throws ParticipantNotFoundException
 	 * @throws PermissionsException
 	 * @throws ReadOnlyException
+	 * @throws ForbiddenException
 	 * @throws RoomNotFoundException
 	 */
 	public function beforeController(Controller $controller, string $methodName): void {
@@ -98,7 +93,20 @@ class InjectionMiddleware extends Middleware {
 		$reflectionMethod = new \ReflectionMethod($controller, $methodName);
 
 		$apiVersion = $this->request->getParam('apiVersion');
-		$controller->setAPIVersion((int) substr($apiVersion, 1));
+		$controller->setAPIVersion((int)substr($apiVersion, 1));
+
+		if (!empty($reflectionMethod->getAttributes(AllowWithoutParticipantWhenPendingInvitation::class))) {
+			try {
+				$this->getRoomByInvite($controller);
+				return;
+			} catch (RoomNotFoundException|ParticipantNotFoundException) {
+				// Falling back to bellow checks
+			}
+		}
+
+		if (!empty($reflectionMethod->getAttributes(RequireAuthenticatedParticipant::class))) {
+			$this->getLoggedInOrGuest($controller, false, requireFederationWhenNotLoggedIn: true);
+		}
 
 		if (!empty($reflectionMethod->getAttributes(RequireLoggedInParticipant::class))) {
 			$this->getLoggedIn($controller, false);
@@ -108,6 +116,16 @@ class InjectionMiddleware extends Middleware {
 			$this->getLoggedIn($controller, true);
 		}
 
+		if (!empty($reflectionMethod->getAttributes(RequireParticipantOrLoggedInAndListedConversation::class))) {
+			$this->getLoggedInOrGuest($controller, false, true);
+		}
+
+		$attributes = $reflectionMethod->getAttributes(RequireFederatedParticipant::class);
+		if (!empty($attributes)) {
+			$sessionIdParameter = $this->readSessionIdParameterFromAttributes($attributes);
+			$this->getLoggedInOrGuest($controller, false, sessionIdParameter: $sessionIdParameter);
+		}
+
 		if (!empty($reflectionMethod->getAttributes(RequireParticipant::class))) {
 			$this->getLoggedInOrGuest($controller, false);
 		}
@@ -120,6 +138,11 @@ class InjectionMiddleware extends Middleware {
 			$this->getRoom($controller);
 		}
 
+		if (empty($reflectionMethod->getAttributes(FederationSupported::class))) {
+			// When federation is not supported, the room needs to be local
+			$this->checkFederationSupport($controller);
+		}
+
 		if (!empty($reflectionMethod->getAttributes(RequireReadWriteConversation::class))) {
 			$this->checkReadOnlyState($controller);
 		}
@@ -138,13 +161,27 @@ class InjectionMiddleware extends Middleware {
 		}
 	}
 
+	protected function readSessionIdParameterFromAttributes(array $attributes): ?string {
+		foreach ($attributes as $attribute) {
+			/** @var RequireFederatedParticipant $instance */
+			$instance = $attribute->newInstance();
+			if ($instance->getSessionIdParameter() !== null) {
+				return $instance->getSessionIdParameter();
+			}
+		}
+		return null;
+	}
+
 	/**
 	 * @param AEnvironmentAwareController $controller
+	 * @throws ForbiddenException
 	 */
 	protected function getRoom(AEnvironmentAwareController $controller): void {
 		$token = $this->request->getParam('token');
 		$room = $this->manager->getRoomByToken($token);
 		$controller->setRoom($room);
+
+		$this->banService->throwIfActorIsBanned($room, $this->userId);
 	}
 
 	/**
@@ -161,6 +198,8 @@ class InjectionMiddleware extends Middleware {
 		$participant = $this->participantService->getParticipant($room, $this->userId, $sessionId);
 		$controller->setParticipant($participant);
 
+		$this->banService->throwIfActorIsBanned($room, $this->userId);
+
 		if ($moderatorRequired && !$participant->hasModeratorPermissions(false)) {
 			throw new NotAModeratorException();
 		}
@@ -169,15 +208,47 @@ class InjectionMiddleware extends Middleware {
 	/**
 	 * @param AEnvironmentAwareController $controller
 	 * @param bool $moderatorRequired
+	 * @param bool $requireListedWhenNoParticipant
 	 * @throws NotAModeratorException
 	 * @throws ParticipantNotFoundException
 	 */
-	protected function getLoggedInOrGuest(AEnvironmentAwareController $controller, bool $moderatorRequired): void {
+	protected function getLoggedInOrGuest(
+		AEnvironmentAwareController $controller,
+		bool $moderatorRequired,
+		bool $requireListedWhenNoParticipant = false,
+		bool $requireFederationWhenNotLoggedIn = false,
+		?string $sessionIdParameter = null,
+	): void {
+		if ($requireFederationWhenNotLoggedIn && $this->userId === null && !$this->federationAuthenticator->isFederationRequest()) {
+			throw new ParticipantNotFoundException();
+		}
+
+		if ($sessionIdParameter !== null && !$this->federationAuthenticator->isFederationRequest()) {
+			throw new ParticipantNotFoundException();
+		}
+
 		$room = $controller->getRoom();
+		$sessionId = null;
 		if (!$room instanceof Room) {
 			$token = $this->request->getParam('token');
-			$sessionId = $this->talkSession->getSessionForRoom($token);
-			$room = $this->manager->getRoomForUserByToken($token, $this->userId, $sessionId);
+			if (!$this->federationAuthenticator->isFederationRequest()) {
+				$sessionId = $this->talkSession->getSessionForRoom($token);
+				$room = $this->manager->getRoomForUserByToken($token, $this->userId, $sessionId);
+			} else {
+				$sessionId = $sessionIdParameter !== null ? $this->request->getParam($sessionIdParameter) : null;
+				$room = $this->manager->getRoomByRemoteAccess($token, Attendee::ACTOR_FEDERATED_USERS, $this->federationAuthenticator->getCloudId(), $this->federationAuthenticator->getAccessToken(), $sessionId);
+
+				// Get and set the participant already, so we don't retry public access
+				$participant = $this->participantService->getParticipantByActor($room, Attendee::ACTOR_FEDERATED_USERS, $this->federationAuthenticator->getCloudId());
+
+				if ($sessionIdParameter !== null && !$participant->getSession() instanceof Session) {
+					// If a session is required, fail if we didn't find it
+					throw new ParticipantNotFoundException();
+				}
+
+				$this->federationAuthenticator->authenticated($room, $participant);
+				$controller->setParticipant($participant);
+			}
 			$controller->setRoom($room);
 		}
 
@@ -187,6 +258,7 @@ class InjectionMiddleware extends Middleware {
 			if ($sessionId !== null) {
 				try {
 					$participant = $this->participantService->getParticipantBySession($room, $sessionId);
+					$controller->setParticipant($participant);
 				} catch (ParticipantNotFoundException $e) {
 					// ignore and fall back in case a concurrent request might have
 					// invalidated the session
@@ -194,17 +266,59 @@ class InjectionMiddleware extends Middleware {
 			}
 
 			if ($participant === null) {
-				$participant = $this->participantService->getParticipant($room, $this->userId);
+				if (!$requireListedWhenNoParticipant || !$this->manager->isRoomListableByUser($room, $this->userId)) {
+					$participant = $this->participantService->getParticipant($room, $this->userId);
+					$controller->setParticipant($participant);
+				}
 			}
-
-			$controller->setParticipant($participant);
 		}
 
+		$this->banService->throwIfActorIsBanned($room, $this->userId);
+
 		if ($moderatorRequired && !$participant->hasModeratorPermissions()) {
 			throw new NotAModeratorException();
 		}
 	}
 
+	/**
+	 * @param AEnvironmentAwareController $controller
+	 * @throws RoomNotFoundException
+	 * @throws ParticipantNotFoundException
+	 */
+	protected function getRoomByInvite(AEnvironmentAwareController $controller): void {
+		if ($this->userId === null) {
+			throw new ParticipantNotFoundException('No user available');
+		}
+
+		$room = $controller->getRoom();
+		if (!$room instanceof Room) {
+			$token = $this->request->getParam('token');
+			$room = $this->manager->getRoomByToken($token);
+		}
+
+		$participant = $controller->getParticipant();
+		if (!$participant instanceof Participant) {
+			try {
+				$invitation = $this->invitationMapper->getInvitationForUserByLocalRoom($room, $this->userId);
+				$controller->setRoom($room);
+				$controller->setInvitation($invitation);
+			} catch (DoesNotExistException $e) {
+				throw new ParticipantNotFoundException('No invite available', $e->getCode(), $e);
+			}
+		}
+	}
+
+	/**
+	 * @param AEnvironmentAwareController $controller
+	 * @throws FederationUnsupportedFeatureException
+	 */
+	protected function checkFederationSupport(AEnvironmentAwareController $controller): void {
+		$room = $controller->getRoom();
+		if ($room instanceof Room && $room->isFederatedConversation()) {
+			throw new FederationUnsupportedFeatureException();
+		}
+	}
+
 	/**
 	 * @param AEnvironmentAwareController $controller
 	 * @throws ReadOnlyException
@@ -220,7 +334,6 @@ class InjectionMiddleware extends Middleware {
 	}
 
 	/**
-	 * @param AEnvironmentAwareController $controller
 	 * @throws PermissionsException
 	 */
 	protected function checkPermission(AEnvironmentAwareController $controller, string $permission): void {
@@ -238,15 +351,13 @@ class InjectionMiddleware extends Middleware {
 	}
 
 	/**
-	 * @param AEnvironmentAwareController $controller
 	 * @throws LobbyException
 	 */
 	protected function checkLobbyState(AEnvironmentAwareController $controller): void {
 		try {
 			$this->getLoggedInOrGuest($controller, true);
 			return;
-		} catch (NotAModeratorException $e) {
-		} catch (ParticipantNotFoundException $e) {
+		} catch (NotAModeratorException|ParticipantNotFoundException) {
 		}
 
 		$participant = $controller->getParticipant();
@@ -262,13 +373,9 @@ class InjectionMiddleware extends Middleware {
 	}
 
 	/**
-	 * @param Controller $controller
-	 * @param string $methodName
-	 * @param \Exception $exception
 	 * @throws \Exception
-	 * @return Response
 	 */
-	public function afterException($controller, $methodName, \Exception $exception): Response {
+	public function afterException(Controller $controller, string $methodName, \Exception $exception): Response {
 		if ($exception instanceof RoomNotFoundException ||
 			$exception instanceof ParticipantNotFoundException) {
 			if ($controller instanceof OCSController) {
@@ -281,8 +388,13 @@ class InjectionMiddleware extends Middleware {
 						$protection = $attribute->newInstance();
 						$action = $protection->getAction();
 
-						if ('talkRoomToken' === $action) {
-							$this->throttler->sleepDelay($this->request->getRemoteAddress(), $action);
+						if ($action === 'talkRoomToken') {
+							$this->logger->debug('User "' . ($this->userId ?? 'ANONYMOUS') . '" throttled for accessing "' . ($this->request->getParam('token') ?? 'UNKNOWN') . '"', ['app' => 'spreed-bfp']);
+							try {
+								$this->throttler->sleepDelayOrThrowOnMax($this->request->getRemoteAddress(), $action);
+							} catch (MaxDelayReached $e) {
+								throw new OCSException($e->getMessage(), Http::STATUS_TOO_MANY_REQUESTS);
+							}
 							$this->throttler->registerAttempt($action, $this->request->getRemoteAddress(), [
 								'token' => $this->request->getParam('token') ?? '',
 							]);
@@ -293,7 +405,23 @@ class InjectionMiddleware extends Middleware {
 				throw new OCSException('', Http::STATUS_NOT_FOUND);
 			}
 
-			return new RedirectToDefaultAppResponse();
+			return new RedirectResponse($this->url->linkToDefaultPageUrl());
+		}
+
+		if ($exception instanceof CannotReachRemoteException) {
+			if ($controller instanceof OCSController) {
+				throw new OCSException('', Http::STATUS_UNPROCESSABLE_ENTITY);
+			}
+
+			return new RedirectResponse($this->url->linkToDefaultPageUrl());
+		}
+
+		if ($exception instanceof FederationUnsupportedFeatureException) {
+			if ($controller instanceof OCSController) {
+				throw new OCSException('', Http::STATUS_NOT_ACCEPTABLE);
+			}
+
+			return new RedirectResponse($this->url->linkToDefaultPageUrl());
 		}
 
 		if ($exception instanceof LobbyException) {
@@ -301,17 +429,18 @@ class InjectionMiddleware extends Middleware {
 				throw new OCSException('', Http::STATUS_PRECONDITION_FAILED);
 			}
 
-			return new RedirectToDefaultAppResponse();
+			return new RedirectResponse($this->url->linkToDefaultPageUrl());
 		}
 
 		if ($exception instanceof NotAModeratorException ||
 			$exception instanceof ReadOnlyException ||
+			$exception instanceof ForbiddenException ||
 			$exception instanceof PermissionsException) {
 			if ($controller instanceof OCSController) {
 				throw new OCSException('', Http::STATUS_FORBIDDEN);
 			}
 
-			return new RedirectToDefaultAppResponse();
+			return new RedirectResponse($this->url->linkToDefaultPageUrl());
 		}
 
 		throw $exception;
