@@ -2,37 +2,19 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2021 Gary Kim <gary@garykim.dev>
- *
- * @author Gary Kim <gary@garykim.dev>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Model;
 
 use OCA\Talk\Room;
 use OCP\AppFramework\Db\DoesNotExistException;
-use OCP\AppFramework\Db\MultipleObjectsReturnedException;
 use OCP\AppFramework\Db\QBMapper;
-use OCP\DB\Exception as DBException;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
 use OCP\IUser;
+use SensitiveParameter;
 
 /**
  * Class InvitationMapper
@@ -50,8 +32,6 @@ class InvitationMapper extends QBMapper {
 	}
 
 	/**
-	 * @throws DBException
-	 * @throws MultipleObjectsReturnedException
 	 * @throws DoesNotExistException
 	 */
 	public function getInvitationById(int $id): Invitation {
@@ -65,24 +45,28 @@ class InvitationMapper extends QBMapper {
 	}
 
 	/**
-	 * @param Room $room
-	 * @return Invitation[]
-	 * @throws DBException
+	 * @throws DoesNotExistException
 	 */
-	public function getInvitationsForRoom(Room $room): array {
+	public function getByRemoteAndAccessToken(
+		string $remoteServerUrl,
+		int $remoteAttendeeId,
+		#[SensitiveParameter]
+		string $accessToken,
+	): Invitation {
 		$qb = $this->db->getQueryBuilder();
 
 		$qb->select('*')
 			->from($this->getTableName())
-			->where($qb->expr()->eq('room_id', $qb->createNamedParameter($room->getId())));
+			->where($qb->expr()->eq('remote_server_url', $qb->createNamedParameter($remoteServerUrl)))
+			->andWhere($qb->expr()->eq('remote_attendee_id', $qb->createNamedParameter($remoteAttendeeId, IQueryBuilder::PARAM_INT)))
+			->andWhere($qb->expr()->eq('access_token', $qb->createNamedParameter($accessToken)));
 
-		return $this->findEntities($qb);
+		return $this->findEntity($qb);
 	}
 
 	/**
 	 * @param IUser $user
 	 * @return Invitation[]
-	 * @throws DBException
 	 */
 	public function getInvitationsForUser(IUser $user): array {
 		$qb = $this->db->getQueryBuilder();
@@ -95,29 +79,55 @@ class InvitationMapper extends QBMapper {
 	}
 
 	/**
-	 * @throws DBException
+	 * @psalm-param Invitation::STATE_*|null $state
 	 */
-	public function countInvitationsForRoom(Room $room): int {
+	public function countInvitationsForUser(IUser $user, ?int $state = null): int {
+		$qb = $this->db->getQueryBuilder();
+
+		$qb->select($qb->func()->count('*'))
+			->from($this->getTableName())
+			->where($qb->expr()->eq('user_id', $qb->createNamedParameter($user->getUID())));
+
+		if ($state !== null) {
+			$qb->andWhere($qb->expr()->eq('state', $qb->createNamedParameter($state)));
+		}
+
+		$result = $qb->executeQuery();
+		$count = (int)$result->fetchOne();
+		$result->closeCursor();
+
+		return $count;
+	}
+
+	/**
+	 * @throws DoesNotExistException
+	 */
+	public function getInvitationForUserByLocalRoom(Room $room, string $userId, bool $caseInsensitive = false): Invitation {
+		$query = $this->db->getQueryBuilder();
+
+		$query->select('*')
+			->from($this->getTableName())
+			->where($query->expr()->eq('local_room_id', $query->createNamedParameter($room->getId())));
+
+		if ($caseInsensitive) {
+			$query->andWhere($query->expr()->eq($query->func()->lower('user_id'), $query->createNamedParameter(strtolower($userId))));
+		} else {
+			$query->andWhere($query->expr()->eq('user_id', $query->createNamedParameter($userId)));
+		}
+		return $this->findEntity($query);
+	}
+
+	public function countInvitationsForLocalRoom(Room $room): int {
 		$qb = $this->db->getQueryBuilder();
 
 		$qb->select($qb->func()->count('*', 'num_invitations'))
 			->from($this->getTableName())
-			->where($qb->expr()->eq('room_id', $qb->createNamedParameter($room->getId())));
+			->where($qb->expr()->eq('local_room_id', $qb->createNamedParameter($room->getId())));
 
 		$result = $qb->executeQuery();
 		$row = $result->fetch();
 		$result->closeCursor();
 
-		return (int) ($row['num_invitations' ?? 0]);
-	}
-
-	public function createInvitationFromRow(array $row): Invitation {
-		return $this->mapRowToEntity([
-			'id' => $row['id'],
-			'room_id' => (int) $row['room_id'],
-			'user_id' => (string) $row['user_id'],
-			'access_token' => (string) $row['access_token'],
-			'remote_id' => (string) $row['remote_id'],
-		]);
+		return (int)($row['num_invitations'] ?? 0);
 	}
 }
