@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Model;
@@ -41,7 +26,6 @@ class SelectHelper {
 			->addSelect($alias . 'description')
 			->addSelect($alias . 'password')
 			->addSelect($alias . 'avatar')
-			->addSelect($alias . 'active_guests')
 			->addSelect($alias . 'active_since')
 			->addSelect($alias . 'default_permissions')
 			->addSelect($alias . 'call_permissions')
@@ -58,6 +42,9 @@ class SelectHelper {
 			->addSelect($alias . 'breakout_room_mode')
 			->addSelect($alias . 'breakout_room_status')
 			->addSelect($alias . 'call_recording')
+			->addSelect($alias . 'recording_consent')
+			->addSelect($alias . 'has_federation')
+			->addSelect($alias . 'mention_permissions')
 			->selectAlias($alias . 'id', 'r_id');
 	}
 
@@ -83,6 +70,13 @@ class SelectHelper {
 			->addSelect($alias . 'permissions')
 			->addSelect($alias . 'access_token')
 			->addSelect($alias . 'remote_id')
+			->addSelect($alias . 'invited_cloud_id')
+			->addSelect($alias . 'phone_number')
+			->addSelect($alias . 'call_id')
+			->addSelect($alias . 'state')
+			->addSelect($alias . 'unread_messages')
+			->addSelect($alias . 'last_attendee_activity')
+			->addSelect($alias . 'archived')
 			->selectAlias($alias . 'id', 'a_id');
 	}
 
@@ -95,6 +89,7 @@ class SelectHelper {
 			->addSelect($alias . 'session_id')
 			->addSelect($alias . 'in_call')
 			->addSelect($alias . 'last_ping')
+			->selectAlias($alias . 'state', 's_state')
 			->selectAlias($alias . 'id', 's_id');
 	}
 
@@ -108,6 +103,7 @@ class SelectHelper {
 			// BIT_OR would be better, but SQLite does not support something like it.
 			->selectAlias($query->func()->max($alias . 'in_call'), 'in_call')
 			->selectAlias($query->func()->max($alias . 'last_ping'), 'last_ping')
+			->selectAlias($query->func()->max($alias . 'state'), 's_state')
 			->selectAlias($query->func()->max($alias . 'id'), 's_id');
 	}
 }
