@@ -2,29 +2,13 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2022 Joas Schilling <coding@schilljs.com>
- *
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Service;
 
+use OCA\Talk\Exceptions\PollPropertyException;
 use OCA\Talk\Exceptions\WrongPermissionsException;
 use OCA\Talk\Model\Poll;
 use OCA\Talk\Model\PollMapper;
@@ -32,42 +16,40 @@ use OCA\Talk\Model\Vote;
 use OCA\Talk\Model\VoteMapper;
 use OCA\Talk\Participant;
 use OCP\AppFramework\Db\DoesNotExistException;
+use OCP\Comments\ICommentsManager;
 use OCP\DB\Exception;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
 
 class PollService {
-	protected IDBConnection $connection;
-	protected PollMapper $pollMapper;
-	protected VoteMapper $voteMapper;
 
 	public function __construct(
-		IDBConnection $connection,
-		PollMapper $pollMapper,
-		VoteMapper $voteMapper,
+		protected IDBConnection $connection,
+		protected PollMapper $pollMapper,
+		protected VoteMapper $voteMapper,
 	) {
-		$this->connection = $connection;
-		$this->pollMapper = $pollMapper;
-		$this->voteMapper = $voteMapper;
 	}
 
-	public function createPoll(int $roomId, string $actorType, string $actorId, string $displayName, string $question, array $options, int $resultMode, int $maxVotes): Poll {
+	/**
+	 * @throws PollPropertyException
+	 */
+	public function createPoll(int $roomId, string $actorType, string $actorId, string $displayName, string $question, array $options, int $resultMode, int $maxVotes, bool $draft): Poll {
 		$question = trim($question);
 
 		if ($question === '' || strlen($question) > 32_000) {
-			throw new \UnexpectedValueException();
+			throw new PollPropertyException(PollPropertyException::REASON_QUESTION);
 		}
 
 		try {
 			json_encode($options, JSON_THROW_ON_ERROR, 1);
-		} catch (\Exception $e) {
-			throw new \RuntimeException();
+		} catch (\Exception) {
+			throw new PollPropertyException(PollPropertyException::REASON_OPTIONS);
 		}
 
 		$validOptions = [];
 		foreach ($options as $option) {
 			if (!is_string($option)) {
-				throw new \RuntimeException();
+				throw new PollPropertyException(PollPropertyException::REASON_OPTIONS);
 			}
 
 			$option = trim($option);
@@ -77,17 +59,17 @@ class PollService {
 		}
 
 		if (count($validOptions) < 2) {
-			throw new \RuntimeException();
+			throw new PollPropertyException(PollPropertyException::REASON_OPTIONS);
 		}
 
 		try {
 			$jsonOptions = json_encode($validOptions, JSON_THROW_ON_ERROR, 1);
-		} catch (\Exception $e) {
-			throw new \RuntimeException();
+		} catch (\Exception) {
+			throw new PollPropertyException(PollPropertyException::REASON_OPTIONS);
 		}
 
 		if (strlen($jsonOptions) > 60_000) {
-			throw new \UnexpectedValueException();
+			throw new PollPropertyException(PollPropertyException::REASON_OPTIONS);
 		}
 
 		$poll = new Poll();
@@ -100,12 +82,23 @@ class PollService {
 		$poll->setVotes(json_encode([]));
 		$poll->setResultMode($resultMode);
 		$poll->setMaxVotes($maxVotes);
+		if ($draft) {
+			$poll->setStatus(Poll::STATUS_DRAFT);
+		}
 
 		$this->pollMapper->insert($poll);
 
 		return $poll;
 	}
 
+	/**
+	 * @param int $roomId
+	 * @return Poll[]
+	 */
+	public function getDraftsForRoom(int $roomId): array {
+		return $this->pollMapper->getDraftsByRoomId($roomId);
+	}
+
 	/**
 	 * @param int $roomId
 	 * @param int $pollId
@@ -345,8 +338,8 @@ class PollService {
 		$update = $this->connection->getQueryBuilder();
 		$update->update('talk_polls')
 			->set('display_name', $update->createNamedParameter(''))
-			->set('actor_type', $update->createNamedParameter('deleted_users'))
-			->set('actor_id', $update->createNamedParameter('deleted_users'))
+			->set('actor_type', $update->createNamedParameter(ICommentsManager::DELETED_USER))
+			->set('actor_id', $update->createNamedParameter(ICommentsManager::DELETED_USER))
 			->where($update->expr()->eq('actor_type', $update->createNamedParameter($actorType)))
 			->andWhere($update->expr()->eq('actor_id', $update->createNamedParameter($actorId)));
 		$update->executeStatement();
@@ -354,8 +347,8 @@ class PollService {
 		$update = $this->connection->getQueryBuilder();
 		$update->update('talk_poll_votes')
 			->set('display_name', $update->createNamedParameter(''))
-			->set('actor_type', $update->createNamedParameter('deleted_users'))
-			->set('actor_id', $update->createNamedParameter('deleted_users'))
+			->set('actor_type', $update->createNamedParameter(ICommentsManager::DELETED_USER))
+			->set('actor_id', $update->createNamedParameter(ICommentsManager::DELETED_USER))
 			->where($update->expr()->eq('actor_type', $update->createNamedParameter($actorType)))
 			->andWhere($update->expr()->eq('actor_id', $update->createNamedParameter($actorId)));
 		$update->executeStatement();
