@@ -2,26 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2022, Vitor Mattos <vitor@php.rio>
- * @copyright Copyright (c) 2023, Elmer Miroslav Mosher Golovin (miroslav@mishamosher.com)
- *
- * @author Vitor Mattos <vitor@php.rio>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Service;
@@ -37,6 +19,7 @@ use OCA\Talk\Manager;
 use OCA\Talk\Participant;
 use OCA\Talk\Recording\BackendNotifier;
 use OCA\Talk\Room;
+use OCP\AppFramework\Services\IAppConfig;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Files\File;
 use OCP\Files\Folder;
@@ -45,14 +28,25 @@ use OCP\Files\IRootFolder;
 use OCP\Files\NotFoundException;
 use OCP\Files\NotPermittedException;
 use OCP\IConfig;
+use OCP\IUserManager;
+use OCP\L10N\IFactory;
 use OCP\Notification\IManager;
-use OCP\PreConditionNotMetException;
 use OCP\Share\IManager as ShareManager;
 use OCP\Share\IShare;
-use OCP\SpeechToText\ISpeechToTextManager;
+use OCP\TaskProcessing\Exception\Exception;
+use OCP\TaskProcessing\IManager as ITaskProcessingManager;
+use OCP\TaskProcessing\Task;
+use OCP\TaskProcessing\TaskTypes\AudioToText;
+use OCP\TaskProcessing\TaskTypes\TextToTextSummary;
 use Psr\Log\LoggerInterface;
 
 class RecordingService {
+	public const CONSENT_REQUIRED_NO = 0;
+	public const CONSENT_REQUIRED_YES = 1;
+	public const CONSENT_REQUIRED_OPTIONAL = 2;
+
+	public const APPCONFIG_PREFIX = 'recording/';
+
 	public const DEFAULT_ALLOWED_RECORDING_FORMATS = [
 		'audio/ogg' => ['ogg'],
 		'video/ogg' => ['ogv'],
@@ -78,12 +72,15 @@ class RecordingService {
 		protected ITimeFactory $timeFactory,
 		protected Config $config,
 		protected IConfig $serverConfig,
+		protected IAppConfig $appConfig,
 		protected RoomService $roomService,
 		protected ShareManager $shareManager,
 		protected ChatManager $chatManager,
 		protected LoggerInterface $logger,
 		protected BackendNotifier $backendNotifier,
-		protected ISpeechToTextManager $speechToTextManager,
+		protected ITaskProcessingManager $taskProcessingManager,
+		protected IFactory $l10nFactory,
+		protected IUserManager $userManager,
 	) {
 	}
 
@@ -106,6 +103,7 @@ class RecordingService {
 
 		$startingStatus = $status === Room::RECORDING_VIDEO ? Room::RECORDING_VIDEO_STARTING : Room::RECORDING_AUDIO_STARTING;
 		$this->roomService->setCallRecording($room, $startingStatus);
+		$this->appConfig->setAppValueString(self::APPCONFIG_PREFIX . $room->getToken(), $owner, true, true);
 	}
 
 	public function stop(Room $room, ?Participant $participant = null): void {
@@ -124,6 +122,7 @@ class RecordingService {
 	}
 
 	public function store(Room $room, string $owner, array $file): void {
+		$this->appConfig->deleteAppValue(self::APPCONFIG_PREFIX . $room->getToken());
 		try {
 			$participant = $this->participantService->getParticipant($room, $owner);
 		} catch (ParticipantNotFoundException $e) {
@@ -147,54 +146,190 @@ class RecordingService {
 			throw new InvalidArgumentException('owner_permission');
 		}
 
-		if (!$this->serverConfig->getAppValue('spreed', 'call_recording_transcription', 'no') === 'yes') {
+		$shouldTranscribe = $this->serverConfig->getAppValue('spreed', 'call_recording_transcription', 'no') === 'yes';
+		$shouldSummarize = $this->serverConfig->getAppValue('spreed', 'call_recording_summary', 'yes') === 'yes';
+		if (!$shouldTranscribe && !$shouldSummarize) {
+			$this->logger->debug('Skipping transcription and summary of call recording, as both are disabled');
+			return;
+		}
+
+		$supportedTaskTypes = $this->taskProcessingManager->getAvailableTaskTypes();
+		if (!isset($supportedTaskTypes[AudioToText::ID])) {
+			$this->logger->error('Can not transcribe call recording as no Audio2Text task provider is available');
+			return;
+		}
+
+		$task = new Task(
+			AudioToText::ID,
+			['input' => $fileNode->getId()],
+			Application::APP_ID,
+			$owner,
+			'call/transcription/' . $room->getToken(),
+		);
+
+		try {
+			$this->taskProcessingManager->scheduleTask($task);
+			$this->logger->debug('Scheduled call recording transcript');
+		} catch (Exception $e) {
+			$this->logger->error('An error occurred while trying to transcribe the call recording', ['exception' => $e]);
+		}
+	}
+
+	/**
+	 * @param 'transcript'|'summary' $aiTask
+	 */
+	public function storeTranscript(string $owner, string $roomToken, int $recordingFileId, string $output, string $aiTask): void {
+		$userFolder = $this->rootFolder->getUserFolder($owner);
+		$recordingNodes = $userFolder->getById($recordingFileId);
+
+		if (empty($recordingNodes)) {
+			$this->logger->warning("Could not save recording $aiTask as the recording could not be found", [
+				'owner' => $owner,
+				'roomToken' => $roomToken,
+				'recordingFileId' => $recordingFileId,
+			]);
+			throw new InvalidArgumentException('owner_participant');
+		}
+		$recording = array_pop($recordingNodes);
+		$recordingFolder = $recording->getParent();
+
+		if ($recordingFolder->getName() !== $roomToken) {
+			$this->logger->warning("Could not determinate conversation when trying to store $aiTask of call recording, as folder name did not match customId conversation token");
+			throw new InvalidArgumentException('owner_participant');
+		}
+
+		try {
+			$room = $this->roomManager->getRoomForUserByToken($roomToken, $owner);
+			$participant = $this->participantService->getParticipant($room, $owner);
+		} catch (ParticipantNotFoundException) {
+			$this->logger->warning("Could not determinate conversation when trying to store $aiTask of call recording");
+			throw new InvalidArgumentException('owner_participant');
+		}
+
+		$shouldTranscribe = $this->serverConfig->getAppValue('spreed', 'call_recording_transcription', 'no') === 'yes';
+		$shouldSummarize = $this->serverConfig->getAppValue('spreed', 'call_recording_summary', 'yes') === 'yes';
+
+		if ($aiTask === 'transcript') {
+			$transcriptFileName = pathinfo($recording->getName(), PATHINFO_FILENAME) . '.md';
+			if (!$shouldTranscribe) {
+				$this->logger->debug('Skipping saving of transcript for call recording as it is disabled');
+			}
+		} else {
+			$transcriptFileName = pathinfo($recording->getName(), PATHINFO_FILENAME) . ' - ' . $aiTask . '.md';
+		}
+
+		if (($shouldTranscribe && $aiTask === 'transcript')
+			|| ($shouldSummarize && $aiTask === 'summary')) {
+			$user = $this->userManager->get($owner);
+			$language = $this->l10nFactory->getUserLanguage($user);
+			$l = $this->l10nFactory->get(Application::APP_ID, $language);
+
+			if ($aiTask === 'transcript') {
+				$warning = $l->t('Transcript is AI generated and may contain mistakes');
+			} else {
+				$warning = $l->t('Summary is AI generated and may contain mistakes');
+			}
+
+			try {
+				$fileNode = $recordingFolder->newFile(
+					$transcriptFileName,
+					$output . "\n\n$warning\n",
+				);
+				$this->notifyStoredTranscript($room, $participant, $fileNode, $aiTask);
+			} catch (NoUserException) {
+				throw new InvalidArgumentException('owner_invalid');
+			} catch (NotPermittedException) {
+				throw new InvalidArgumentException('owner_permission');
+			}
+		}
+
+		if (!$shouldSummarize) {
+			// If summary is off skip scheduling it
+			$this->logger->debug('Skipping scheduling summary of call recording as it is disabled');
+			return;
+		}
+
+		if ($aiTask === 'summary') {
+			// After saving the summary there is nothing more to do
+			return;
+		}
+
+		$supportedTaskTypes = $this->taskProcessingManager->getAvailableTaskTypes();
+		if (!isset($supportedTaskTypes[TextToTextSummary::ID])) {
+			$this->logger->error('Can not summarize call recording as no TextToTextSummary task provider is available');
+			return;
+		}
+
+		$task = new Task(
+			TextToTextSummary::ID,
+			['input' => $output],
+			Application::APP_ID,
+			$owner,
+			'call/summary/' . $room->getToken() . '/' . $recordingFileId,
+		);
+
+		try {
+			$this->taskProcessingManager->scheduleTask($task);
+			$this->logger->debug('Scheduled call recording summary');
+		} catch (Exception $e) {
+			$this->logger->error('An error occurred while trying to summarize the call recording', ['exception' => $e]);
+		}
+	}
+
+	/**
+	 * @throws InvalidArgumentException
+	 */
+	public function notifyAboutFailedStore(Room $room): void {
+		$owner = $this->appConfig->getAppValueString(self::APPCONFIG_PREFIX . $room->getToken(), lazy: true);
+		if ($owner === '') {
 			return;
 		}
 
 		try {
-			$this->speechToTextManager->scheduleFileTranscription($fileNode, $owner, Application::APP_ID);
-			$this->logger->debug('Scheduled transcription of call recording');
-		} catch (PreConditionNotMetException $e) {
-			// No Speech-to-text provider installed
-			$this->logger->debug('Could not generate transcript of call recording', ['exception' => $e]);
-		} catch (InvalidArgumentException $e) {
-			$this->logger->warning('Could not generate transcript of call recording', ['exception' => $e]);
-		}
-	}
-
-	public function storeTranscript(string $owner, File $recording, string $transcript): void {
-		$recordingFolder = $recording->getParent();
-		$roomToken = $recordingFolder->getName();
-
-		try {
-			$room = $this->roomManager->getRoomForUserByToken($roomToken, $owner);
 			$participant = $this->participantService->getParticipant($room, $owner);
 		} catch (ParticipantNotFoundException) {
-			$this->logger->warning('Could not determinate conversation when trying to store transcription of call recording');
+			$this->logger->warning('Could not determinate conversation when trying to notify about failed upload of call recording');
 			throw new InvalidArgumentException('owner_participant');
 		}
 
-		$transcriptFileName = pathinfo($recording->getName(), PATHINFO_FILENAME) . '.txt';
+		$attendee = $participant->getAttendee();
 
-		try {
-			$fileNode = $recordingFolder->newFile($transcriptFileName, $transcript);
-			$this->notifyStoredTranscript($room, $participant, $fileNode);
-		} catch (NoUserException) {
-			throw new InvalidArgumentException('owner_invalid');
-		} catch (NotPermittedException) {
-			throw new InvalidArgumentException('owner_permission');
-		}
+		$notification = $this->notificationManager->createNotification();
+
+		$notification
+			->setApp('spreed')
+			->setDateTime($this->timeFactory->getDateTime())
+			->setObject('recording_information', $room->getToken())
+			->setUser($attendee->getActorId())
+			->setSubject('record_file_store_fail');
+		$this->notificationManager->notify($notification);
 	}
 
-	public function notifyAboutFailedTranscript(string $owner, File $recording): void {
+	public function notifyAboutFailedTranscript(string $owner, string $roomToken, int $recordingFileId, string $aiType): void {
+		$userFolder = $this->rootFolder->getUserFolder($owner);
+		$recordingNodes = $userFolder->getById($recordingFileId);
+
+		if (empty($recordingNodes)) {
+			$this->logger->warning("Could not trying to notify about failed $aiType as the recording could not be found", [
+				'owner' => $owner,
+				'roomToken' => $roomToken,
+				'recordingFileId' => $recordingFileId,
+			]);
+			throw new InvalidArgumentException('owner_participant');
+		}
+		$recording = array_pop($recordingNodes);
 		$recordingFolder = $recording->getParent();
-		$roomToken = $recordingFolder->getName();
+
+		if ($recordingFolder->getName() !== $roomToken) {
+			$this->logger->warning("Could not determinate conversation when trying to notify about failed $aiType, as folder name did not match customId conversation token");
+			throw new InvalidArgumentException('owner_participant');
+		}
 
 		try {
 			$room = $this->roomManager->getRoomForUserByToken($roomToken, $owner);
 			$participant = $this->participantService->getParticipant($room, $owner);
 		} catch (ParticipantNotFoundException) {
-			$this->logger->warning('Could not determinate conversation when trying to notify about failed transcription of call recording');
+			$this->logger->warning("Could not determinate conversation when trying to notify about failed $aiType of call recording");
 			throw new InvalidArgumentException('owner_participant');
 		}
 
@@ -207,7 +342,7 @@ class RecordingService {
 			->setDateTime($this->timeFactory->getDateTime())
 			->setObject('recording', $room->getToken())
 			->setUser($attendee->getActorId())
-			->setSubject('transcript_failed', [
+			->setSubject($aiType === 'transcript' ? 'transcript_failed' : 'summary_failed', [
 				'objectId' => $recording->getId(),
 			]);
 		$this->notificationManager->notify($notification);
@@ -283,10 +418,17 @@ class RecordingService {
 		$userFolder = $this->rootFolder->getUserFolder($owner);
 		$recordingRootFolderName = $this->config->getRecordingFolder($owner);
 		try {
-			/** @var \OCP\Files\Folder */
+			/** @var Folder */
 			$recordingRootFolder = $userFolder->get($recordingRootFolderName);
+			if ($recordingRootFolder->isShared()) {
+				$this->logger->error('Talk attachment folder for user {userId} is set to a shared folder. Resetting to their root.', [
+					'userId' => $owner,
+				]);
+
+				$this->serverConfig->setUserValue($owner, 'spreed', 'attachment_folder', '/');
+			}
 		} catch (NotFoundException $e) {
-			/** @var \OCP\Files\Folder */
+			/** @var Folder */
 			$recordingRootFolder = $userFolder->newFolder($recordingRootFolderName);
 		}
 		try {
@@ -314,7 +456,10 @@ class RecordingService {
 	}
 
 
-	public function notifyStoredTranscript(Room $room, Participant $participant, File $file): void {
+	/**
+	 * @param 'transcript'|'summary' $aiType
+	 */
+	public function notifyStoredTranscript(Room $room, Participant $participant, File $file, string $aiType): void {
 		$attendee = $participant->getAttendee();
 
 		$notification = $this->notificationManager->createNotification();
@@ -324,20 +469,26 @@ class RecordingService {
 			->setDateTime($this->timeFactory->getDateTime())
 			->setObject('recording', $room->getToken())
 			->setUser($attendee->getActorId())
-			->setSubject('transcript_file_stored', [
+			->setSubject($aiType === 'transcript' ? 'transcript_file_stored' : 'summary_file_stored', [
 				'objectId' => $file->getId(),
 			]);
 		$this->notificationManager->notify($notification);
 	}
 
-	public function notificationDismiss(Room $room, Participant $participant, int $timestamp): void {
+	public function notificationDismiss(Room $room, Participant $participant, int $timestamp, ?string $notificationSubject): void {
 		$notification = $this->notificationManager->createNotification();
 		$notification->setApp('spreed')
 			->setObject('recording', $room->getToken())
 			->setDateTime($this->timeFactory->getDateTime('@' . $timestamp))
 			->setUser($participant->getAttendee()->getActorId());
 
-		foreach (['record_file_stored', 'transcript_file_stored'] as $subject) {
+		if ($notificationSubject === null) {
+			$subjects = ['record_file_stored', 'transcript_file_stored', 'summary_file_stored'];
+		} else {
+			$subjects = [$notificationSubject];
+		}
+
+		foreach ($subjects as $subject) {
 			$notification->setSubject($subject);
 			$this->notificationManager->markProcessed($notification);
 		}
@@ -345,9 +496,9 @@ class RecordingService {
 
 	private function getTypeOfShare(string $mimetype): string {
 		if (str_starts_with($mimetype, 'video/')) {
-			return 'record-video';
+			return ChatManager::VERB_RECORD_VIDEO;
 		}
-		return 'record-audio';
+		return ChatManager::VERB_RECORD_AUDIO;
 	}
 
 	public function shareToChat(Room $room, Participant $participant, int $fileId, int $timestamp): void {
@@ -355,8 +506,8 @@ class RecordingService {
 			$userFolder = $this->rootFolder->getUserFolder(
 				$participant->getAttendee()->getActorId()
 			);
-			/** @var \OCP\Files\File[] */
 			$files = $userFolder->getById($fileId);
+			/** @var \OCP\Files\File $file */
 			$file = array_shift($files);
 		} catch (\Throwable $th) {
 			throw new InvalidArgumentException('file');
@@ -373,6 +524,15 @@ class RecordingService {
 			->setSharedWith($room->getToken())
 			->setPermissions(\OCP\Constants::PERMISSION_READ);
 
+		$removeNotification = null;
+		if (!str_ends_with($file->getName(), '.md')) {
+			$removeNotification = 'record_file_stored';
+		} elseif (!str_ends_with($file->getName(), ' - summary.md')) {
+			$removeNotification = 'transcript_file_stored';
+		} elseif (str_ends_with($file->getName(), ' - summary.md')) {
+			$removeNotification = 'summary_file_stored';
+		}
+
 		$share = $this->shareManager->createShare($share);
 
 		$message = json_encode([
@@ -399,6 +559,6 @@ class RecordingService {
 			$this->logger->error($e->getMessage(), ['exception' => $e]);
 			throw new InvalidArgumentException('system');
 		}
-		$this->notificationDismiss($room, $participant, $timestamp);
+		$this->notificationDismiss($room, $participant, $timestamp, $removeNotification);
 	}
 }
