@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2019 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Settings\Admin;
@@ -26,11 +11,10 @@ namespace OCA\Talk\Settings\Admin;
 use OCA\Talk\Config;
 use OCA\Talk\Exceptions\WrongPermissionsException;
 use OCA\Talk\MatterbridgeManager;
-use OCA\Talk\Model\Command;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
-use OCA\Talk\Service\CommandService;
 use OCP\AppFramework\Http\TemplateResponse;
+use OCP\AppFramework\Services\IAppConfig;
 use OCP\AppFramework\Services\IInitialState;
 use OCP\ICacheFactory;
 use OCP\IConfig;
@@ -44,39 +28,21 @@ use OCP\Settings\ISettings;
 use OCP\Util;
 
 class AdminSettings implements ISettings {
-	private Config $talkConfig;
-	private IConfig $serverConfig;
-	private CommandService $commandService;
-	private IInitialState $initialState;
-	private ICacheFactory $memcacheFactory;
-	private IGroupManager $groupManager;
-	private MatterbridgeManager $bridgeManager;
 	private ?IUser $currentUser = null;
-	private IL10N $l10n;
-	private IFactory $l10nFactory;
 
 	public function __construct(
-		Config $talkConfig,
-		IConfig $serverConfig,
-		CommandService $commandService,
-		IInitialState $initialState,
-		ICacheFactory $memcacheFactory,
-		IGroupManager $groupManager,
-		MatterbridgeManager $bridgeManager,
+		private Config $talkConfig,
+		private IConfig $serverConfig,
+		private IAppConfig $appConfig,
+		private IInitialState $initialState,
+		private ICacheFactory $memcacheFactory,
+		private IGroupManager $groupManager,
+		private MatterbridgeManager $bridgeManager,
 		IUserSession $userSession,
-		IL10N $l10n,
-		IFactory $l10nFactory,
+		private IL10N $l10n,
+		private IFactory $l10nFactory,
 	) {
-		$this->talkConfig = $talkConfig;
-		$this->serverConfig = $serverConfig;
-		$this->commandService = $commandService;
-		$this->initialState = $initialState;
-		$this->memcacheFactory = $memcacheFactory;
-		$this->groupManager = $groupManager;
-		$this->bridgeManager = $bridgeManager;
 		$this->currentUser = $userSession->getUser();
-		$this->l10n = $l10n;
-		$this->l10nFactory = $l10nFactory;
 	}
 
 	/**
@@ -85,7 +51,7 @@ class AdminSettings implements ISettings {
 	public function getForm(): TemplateResponse {
 		$this->initGeneralSettings();
 		$this->initAllowedGroups();
-		$this->initCommands();
+		$this->initFederation();
 		$this->initMatterbridge();
 		$this->initStunServers();
 		$this->initTurnServers();
@@ -96,19 +62,20 @@ class AdminSettings implements ISettings {
 
 
 		Util::addScript('spreed', 'talk-admin-settings');
+		Util::addStyle('spreed', 'talk-admin-settings');
 
 		return new TemplateResponse('spreed', 'settings/admin-settings', [], '');
 	}
 
 	protected function initGeneralSettings(): void {
-		$this->initialState->provideInitialState('default_group_notification', (int) $this->serverConfig->getAppValue('spreed', 'default_group_notification', (string) Participant::NOTIFY_MENTION));
-		$this->initialState->provideInitialState('conversations_files', (int) $this->serverConfig->getAppValue('spreed', 'conversations_files', '1'));
-		$this->initialState->provideInitialState('conversations_files_public_shares', (int) $this->serverConfig->getAppValue('spreed', 'conversations_files_public_shares', '1'));
+		$this->initialState->provideInitialState('default_group_notification', (int)$this->serverConfig->getAppValue('spreed', 'default_group_notification', (string)Participant::NOTIFY_MENTION));
+		$this->initialState->provideInitialState('conversations_files', (int)$this->serverConfig->getAppValue('spreed', 'conversations_files', '1'));
+		$this->initialState->provideInitialState('conversations_files_public_shares', (int)$this->serverConfig->getAppValue('spreed', 'conversations_files_public_shares', '1'));
 		$this->initialState->provideInitialState('valid_apache_php_configuration', $this->validApachePHPConfiguration());
 	}
 
 	protected function initAllowedGroups(): void {
-		$this->initialState->provideInitialState('start_calls', (int) $this->serverConfig->getAppValue('spreed', 'start_calls', (string) Room::START_CALL_EVERYONE));
+		$this->initialState->provideInitialState('start_calls', (int)$this->serverConfig->getAppValue('spreed', 'start_calls', (string)Room::START_CALL_EVERYONE));
 
 		$groups = $this->getGroupDetailsArray($this->talkConfig->getAllowedConversationsGroupIds(), 'start_conversations');
 		$this->initialState->provideInitialState('start_conversations', $groups);
@@ -117,20 +84,18 @@ class AdminSettings implements ISettings {
 		$this->initialState->provideInitialState('allowed_groups', $groups);
 	}
 
-	protected function initCommands(): void {
-		$commands = $this->commandService->findAll();
-
-		$result = array_map(function (Command $command) {
-			return $command->asArray();
-		}, $commands);
-
-		$this->initialState->provideInitialState('commands', $result);
+	protected function initFederation(): void {
+		$this->initialState->provideInitialState('federation_enabled', $this->talkConfig->isFederationEnabled());
+		$this->initialState->provideInitialState('federation_incoming_enabled', $this->appConfig->getAppValueBool('federation_incoming_enabled', true));
+		$this->initialState->provideInitialState('federation_outgoing_enabled', $this->appConfig->getAppValueBool('federation_outgoing_enabled', true));
+		$this->initialState->provideInitialState('federation_only_trusted_servers', $this->appConfig->getAppValueBool('federation_only_trusted_servers'));
+		$this->initialState->provideInitialState('federation_allowed_groups', $this->appConfig->getAppValueArray('federation_allowed_groups'));
 	}
 
 	protected function initMatterbridge(): void {
 		$error = '';
 		try {
-			$version = (string) $this->bridgeManager->getCurrentVersionFromBinary();
+			$version = (string)$this->bridgeManager->getCurrentVersionFromBinary();
 			if ($version === '') {
 				$error = 'binary';
 			}
@@ -429,7 +394,7 @@ class AdminSettings implements ISettings {
 		}
 		$userLocale = $this->serverConfig->getUserValue($this->currentUser->getUID(), 'core', 'locale', 'en_US');
 		$guessCountry = 'US';
-		if (strpos($userLocale, '_') !== false) {
+		if (str_contains($userLocale, '_')) {
 			$guessCountry = substr($userLocale, strrpos($userLocale, '_') + 1);
 			$correctGuess = false;
 			foreach ($countries as $country) {
@@ -482,6 +447,7 @@ class AdminSettings implements ISettings {
 			'secret' => $this->talkConfig->getRecordingSecret(),
 			'uploadLimit' => is_infinite($uploadLimit) ? 0 : $uploadLimit,
 		]);
+		$this->initialState->provideInitialState('recording_consent', $this->talkConfig->getRecordingConsentConfig());
 	}
 
 	protected function initSIPBridge(): void {
@@ -490,6 +456,7 @@ class AdminSettings implements ISettings {
 		$this->initialState->provideInitialState('sip_bridge_groups', $groups);
 		$this->initialState->provideInitialState('sip_bridge_shared_secret', $this->talkConfig->getSIPSharedSecret());
 		$this->initialState->provideInitialState('sip_bridge_dialin_info', $this->talkConfig->getDialInInfo());
+		$this->initialState->provideInitialState('sip_bridge_dialout', $this->talkConfig->isSIPDialOutEnabled());
 	}
 
 	protected function getGroupDetailsArray(array $gids, string $configKey): array {
@@ -535,11 +502,11 @@ class AdminSettings implements ISettings {
 
 		if ($usingFPM) {
 			// Needs to use mpm_event
-			return strpos($apacheModule, 'event') !== false ? '' : 'invalid';
+			return str_contains($apacheModule, 'event') ? '' : 'invalid';
 		}
 
 		// Needs to use mpm_prefork
-		return strpos($apacheModule, 'prefork') !== false ? '' : 'invalid';
+		return str_contains($apacheModule, 'prefork') ? '' : 'invalid';
 	}
 
 	/**
@@ -551,8 +518,8 @@ class AdminSettings implements ISettings {
 
 	/**
 	 * @return int whether the form should be rather on the top or bottom of
-	 * the admin section. The forms are arranged in ascending order of the
-	 * priority values. It is required to return a value between 0 and 100.
+	 *             the admin section. The forms are arranged in ascending order of the
+	 *             priority values. It is required to return a value between 0 and 100.
 	 *
 	 * E.g.: 70
 	 */
