@@ -2,24 +2,8 @@
 
 declare(strict_types=1);
 /**
- *
- * @copyright Copyright (c) 2018, Daniel Calviño Sánchez (danxuliu@gmail.com)
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Share\Helper;
@@ -42,27 +26,15 @@ use OCP\Share\IShare;
  * actions or checks specific to room shares.
  */
 class ShareAPIController {
-	protected string $userId;
-	protected Manager $manager;
-	protected ParticipantService $participantService;
-	protected ITimeFactory $timeFactory;
-	protected IL10N $l;
-	protected IURLGenerator $urlGenerator;
 
 	public function __construct(
-		string $UserId,
-		Manager $manager,
-		ParticipantService $participantService,
-		ITimeFactory $timeFactory,
-		IL10N $l10n,
-		IURLGenerator $urlGenerator,
+		protected string $userId,
+		protected Manager $manager,
+		protected ParticipantService $participantService,
+		protected ITimeFactory $timeFactory,
+		protected IL10N $l,
+		protected IURLGenerator $urlGenerator,
 	) {
-		$this->userId = $UserId;
-		$this->manager = $manager;
-		$this->participantService = $participantService;
-		$this->timeFactory = $timeFactory;
-		$this->l = $l10n;
-		$this->urlGenerator = $urlGenerator;
 	}
 
 	/**
@@ -115,8 +87,8 @@ class ShareAPIController {
 
 		if ($expireDate !== '') {
 			try {
-				$expireDate = $this->parseDate($expireDate);
-				$share->setExpirationDate($expireDate);
+				$expireDateTime = $this->parseDate($expireDate);
+				$share->setExpirationDate($expireDateTime);
 			} catch (\Exception $e) {
 				throw new OCSNotFoundException($this->l->t('Invalid date, date format must be YYYY-MM-DD'));
 			}
@@ -141,11 +113,7 @@ class ShareAPIController {
 			throw new \Exception('Invalid date. Format must be YYYY-MM-DD');
 		}
 
-		if ($date === false) {
-			throw new \Exception('Invalid date. Format must be YYYY-MM-DD');
-		}
-
-		$date->setTime(0, 0, 0);
+		$date->setTime(0, 0);
 
 		return $date;
 	}
