@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Signaling;
@@ -34,20 +19,11 @@ use OCP\IDBConnection;
 class Messages {
 	use TTransactional;
 
-	protected IDBConnection $db;
-
-	protected ParticipantService $participantService;
-
-	protected ITimeFactory $timeFactory;
-
 	public function __construct(
-		IDBConnection $db,
-		ParticipantService $participantService,
-		ITimeFactory $timeFactory,
+		protected IDBConnection $db,
+		protected ParticipantService $participantService,
+		protected ITimeFactory $timeFactory,
 	) {
-		$this->db = $db;
-		$this->participantService = $participantService;
-		$this->timeFactory = $timeFactory;
 	}
 
 	/**
@@ -121,7 +97,7 @@ class Messages {
 	 * "new" message.
 	 *
 	 * @param string $sessionId
-	 * @return array
+	 * @return list<array{type: string, data: string}>
 	 */
 	public function getAndDeleteMessages(string $sessionId): array {
 		$messages = [];
